Author: Brian B. Avants and Nicholas J. Tustison

# ANTsPyMM processing summary and data dictionary

#### Brian B. Avants and Nicholas J. Tustison

## ANTsPyMM imaging-derived phenotypes and associated coordinate systems / neuroanatomy

A quick overview of the labels used/generated by this framework: .

The `ANTsPyMM` system takes advantage of templates, core T1 processing and super-resolution described in this paper.

- We quantify cortex with the Desikan-Killiany-Tourville parcellation (DKT).

  - `*dktregions` refers to the segmentation label directly from the deep learning method.

  - `*dktcortex` refers to the segmentation label restricted to the cortical segmentation that is provided by the tissue segmentation method.

- Subcortical segmentation with deep learning and also SyN registration leverages the CIT168 atlas 10.1101/211201.

- A medial temporal lobe parcellation is based on manual labels derived from M. Yassa’s research group (preprint) and described here.

- A cerebellum parcellation based on a template from the CoBrALab with additional manual editing by the Tustison family (publication in progress). The parcellation scheme is defined using the Schmahmann nomenclature (reviewed here). The core tool is named `cerebellum_morphology` and based on a concatentation of two U-nets.

- Brain stem is subdivided into the mid-brain, pons and medulla; This segmentation derives from registration between the individual T1w and the manually labeled CIT168 template. The protocol is based on this used in Freesurfer.

- We segment anatomy related to the basal forebrain and associated cholinergic neurons with a deep learning method (`deepNBM`) derived from manual labeling of ADNI data.

  - This approach is based on anatomical landmarks proposed in Liu, A. et al. (2015). The `deepNBM` method uses super-resolution segmentation to take advantage of manual labels performed on super-resolution training data.

  - The classic Zaborszky, L. et al. (2008) “Stereotaxic probabilistic maps of the magnocellular cell groups in human basal forebrain.” Neuroimage 42: 1127–1141 also informed the manual labeling.

  - Presented at Human Brain Mapping conference 2022.

- The Mori JHU white matter atlas provides a parcellation of white matter regions (paper here) which are applied to diffusion weighted images.

- Jonathan Power’s coordinates from “Functional Network Organization of the Human Brain” 10.1016/j.neuron.2011.09.006 were previously used to guide our analysis of resting state function MRI (rsfMRI). We also based our processing evaluation on these data. However, we now use the homotopic coordinates described below.

- Yeo’s Homotopic local-global parcellation of the human cerebral cortex from resting-state functional connectivity is the new default that we use for rsfMRI instead of the JP coordinates. Additional details about the parcellation are here. We use the variant with 500 homotopic parcels i.e. 250 per hemisphere.

  - these parcels are used to generate inter and intra network correlations using the following networks (which are further subdivided s.t. 17 network names are available)

    - Visual Network: Processes visual information, including spatial and motion processing.

    - Somatomotor Network: Involved in the control of movement and processing of somatosensory information.

    - Dorsal Attention Network: Plays a key role in top-down attentional control and spatial orientation.

    - Ventral Attention Network: Involved in detecting unexpected stimuli and bottom-up attention.

    - Limbic Network: Associated with emotion processing, memory, and autonomic functions.

    - Frontoparietal Network: Important for cognitive functions including working memory and executive control.

    - Default Mode Network (DMN): Active during rest and involved in self-referential thought, memory retrieval, and planning for the future.

  - The 17 Network abbreviations are adapted from Ru Kong’s work.

  - rsfMRI phenotype variables like “fcnxpro129” indicate that parameter set 129 was used; currently 122 is considered “best” but 129 and 134 are also provided. they differ in the censoring and nuisance variables used in the processing.

  - we also provide voxel-wise measurements within each parcel including:

    - fALFF and ALFF each divided by the global mean of the brain (mfALFF and mALFF)

    - percent absolute fluctuation divided by the global PerAF mean of the brain (mPerAF)

## ANTsPyMM data dictionary

The `ANTsPyMM` data dictionary labels associates each column name with each of the above anatomical references. Table 1 below summarizes the number of variables associated with each modality and anatomical prior space. DTI-derived connectivity yields the largest number of variables because we pairwise map each DKT cortical region as well as the primary CIT168 regions.

### Table 1

| DTI | Flair | Neuromelanin | Other | restingStatefMRI | T1 DiReCT thickness processing | T1 hierarchical processing | p
--- | --- | --- | --- | --- | --- | --- | --- | ---
| (N=572) | (N=9) | (N=27) | (N=70) | (N=1839) | (N=63) | (N=853)
Atlas |  |  |  |  |  |  |  | < 0.001
ANTs | 4 ( 0.7%) | 9 (100.0%) | 13 (48.1%) | 70 (100.0%) | 0 ( 0.0%) | 1 ( 1.6%) | 21 ( 2.5%) |
BF | 18 ( 3.1%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 24 ( 2.8%) |
CIT168 | 200 (35.0%) | 0 ( 0.0%) | 14 (51.9%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 189 (22.2%) |
desikan-killiany-tourville | 252 (44.1%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 62 (98.4%) | 486 (57.0%) |
johns hopkins white matter | 98 (17.1%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) |
MTL | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 36 ( 4.2%) |
quality control metrics | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 25 ( 2.9%) |
TustisonCobra | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 72 ( 8.4%) |
yeo_homotopic | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 1839 (100.0%) | 0 ( 0.0%) | 0 ( 0.0%) |
Measurement | unique values:50 | unique values:50 | unique values:50 | unique values:50 | unique values:50 | unique values:50 | unique values:50 |

## Quality control metrics

Automated (blind) QC is part of standard ANTsPyMM processing. QC metrics are therefore present in the standard output tables. Notes on the meaning of these metrics, along with examples of the metrics on images, are here.

The most important QC metric is `T1Hier_resnetGrade` which rejects truly bad images. We recommend rejecting images with `T1Hier_resnetGrade < 1.01` where higher thresholds may be useful in some cases. This grading function uses deep learning to generate a pseudocontinuous measurement of aggregate T1w image quality. Several factors will contribute to these scores and it is not a perfect approach but it is well-defined and evaluated based on manual ratings here.

The `outlierness` function produces additional blind QC measurements via automated outlierness calculations. These measurements are denoted by Local Outlier Probability (LOOP `*loop*` ) and local outlier factor ( LOF `*lof*` ) column names.

Time series images may have additional QC metrics such as:

- TSNR: temporal signal to noise ratio

- SSNR: spatial signal to noise ratio on the mean image (different from TSNR)

- DVARS: the spatial root mean square of the data after temporal differencing

- Neuromelanin (NM) has its own set of variables including:

  - count: the number of acquisitions at that date

  - min/max/mean/sd: a statistic on the raw image signal after averaging the acquisitions

  - `avg/std_refregion` : average and standard deviation of signal in the reference region

  - `avg/std_substantianigra` : average and standard deviation of signal in the substantia nigra or a related CIT168 region (determined by deepCIT168)

  - `NM2DMT_NM_substantianigra_z_coordinate`: estimate of the normalized (zero to one) z-coordinate of the substantia nigra in a neuromelanin scan; higher values mean higher in the slab.

- the framewise displacement (FD) values are 10x in DTI data compared to rsfMRI data. E.g. if 0.3 were a reasonable high motion threshold in rsfMRI; then 3.0 would be a comparable threshold for DTI.

## the full data dictionary

A sortable version of the data dictionary is below (if viewing on local machine).

### Table 2

Label
Modality
side
Atlas
Measurement
Anatomy
tidynames
X
Other
​
ANTs
ignore
​
x
filename
Other
​
ANTs
​
​
filename
noise
Other
​
ANTs
QC
​
noise
snr
Other
​
ANTs
QC
​
snr
cnr
Other
​
ANTs
QC
​
cnr
psnr
Other
​
ANTs
QC
​
psnr
ssim
Other
​
ANTs
QC
​
ssim
mi
Other
​
ANTs
QC
​
mi
reflection_err
Other
​
ANTs
QC
​
reflection.err
EVR
Other
​
ANTs
QC
​
evr
msk_vol
Other
​
ANTs
geometry/volume
​
msk.vol
spc0
Other
​
ANTs
QC
​
spc0
spc1
Other
​
ANTs
QC
​
spc1
spc2
Other
​
ANTs
QC
​
spc2
org0
Other
​
ANTs
QC
​
org0
org1
Other
​
ANTs
QC
​
org1
org2
Other
​
ANTs
QC
​
org2
dimx
Other
​
ANTs
QC
​
dimx
dimy
Other
​
ANTs
QC
​
dimy
dimz
Other
​
ANTs
QC
​
dimz
slice
Other
​
ANTs
slice number in time series (ignore)
​
slice
modality
Other
​
ANTs
generic modality name
​
modality
mrimfg
Other
​
ANTs
MRI manufacturer (often missing)
​
mrimfg
mrimodel
Other
​
ANTs
MRI model (often missing)
​
mrimodel
ol_loop
Other
​
ANTs
QC
​
ol.loop
ol_lof
Other
​
ANTs
QC
​
ol.lof
ol_lof_decision
Other
​
ANTs
QC
​
ol.lof.decision
subjectID
Other
​
ANTs
unique subject ID
​
subjectid
date
Other
​
ANTs
image acquisition date
​
date
subjectIDdate
Other
​
ANTs
concatenation of subject ID and date
​
subjectiddate
imageID
Other
​
ANTs
unique image ID (ideally unique but not always)
​
imageid
negol
Other
​
ANTs
negative outlier variable (higher is better)
​
negol
flairid
Flair
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
flairid
flairfn
Flair
​
ANTs
original source data filename
​
flairfn
flairloop
Flair
​
ANTs
QC
​
flairloop
flairlof
Flair
​
ANTs
QC
​
flairlof
dtid1
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
dtid1
dtfn1
Other
​
ANTs
original source data filename
​
dtfn1
dtloop1
Other
​
ANTs
QC
​
dtloop1
dtlof1
Other
​
ANTs
QC
​
dtlof1
dtid2
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
dtid2
dtfn2
Other
​
ANTs
original source data filename
​
dtfn2
dtloop2
Other
​
ANTs
QC
​
dtloop2
dtlof2
Other
​
ANTs
QC
​
dtlof2
rsfid1
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
rsfid1
rsffn1
Other
​
ANTs
original source data filename
​
rsffn1
rsfloop1
Other
​
ANTs
QC
​
rsfloop1
rsflof1
Other
​
ANTs
QC
​
rsflof1
rsfid2
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
rsfid2
rsffn2
Other
​
ANTs
original source data filename
​
rsffn2
rsfloop2
Other
​
ANTs
QC
​
rsfloop2
rsflof2
Other
​
ANTs
QC
​
rsflof2
nmid1
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmid1
nmfn1
Other
​
ANTs
original source data filename
​
nmfn1
nmloop1
Other
​
ANTs
QC
​
nmloop1
nmlof1
Other
​
ANTs
QC
​
nmlof1
nmid2
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmid2
nmfn2
Other
​
ANTs
original source data filename
​
nmfn2
nmloop2
Other
​
ANTs
QC
​
nmloop2
nmlof2
Other
​
ANTs
QC
​
nmlof2
nmid3
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmid3
nmfn3
Other
​
ANTs
original source data filename
​
nmfn3
nmloop3
Other
​
ANTs
QC
​
nmloop3
nmlof3
Other
​
ANTs
QC
​
nmlof3
nmid4
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmid4
nmfn4
Other
​
ANTs
original source data filename
​
nmfn4
nmloop4
Other
​
ANTs
QC
​
nmloop4
nmlof4
Other
​
ANTs
QC
​
nmlof4
nmid5
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmid5
nmfn5
Other
​
ANTs
original source data filename
​
nmfn5
nmloop5
Other
​
ANTs
QC
​
nmloop5
nmlof5
Other
​
ANTs
QC
​
nmlof5
negative_outlier_factor
Other
​
ANTs
negative outlier variable (higher is better)
​
negative.outlier.factor
projectID
Other
​
ANTs
project ID or name eg ADNI
​
projectid
T1Hier_vol_hemisphere_lefthemispheres
T1 hierarchical processing
left
ANTs
geometry/volume
vol hemisphere hemispheres
t1.vol.hemisphere.lefthemispheres
T1Hier_vol_hemisphere_righthemispheres
T1 hierarchical processing
right
ANTs
geometry/volume
vol hemisphere hemispheres
t1.vol.hemisphere.righthemispheres
T1Hier_area_hemisphere_lefthemispheres
T1 hierarchical processing
left
ANTs
geometry/area
hemisphere hemispheres
t1.area.hemisphere.lefthemispheres
T1Hier_area_hemisphere_righthemispheres
T1 hierarchical processing
right
ANTs
geometry/area
hemisphere hemispheres
t1.area.hemisphere.righthemispheres
T1Hier_thk_hemisphere_lefthemispheres
T1 hierarchical processing
left
ANTs
geometry/thickness
hemisphere hemispheres
t1.thk.hemisphere.lefthemispheres
T1Hier_thk_hemisphere_righthemispheres
T1 hierarchical processing
right
ANTs
geometry/thickness
hemisphere hemispheres
t1.thk.hemisphere.righthemispheres
T1Hier_vol_brainstemtissues
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.brainstemtissues
T1Hier_vol_csftissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol csftissues
t1.vol.csftissues
T1Hier_vol_cerebellumtissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol cerebellumtissues
t1.vol.cerebellumtissues
T1Hier_vol_deepgraytissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol deepgraytissues
t1.vol.deepgraytissues
T1Hier_vol_gmtissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol gmtissues
t1.vol.gmtissues
T1Hier_vol_wmtissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol wmtissues
t1.vol.wmtissues
T1Hier_area_brainstemtissues
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.brainstemtissues
T1Hier_area_csftissues
T1 hierarchical processing
​
ANTs
geometry/area
csftissues
t1.area.csftissues
T1Hier_area_cerebellumtissues
T1 hierarchical processing
​
ANTs
geometry/area
cerebellumtissues
t1.area.cerebellumtissues
T1Hier_area_deepgraytissues
T1 hierarchical processing
​
ANTs
geometry/area
deepgraytissues
t1.area.deepgraytissues
T1Hier_area_gmtissues
T1 hierarchical processing
​
ANTs
geometry/area
gmtissues
t1.area.gmtissues
T1Hier_area_wmtissues
T1 hierarchical processing
​
ANTs
geometry/area
wmtissues
t1.area.wmtissues
T1Hier_thk_brainstemtissues
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.brainstemtissues
T1Hier_thk_csftissues
T1 hierarchical processing
​
ANTs
geometry/thickness
csftissues
t1.thk.csftissues
T1Hier_thk_cerebellumtissues
T1 hierarchical processing
​
ANTs
geometry/thickness
cerebellumtissues
t1.thk.cerebellumtissues
T1Hier_thk_deepgraytissues
T1 hierarchical processing
​
ANTs
geometry/thickness
deepgraytissues
t1.thk.deepgraytissues
T1Hier_thk_gmtissues
T1 hierarchical processing
​
ANTs
geometry/thickness
gmtissues
t1.thk.gmtissues
T1Hier_thk_wmtissues
T1 hierarchical processing
​
ANTs
geometry/thickness
wmtissues
t1.thk.wmtissues
T1Hier_vol_brainstem_ldktlobes
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.brainstem.ldktlobes
T1Hier_vol_brainstem_rdktlobes
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.brainstem.rdktlobes
T1Hier_vol_cerebellum_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol cerebellum ldktlobes
t1.vol.cerebellum.ldktlobes
T1Hier_vol_cerebellum_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol cerebellum rdktlobes
t1.vol.cerebellum.rdktlobes
T1Hier_vol_frontal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol frontal ldktlobes
t1.vol.frontal.ldktlobes
T1Hier_vol_frontal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol frontal rdktlobes
t1.vol.frontal.rdktlobes
T1Hier_vol_occipital_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol occipital ldktlobes
t1.vol.occipital.ldktlobes
T1Hier_vol_occipital_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol occipital rdktlobes
t1.vol.occipital.rdktlobes
T1Hier_vol_parietal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol parietal ldktlobes
t1.vol.parietal.ldktlobes
T1Hier_vol_parietal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol parietal rdktlobes
t1.vol.parietal.rdktlobes
T1Hier_vol_temporal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol temporal ldktlobes
t1.vol.temporal.ldktlobes
T1Hier_vol_temporal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol temporal rdktlobes
t1.vol.temporal.rdktlobes
T1Hier_area_brainstem_ldktlobes
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.brainstem.ldktlobes
T1Hier_area_brainstem_rdktlobes
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.brainstem.rdktlobes
T1Hier_area_cerebellum_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellum ldktlobes
t1.area.cerebellum.ldktlobes
T1Hier_area_cerebellum_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellum rdktlobes
t1.area.cerebellum.rdktlobes
T1Hier_area_frontal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
frontal ldktlobes
t1.area.frontal.ldktlobes
T1Hier_area_frontal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
frontal rdktlobes
t1.area.frontal.rdktlobes
T1Hier_area_occipital_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
occipital ldktlobes
t1.area.occipital.ldktlobes
T1Hier_area_occipital_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
occipital rdktlobes
t1.area.occipital.rdktlobes
T1Hier_area_parietal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
parietal ldktlobes
t1.area.parietal.ldktlobes
T1Hier_area_parietal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
parietal rdktlobes
t1.area.parietal.rdktlobes
T1Hier_area_temporal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
temporal ldktlobes
t1.area.temporal.ldktlobes
T1Hier_area_temporal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
temporal rdktlobes
t1.area.temporal.rdktlobes
T1Hier_thk_brainstem_ldktlobes
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.brainstem.ldktlobes
T1Hier_thk_brainstem_rdktlobes
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.brainstem.rdktlobes
T1Hier_thk_cerebellum_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellum ldktlobes
t1.thk.cerebellum.ldktlobes
T1Hier_thk_cerebellum_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellum rdktlobes
t1.thk.cerebellum.rdktlobes
T1Hier_thk_frontal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
frontal ldktlobes
t1.thk.frontal.ldktlobes
T1Hier_thk_frontal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
frontal rdktlobes
t1.thk.frontal.rdktlobes
T1Hier_thk_occipital_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
occipital ldktlobes
t1.thk.occipital.ldktlobes
T1Hier_thk_occipital_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
occipital rdktlobes
t1.thk.occipital.rdktlobes
T1Hier_thk_parietal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
parietal ldktlobes
t1.thk.parietal.ldktlobes
T1Hier_thk_parietal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
parietal rdktlobes
t1.thk.parietal.rdktlobes
T1Hier_thk_temporal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
temporal ldktlobes
t1.thk.temporal.ldktlobes
T1Hier_thk_temporal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
temporal rdktlobes
t1.thk.temporal.rdktlobes
T1Hier_vol_4th_ventricledktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
4th ventricle
t1.vol.4th.ventricledktregions
T1Hier_vol_csfdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol csf
t1.vol.csfdktregions
T1Hier_vol_brain_stemdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
brain stem
t1.vol.brain.stemdktregions
T1Hier_vol_cerebellar_vermal_lobules_i.vdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol cerebellar vermal lobules i v
t1.vol.cerebellar.vermal.lobules.i.vdktregions
T1Hier_vol_cerebellar_vermal_lobules_vi.viidktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol cerebellar vermal lobules vi vii
t1.vol.cerebellar.vermal.lobules.vi.viidktregions
T1Hier_vol_cerebellar_vermal_lobules_viii.xdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol cerebellar vermal lobules viii x
t1.vol.cerebellar.vermal.lobules.viii.xdktregions
T1Hier_vol_left_amygdaladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
amygdala
t1.vol.left.amygdaladktregions
T1Hier_vol_left_caudal_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
t1.vol.left.caudal.ant.cingulatedktregions
T1Hier_vol_left_caudal_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
t1.vol.left.caudal.middle.frontaldktregions
T1Hier_vol_left_caudatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudate
t1.vol.left.caudatedktregions
T1Hier_vol_left_cerebellem_exteriordktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cerebellem exterior
t1.vol.left.cerebellem.exteriordktregions
T1Hier_vol_left_cerebellum_white_matterdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cerebellum white matter
t1.vol.left.cerebellum.white.matterdktregions
T1Hier_vol_left_cuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cuneus
t1.vol.left.cuneusdktregions
T1Hier_vol_left_entorhinaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
entorhinal
t1.vol.left.entorhinaldktregions
T1Hier_vol_left_fusiformdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
fusiform
t1.vol.left.fusiformdktregions
T1Hier_vol_left_hippocampusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
hippocampus
t1.vol.left.hippocampusdktregions
T1Hier_vol_left_inferior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior parietal
t1.vol.left.inf.parietaldktregions
T1Hier_vol_left_inferior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior temporal
t1.vol.left.inf.temporaldktregions
T1Hier_vol_left_insuladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
insula
t1.vol.left.insuladktregions
T1Hier_vol_left_isthmus_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
t1.vol.left.isthmus.cingulatedktregions
T1Hier_vol_left_lateral_occipitaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral occipital
t1.vol.left.lateral.occipitaldktregions
T1Hier_vol_left_lateral_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
t1.vol.left.lateral.orbitofrontaldktregions
T1Hier_vol_left_lateral_ventricledktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral ventricle
t1.vol.left.lateral.ventricledktregions
T1Hier_vol_left_lingualdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lingual
t1.vol.left.lingualdktregions
T1Hier_vol_left_medial_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
t1.vol.left.medial.orbitofrontaldktregions
T1Hier_vol_left_middle_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
middle temporal
t1.vol.left.middle.temporaldktregions
T1Hier_vol_left_pallidiumdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pallidium
t1.vol.left.pallidiumdktregions
T1Hier_vol_left_paracentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
paracentral
t1.vol.left.paracentdktregions
T1Hier_vol_left_parahippocampaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.left.parahippocampaldktregions
T1Hier_vol_left_pars_opercularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars opercularis
t1.vol.left.pars.opercularisdktregions
T1Hier_vol_left_pars_orbitalisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
t1.vol.left.pars.orbitalisdktregions
T1Hier_vol_left_pars_triangularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars triangularis
t1.vol.left.pars.triangularisdktregions
T1Hier_vol_left_pericalcarinedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pericalcarine
t1.vol.left.pericalcarinedktregions
T1Hier_vol_left_postcentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
postcentral
t1.vol.left.postcentdktregions
T1Hier_vol_left_posterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
t1.vol.left.post.cingulatedktregions
T1Hier_vol_left_precentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precentral
t1.vol.left.precentdktregions
T1Hier_vol_left_precuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precuneus
t1.vol.left.precuneusdktregions
T1Hier_vol_left_putamendktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
putamen
t1.vol.left.putamendktregions
T1Hier_vol_left_rostral_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
t1.vol.left.rostral.ant.cingulatedktregions
T1Hier_vol_left_rostral_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
t1.vol.left.rostral.middle.frontaldktregions
T1Hier_vol_left_superior_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior frontal
t1.vol.left.sup.frontaldktregions
T1Hier_vol_left_superior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior parietal
t1.vol.left.sup.parietaldktregions
T1Hier_vol_left_superior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior temporal
t1.vol.left.sup.temporaldktregions
T1Hier_vol_left_supramarginaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
supramarginal
t1.vol.left.supramarginaldktregions
T1Hier_vol_left_thalamus_properdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
thalamus proper
t1.vol.left.thalamus.properdktregions
T1Hier_vol_left_transverse_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
transverse temporal
t1.vol.left.transverse.temporaldktregions
T1Hier_vol_left_ventral_dcdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
volventral dc
t1.vol.left.ventral.dcdktregions
T1Hier_vol_right_amygdaladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
amygdala
t1.vol.right.amygdaladktregions
T1Hier_vol_right_caudal_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
t1.vol.right.caudal.ant.cingulatedktregions
T1Hier_vol_right_caudal_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
t1.vol.right.caudal.middle.frontaldktregions
T1Hier_vol_right_caudatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudate
t1.vol.right.caudatedktregions
T1Hier_vol_right_cerebellum_exteriordktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cerebellum exterior
t1.vol.right.cerebellum.exteriordktregions
T1Hier_vol_right_cerebellum_white_matterdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cerebellum white matter
t1.vol.right.cerebellum.white.matterdktregions
T1Hier_vol_right_cuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cuneus
t1.vol.right.cuneusdktregions
T1Hier_vol_right_entorhinaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
entorhinal
t1.vol.right.entorhinaldktregions
T1Hier_vol_right_fusiformdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
fusiform
t1.vol.right.fusiformdktregions
T1Hier_vol_right_hippocampusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
hippocampus
t1.vol.right.hippocampusdktregions
T1Hier_vol_right_inferior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior parietal
t1.vol.right.inf.parietaldktregions
T1Hier_vol_right_inferior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior temporal
t1.vol.right.inf.temporaldktregions
T1Hier_vol_right_insuladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
insula
t1.vol.right.insuladktregions
T1Hier_vol_right_isthmus_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
t1.vol.right.isthmus.cingulatedktregions
T1Hier_vol_right_lateral_occipitaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral occipital
t1.vol.right.lateral.occipitaldktregions
T1Hier_vol_right_lateral_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
t1.vol.right.lateral.orbitofrontaldktregions
T1Hier_vol_right_lateral_ventricledktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral ventricle
t1.vol.right.lateral.ventricledktregions
T1Hier_vol_right_lingualdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lingual
t1.vol.right.lingualdktregions
T1Hier_vol_right_medial_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
t1.vol.right.medial.orbitofrontaldktregions
T1Hier_vol_right_middle_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
middle temporal
t1.vol.right.middle.temporaldktregions
T1Hier_vol_right_palladiumdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
palladium
t1.vol.right.palladiumdktregions
T1Hier_vol_right_paracentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
paracentral
t1.vol.right.paracentdktregions
T1Hier_vol_right_parahippocampaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.right.parahippocampaldktregions
T1Hier_vol_right_pars_opercularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars opercularis
t1.vol.right.pars.opercularisdktregions
T1Hier_vol_right_pars_orbitalisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
t1.vol.right.pars.orbitalisdktregions
T1Hier_vol_right_pars_triangularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars triangularis
t1.vol.right.pars.triangularisdktregions
T1Hier_vol_right_pericalcarinedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pericalcarine
t1.vol.right.pericalcarinedktregions
T1Hier_vol_right_postcentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
postcentral
t1.vol.right.postcentdktregions
T1Hier_vol_right_posterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
t1.vol.right.post.cingulatedktregions
T1Hier_vol_right_precentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precentral
t1.vol.right.precentdktregions
T1Hier_vol_right_precuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precuneus
t1.vol.right.precuneusdktregions
T1Hier_vol_right_putamendktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
putamen
t1.vol.right.putamendktregions
T1Hier_vol_right_rostral_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
t1.vol.right.rostral.ant.cingulatedktregions
T1Hier_vol_right_rostral_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
t1.vol.right.rostral.middle.frontaldktregions
T1Hier_vol_right_superior_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior frontal
t1.vol.right.sup.frontaldktregions
T1Hier_vol_right_superior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior parietal
t1.vol.right.sup.parietaldktregions
T1Hier_vol_right_superior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior temporal
t1.vol.right.sup.temporaldktregions
T1Hier_vol_right_supramarginaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
supramarginal
t1.vol.right.supramarginaldktregions
T1Hier_vol_right_thalamus_properdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
thalamus proper
t1.vol.right.thalamus.properdktregions
T1Hier_vol_right_transverse_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
transverse temporal
t1.vol.right.transverse.temporaldktregions
T1Hier_vol_right_ventral_dcdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
volventral dc
t1.vol.right.ventral.dcdktregions
T1Hier_area_4th_ventricledktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
4th ventricle
t1.area.4th.ventricledktregions
T1Hier_area_csfdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
csf
t1.area.csfdktregions
T1Hier_area_brain_stemdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
brain stem
t1.area.brain.stemdktregions
T1Hier_area_cerebellar_vermal_lobules_i.vdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellar vermal lobules i v
t1.area.cerebellar.vermal.lobules.i.vdktregions
T1Hier_area_cerebellar_vermal_lobules_vi.viidktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellar vermal lobules vi vii
t1.area.cerebellar.vermal.lobules.vi.viidktregions
T1Hier_area_cerebellar_vermal_lobules_viii.xdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellar vermal lobules viii x
t1.area.cerebellar.vermal.lobules.viii.xdktregions
T1Hier_area_left_amygdaladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
amygdala
t1.area.left.amygdaladktregions
T1Hier_area_left_caudal_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
t1.area.left.caudal.ant.cingulatedktregions
T1Hier_area_left_caudal_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal middle frontal
t1.area.left.caudal.middle.frontaldktregions
T1Hier_area_left_caudatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudate
t1.area.left.caudatedktregions
T1Hier_area_left_cerebellem_exteriordktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cerebellem exterior
t1.area.left.cerebellem.exteriordktregions
T1Hier_area_left_cerebellum_white_matterdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cerebellum white matter
t1.area.left.cerebellum.white.matterdktregions
T1Hier_area_left_cuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cuneus
t1.area.left.cuneusdktregions
T1Hier_area_left_entorhinaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
entorhinal
t1.area.left.entorhinaldktregions
T1Hier_area_left_fusiformdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
fusiform
t1.area.left.fusiformdktregions
T1Hier_area_left_hippocampusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
hippocampus
t1.area.left.hippocampusdktregions
T1Hier_area_left_inferior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior parietal
t1.area.left.inf.parietaldktregions
T1Hier_area_left_inferior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior temporal
t1.area.left.inf.temporaldktregions
T1Hier_area_left_insuladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
insula
t1.area.left.insuladktregions
T1Hier_area_left_isthmus_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
isthmus cingulate
t1.area.left.isthmus.cingulatedktregions
T1Hier_area_left_lateral_occipitaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral occipital
t1.area.left.lateral.occipitaldktregions
T1Hier_area_left_lateral_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
t1.area.left.lateral.orbitofrontaldktregions
T1Hier_area_left_lateral_ventricledktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral ventricle
t1.area.left.lateral.ventricledktregions
T1Hier_area_left_lingualdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lingual
t1.area.left.lingualdktregions
T1Hier_area_left_medial_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
medial orbitofrontal
t1.area.left.medial.orbitofrontaldktregions
T1Hier_area_left_middle_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
middle temporal
t1.area.left.middle.temporaldktregions
T1Hier_area_left_pallidiumdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pallidium
t1.area.left.pallidiumdktregions
T1Hier_area_left_paracentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
paracentral
t1.area.left.paracentdktregions
T1Hier_area_left_parahippocampaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.left.parahippocampaldktregions
T1Hier_area_left_pars_opercularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars opercularis
t1.area.left.pars.opercularisdktregions
T1Hier_area_left_pars_orbitalisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars orbitalis
t1.area.left.pars.orbitalisdktregions
T1Hier_area_left_pars_triangularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars triangularis
t1.area.left.pars.triangularisdktregions
T1Hier_area_left_pericalcarinedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pericalcarine
t1.area.left.pericalcarinedktregions
T1Hier_area_left_postcentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
postcentral
t1.area.left.postcentdktregions
T1Hier_area_left_posterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
posterior cingulate
t1.area.left.post.cingulatedktregions
T1Hier_area_left_precentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precentral
t1.area.left.precentdktregions
T1Hier_area_left_precuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precuneus
t1.area.left.precuneusdktregions
T1Hier_area_left_putamendktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
putamen
t1.area.left.putamendktregions
T1Hier_area_left_rostral_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
t1.area.left.rostral.ant.cingulatedktregions
T1Hier_area_left_rostral_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral middle frontal
t1.area.left.rostral.middle.frontaldktregions
T1Hier_area_left_superior_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior frontal
t1.area.left.sup.frontaldktregions
T1Hier_area_left_superior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior parietal
t1.area.left.sup.parietaldktregions
T1Hier_area_left_superior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior temporal
t1.area.left.sup.temporaldktregions
T1Hier_area_left_supramarginaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
supramarginal
t1.area.left.supramarginaldktregions
T1Hier_area_left_thalamus_properdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
thalamus proper
t1.area.left.thalamus.properdktregions
T1Hier_area_left_transverse_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
transverse temporal
t1.area.left.transverse.temporaldktregions
T1Hier_area_left_ventral_dcdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
ventral dc
t1.area.left.ventral.dcdktregions
T1Hier_area_right_amygdaladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
amygdala
t1.area.right.amygdaladktregions
T1Hier_area_right_caudal_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
t1.area.right.caudal.ant.cingulatedktregions
T1Hier_area_right_caudal_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal middle frontal
t1.area.right.caudal.middle.frontaldktregions
T1Hier_area_right_caudatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudate
t1.area.right.caudatedktregions
T1Hier_area_right_cerebellum_exteriordktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cerebellum exterior
t1.area.right.cerebellum.exteriordktregions
T1Hier_area_right_cerebellum_white_matterdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cerebellum white matter
t1.area.right.cerebellum.white.matterdktregions
T1Hier_area_right_cuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cuneus
t1.area.right.cuneusdktregions
T1Hier_area_right_entorhinaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
entorhinal
t1.area.right.entorhinaldktregions
T1Hier_area_right_fusiformdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
fusiform
t1.area.right.fusiformdktregions
T1Hier_area_right_hippocampusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
hippocampus
t1.area.right.hippocampusdktregions
T1Hier_area_right_inferior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior parietal
t1.area.right.inf.parietaldktregions
T1Hier_area_right_inferior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior temporal
t1.area.right.inf.temporaldktregions
T1Hier_area_right_insuladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
insula
t1.area.right.insuladktregions
T1Hier_area_right_isthmus_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
isthmus cingulate
t1.area.right.isthmus.cingulatedktregions
T1Hier_area_right_lateral_occipitaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral occipital
t1.area.right.lateral.occipitaldktregions
T1Hier_area_right_lateral_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
t1.area.right.lateral.orbitofrontaldktregions
T1Hier_area_right_lateral_ventricledktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral ventricle
t1.area.right.lateral.ventricledktregions
T1Hier_area_right_lingualdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lingual
t1.area.right.lingualdktregions
T1Hier_area_right_medial_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
medial orbitofrontal
t1.area.right.medial.orbitofrontaldktregions
T1Hier_area_right_middle_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
middle temporal
t1.area.right.middle.temporaldktregions
T1Hier_area_right_palladiumdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
palladium
t1.area.right.palladiumdktregions
T1Hier_area_right_paracentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
paracentral
t1.area.right.paracentdktregions
T1Hier_area_right_parahippocampaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.right.parahippocampaldktregions
T1Hier_area_right_pars_opercularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars opercularis
t1.area.right.pars.opercularisdktregions
T1Hier_area_right_pars_orbitalisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars orbitalis
t1.area.right.pars.orbitalisdktregions
T1Hier_area_right_pars_triangularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars triangularis
t1.area.right.pars.triangularisdktregions
T1Hier_area_right_pericalcarinedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pericalcarine
t1.area.right.pericalcarinedktregions
T1Hier_area_right_postcentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
postcentral
t1.area.right.postcentdktregions
T1Hier_area_right_posterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
posterior cingulate
t1.area.right.post.cingulatedktregions
T1Hier_area_right_precentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precentral
t1.area.right.precentdktregions
T1Hier_area_right_precuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precuneus
t1.area.right.precuneusdktregions
T1Hier_area_right_putamendktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
putamen
t1.area.right.putamendktregions
T1Hier_area_right_rostral_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
t1.area.right.rostral.ant.cingulatedktregions
T1Hier_area_right_rostral_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral middle frontal
t1.area.right.rostral.middle.frontaldktregions
T1Hier_area_right_superior_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior frontal
t1.area.right.sup.frontaldktregions
T1Hier_area_right_superior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior parietal
t1.area.right.sup.parietaldktregions
T1Hier_area_right_superior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior temporal
t1.area.right.sup.temporaldktregions
T1Hier_area_right_supramarginaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
supramarginal
t1.area.right.supramarginaldktregions
T1Hier_area_right_thalamus_properdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
thalamus proper
t1.area.right.thalamus.properdktregions
T1Hier_area_right_transverse_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
transverse temporal
t1.area.right.transverse.temporaldktregions
T1Hier_area_right_ventral_dcdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
ventral dc
t1.area.right.ventral.dcdktregions
T1Hier_thk_4th_ventricledktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
4th ventricle
t1.thk.4th.ventricledktregions
T1Hier_thk_csfdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
csf
t1.thk.csfdktregions
T1Hier_thk_brain_stemdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
brain stem
t1.thk.brain.stemdktregions
T1Hier_thk_cerebellar_vermal_lobules_i.vdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellar vermal lobules i v
t1.thk.cerebellar.vermal.lobules.i.vdktregions
T1Hier_thk_cerebellar_vermal_lobules_vi.viidktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellar vermal lobules vi vii
t1.thk.cerebellar.vermal.lobules.vi.viidktregions
T1Hier_thk_cerebellar_vermal_lobules_viii.xdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellar vermal lobules viii x
t1.thk.cerebellar.vermal.lobules.viii.xdktregions
T1Hier_thk_left_amygdaladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
amygdala
t1.thk.left.amygdaladktregions
T1Hier_thk_left_caudal_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
t1.thk.left.caudal.ant.cingulatedktregions
T1Hier_thk_left_caudal_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
t1.thk.left.caudal.middle.frontaldktregions
T1Hier_thk_left_caudatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudate
t1.thk.left.caudatedktregions
T1Hier_thk_left_cerebellem_exteriordktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cerebellem exterior
t1.thk.left.cerebellem.exteriordktregions
T1Hier_thk_left_cerebellum_white_matterdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cerebellum white matter
t1.thk.left.cerebellum.white.matterdktregions
T1Hier_thk_left_cuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cuneus
t1.thk.left.cuneusdktregions
T1Hier_thk_left_entorhinaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
entorhinal
t1.thk.left.entorhinaldktregions
T1Hier_thk_left_fusiformdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
fusiform
t1.thk.left.fusiformdktregions
T1Hier_thk_left_hippocampusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
hippocampus
t1.thk.left.hippocampusdktregions
T1Hier_thk_left_inferior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior parietal
t1.thk.left.inf.parietaldktregions
T1Hier_thk_left_inferior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior temporal
t1.thk.left.inf.temporaldktregions
T1Hier_thk_left_insuladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
insula
t1.thk.left.insuladktregions
T1Hier_thk_left_isthmus_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
t1.thk.left.isthmus.cingulatedktregions
T1Hier_thk_left_lateral_occipitaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral occipital
t1.thk.left.lateral.occipitaldktregions
T1Hier_thk_left_lateral_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
t1.thk.left.lateral.orbitofrontaldktregions
T1Hier_thk_left_lateral_ventricledktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral ventricle
t1.thk.left.lateral.ventricledktregions
T1Hier_thk_left_lingualdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lingual
t1.thk.left.lingualdktregions
T1Hier_thk_left_medial_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
t1.thk.left.medial.orbitofrontaldktregions
T1Hier_thk_left_middle_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
middle temporal
t1.thk.left.middle.temporaldktregions
T1Hier_thk_left_pallidiumdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pallidium
t1.thk.left.pallidiumdktregions
T1Hier_thk_left_paracentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
paracentral
t1.thk.left.paracentdktregions
T1Hier_thk_left_parahippocampaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.left.parahippocampaldktregions
T1Hier_thk_left_pars_opercularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars opercularis
t1.thk.left.pars.opercularisdktregions
T1Hier_thk_left_pars_orbitalisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars orbitalis
t1.thk.left.pars.orbitalisdktregions
T1Hier_thk_left_pars_triangularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars triangularis
t1.thk.left.pars.triangularisdktregions
T1Hier_thk_left_pericalcarinedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pericalcarine
t1.thk.left.pericalcarinedktregions
T1Hier_thk_left_postcentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
postcentral
t1.thk.left.postcentdktregions
T1Hier_thk_left_posterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
posterior cingulate
t1.thk.left.post.cingulatedktregions
T1Hier_thk_left_precentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precentral
t1.thk.left.precentdktregions
T1Hier_thk_left_precuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precuneus
t1.thk.left.precuneusdktregions
T1Hier_thk_left_putamendktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
putamen
t1.thk.left.putamendktregions
T1Hier_thk_left_rostral_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
t1.thk.left.rostral.ant.cingulatedktregions
T1Hier_thk_left_rostral_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
t1.thk.left.rostral.middle.frontaldktregions
T1Hier_thk_left_superior_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior frontal
t1.thk.left.sup.frontaldktregions
T1Hier_thk_left_superior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior parietal
t1.thk.left.sup.parietaldktregions
T1Hier_thk_left_superior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior temporal
t1.thk.left.sup.temporaldktregions
T1Hier_thk_left_supramarginaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
supramarginal
t1.thk.left.supramarginaldktregions
T1Hier_thk_left_thalamus_properdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
thalamus proper
t1.thk.left.thalamus.properdktregions
T1Hier_thk_left_transverse_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
transverse temporal
t1.thk.left.transverse.temporaldktregions
T1Hier_thk_left_ventral_dcdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
ventral dc
t1.thk.left.ventral.dcdktregions
T1Hier_thk_right_amygdaladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
amygdala
t1.thk.right.amygdaladktregions
T1Hier_thk_right_caudal_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
t1.thk.right.caudal.ant.cingulatedktregions
T1Hier_thk_right_caudal_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
t1.thk.right.caudal.middle.frontaldktregions
T1Hier_thk_right_caudatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudate
t1.thk.right.caudatedktregions
T1Hier_thk_right_cerebellum_exteriordktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cerebellum exterior
t1.thk.right.cerebellum.exteriordktregions
T1Hier_thk_right_cerebellum_white_matterdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cerebellum white matter
t1.thk.right.cerebellum.white.matterdktregions
T1Hier_thk_right_cuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cuneus
t1.thk.right.cuneusdktregions
T1Hier_thk_right_entorhinaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
entorhinal
t1.thk.right.entorhinaldktregions
T1Hier_thk_right_fusiformdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
fusiform
t1.thk.right.fusiformdktregions
T1Hier_thk_right_hippocampusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
hippocampus
t1.thk.right.hippocampusdktregions
T1Hier_thk_right_inferior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior parietal
t1.thk.right.inf.parietaldktregions
T1Hier_thk_right_inferior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior temporal
t1.thk.right.inf.temporaldktregions
T1Hier_thk_right_insuladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
insula
t1.thk.right.insuladktregions
T1Hier_thk_right_isthmus_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
t1.thk.right.isthmus.cingulatedktregions
T1Hier_thk_right_lateral_occipitaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral occipital
t1.thk.right.lateral.occipitaldktregions
T1Hier_thk_right_lateral_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
t1.thk.right.lateral.orbitofrontaldktregions
T1Hier_thk_right_lateral_ventricledktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral ventricle
t1.thk.right.lateral.ventricledktregions
T1Hier_thk_right_lingualdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lingual
t1.thk.right.lingualdktregions
T1Hier_thk_right_medial_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
t1.thk.right.medial.orbitofrontaldktregions
T1Hier_thk_right_middle_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
middle temporal
t1.thk.right.middle.temporaldktregions
T1Hier_thk_right_palladiumdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
palladium
t1.thk.right.palladiumdktregions
T1Hier_thk_right_paracentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
paracentral
t1.thk.right.paracentdktregions
T1Hier_thk_right_parahippocampaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.right.parahippocampaldktregions
T1Hier_thk_right_pars_opercularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars opercularis
t1.thk.right.pars.opercularisdktregions
T1Hier_thk_right_pars_orbitalisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars orbitalis
t1.thk.right.pars.orbitalisdktregions
T1Hier_thk_right_pars_triangularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars triangularis
t1.thk.right.pars.triangularisdktregions
T1Hier_thk_right_pericalcarinedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pericalcarine
t1.thk.right.pericalcarinedktregions
T1Hier_thk_right_postcentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
postcentral
t1.thk.right.postcentdktregions
T1Hier_thk_right_posterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
posterior cingulate
t1.thk.right.post.cingulatedktregions
T1Hier_thk_right_precentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precentral
t1.thk.right.precentdktregions
T1Hier_thk_right_precuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precuneus
t1.thk.right.precuneusdktregions
T1Hier_thk_right_putamendktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
putamen
t1.thk.right.putamendktregions
T1Hier_thk_right_rostral_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
t1.thk.right.rostral.ant.cingulatedktregions
T1Hier_thk_right_rostral_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
t1.thk.right.rostral.middle.frontaldktregions
T1Hier_thk_right_superior_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior frontal
t1.thk.right.sup.frontaldktregions
T1Hier_thk_right_superior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior parietal
t1.thk.right.sup.parietaldktregions
T1Hier_thk_right_superior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior temporal
t1.thk.right.sup.temporaldktregions
T1Hier_thk_right_supramarginaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
supramarginal
t1.thk.right.supramarginaldktregions
T1Hier_thk_right_thalamus_properdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
thalamus proper
t1.thk.right.thalamus.properdktregions
T1Hier_thk_right_transverse_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
transverse temporal
t1.thk.right.transverse.temporaldktregions
T1Hier_thk_right_ventral_dcdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
ventral dc
t1.thk.right.ventral.dcdktregions
T1Hier_vol_left_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
t1.vol.left.caudal.ant.cingulate.ctx
T1Hier_vol_left_caudal_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
t1.vol.left.caudal.middle.frontal.ctx
T1Hier_vol_left_cuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cuneus
t1.vol.left.cuneus.ctx
T1Hier_vol_left_entorhinaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
entorhinal
t1.vol.left.entorhinal.ctx
T1Hier_vol_left_fusiformdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
fusiform
t1.vol.left.fusiform.ctx
T1Hier_vol_left_inferior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior parietal
t1.vol.left.inf.parietal.ctx
T1Hier_vol_left_inferior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior temporal
t1.vol.left.inf.temporal.ctx
T1Hier_vol_left_insuladktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
insula
t1.vol.left.insula.ctx
T1Hier_vol_left_isthmus_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
t1.vol.left.isthmus.cingulate.ctx
T1Hier_vol_left_lateral_occipitaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral occipital
t1.vol.left.lateral.occipital.ctx
T1Hier_vol_left_lateral_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
t1.vol.left.lateral.orbitofrontal.ctx
T1Hier_vol_left_lingualdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lingual
t1.vol.left.lingual.ctx
T1Hier_vol_left_medial_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
t1.vol.left.medial.orbitofrontal.ctx
T1Hier_vol_left_middle_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
middle temporal
t1.vol.left.middle.temporal.ctx
T1Hier_vol_left_paracentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
paracentral
t1.vol.left.paracent.ctx
T1Hier_vol_left_parahippocampaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.left.parahippocampal.ctx
T1Hier_vol_left_pars_opercularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars opercularis
t1.vol.left.pars.opercularis.ctx
T1Hier_vol_left_pars_orbitalisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
t1.vol.left.pars.orbitalis.ctx
T1Hier_vol_left_pars_triangularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars triangularis
t1.vol.left.pars.triangularis.ctx
T1Hier_vol_left_pericalcarinedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pericalcarine
t1.vol.left.pericalcarine.ctx
T1Hier_vol_left_postcentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
postcentral
t1.vol.left.postcent.ctx
T1Hier_vol_left_posterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
t1.vol.left.post.cingulate.ctx
T1Hier_vol_left_precentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precentral
t1.vol.left.precent.ctx
T1Hier_vol_left_precuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precuneus
t1.vol.left.precuneus.ctx
T1Hier_vol_left_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
t1.vol.left.rostral.ant.cingulate.ctx
T1Hier_vol_left_rostral_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
t1.vol.left.rostral.middle.frontal.ctx
T1Hier_vol_left_superior_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior frontal
t1.vol.left.sup.frontal.ctx
T1Hier_vol_left_superior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior parietal
t1.vol.left.sup.parietal.ctx
T1Hier_vol_left_superior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior temporal
t1.vol.left.sup.temporal.ctx
T1Hier_vol_left_supramarginaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
supramarginal
t1.vol.left.supramarginal.ctx
T1Hier_vol_left_transverse_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
transverse temporal
t1.vol.left.transverse.temporal.ctx
T1Hier_vol_right_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
t1.vol.right.caudal.ant.cingulate.ctx
T1Hier_vol_right_caudal_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
t1.vol.right.caudal.middle.frontal.ctx
T1Hier_vol_right_cuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cuneus
t1.vol.right.cuneus.ctx
T1Hier_vol_right_entorhinaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
entorhinal
t1.vol.right.entorhinal.ctx
T1Hier_vol_right_fusiformdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
fusiform
t1.vol.right.fusiform.ctx
T1Hier_vol_right_inferior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior parietal
t1.vol.right.inf.parietal.ctx
T1Hier_vol_right_inferior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior temporal
t1.vol.right.inf.temporal.ctx
T1Hier_vol_right_insuladktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
insula
t1.vol.right.insula.ctx
T1Hier_vol_right_isthmus_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
t1.vol.right.isthmus.cingulate.ctx
T1Hier_vol_right_lateral_occipitaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral occipital
t1.vol.right.lateral.occipital.ctx
T1Hier_vol_right_lateral_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
t1.vol.right.lateral.orbitofrontal.ctx
T1Hier_vol_right_lingualdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lingual
t1.vol.right.lingual.ctx
T1Hier_vol_right_medial_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
t1.vol.right.medial.orbitofrontal.ctx
T1Hier_vol_right_middle_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
middle temporal
t1.vol.right.middle.temporal.ctx
T1Hier_vol_right_paracentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
paracentral
t1.vol.right.paracent.ctx
T1Hier_vol_right_parahippocampaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.right.parahippocampal.ctx
T1Hier_vol_right_pars_opercularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars opercularis
t1.vol.right.pars.opercularis.ctx
T1Hier_vol_right_pars_orbitalisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
t1.vol.right.pars.orbitalis.ctx
T1Hier_vol_right_pars_triangularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars triangularis
t1.vol.right.pars.triangularis.ctx
T1Hier_vol_right_pericalcarinedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pericalcarine
t1.vol.right.pericalcarine.ctx
T1Hier_vol_right_postcentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
postcentral
t1.vol.right.postcent.ctx
T1Hier_vol_right_posterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
t1.vol.right.post.cingulate.ctx
T1Hier_vol_right_precentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precentral
t1.vol.right.precent.ctx
T1Hier_vol_right_precuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precuneus
t1.vol.right.precuneus.ctx
T1Hier_vol_right_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
t1.vol.right.rostral.ant.cingulate.ctx
T1Hier_vol_right_rostral_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
t1.vol.right.rostral.middle.frontal.ctx
T1Hier_vol_right_superior_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior frontal
t1.vol.right.sup.frontal.ctx
T1Hier_vol_right_superior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior parietal
t1.vol.right.sup.parietal.ctx
T1Hier_vol_right_superior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior temporal
t1.vol.right.sup.temporal.ctx
T1Hier_vol_right_supramarginaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
supramarginal
t1.vol.right.supramarginal.ctx
T1Hier_vol_right_transverse_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
transverse temporal
t1.vol.right.transverse.temporal.ctx
T1Hier_area_left_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
t1.area.left.caudal.ant.cingulate.ctx
T1Hier_area_left_caudal_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal middle frontal
t1.area.left.caudal.middle.frontal.ctx
T1Hier_area_left_cuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cuneus
t1.area.left.cuneus.ctx
T1Hier_area_left_entorhinaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
entorhinal
t1.area.left.entorhinal.ctx
T1Hier_area_left_fusiformdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
fusiform
t1.area.left.fusiform.ctx
T1Hier_area_left_inferior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior parietal
t1.area.left.inf.parietal.ctx
T1Hier_area_left_inferior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior temporal
t1.area.left.inf.temporal.ctx
T1Hier_area_left_insuladktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
insula
t1.area.left.insula.ctx
T1Hier_area_left_isthmus_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
isthmus cingulate
t1.area.left.isthmus.cingulate.ctx
T1Hier_area_left_lateral_occipitaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral occipital
t1.area.left.lateral.occipital.ctx
T1Hier_area_left_lateral_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
t1.area.left.lateral.orbitofrontal.ctx
T1Hier_area_left_lingualdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lingual
t1.area.left.lingual.ctx
T1Hier_area_left_medial_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
medial orbitofrontal
t1.area.left.medial.orbitofrontal.ctx
T1Hier_area_left_middle_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
middle temporal
t1.area.left.middle.temporal.ctx
T1Hier_area_left_paracentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
paracentral
t1.area.left.paracent.ctx
T1Hier_area_left_parahippocampaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.left.parahippocampal.ctx
T1Hier_area_left_pars_opercularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars opercularis
t1.area.left.pars.opercularis.ctx
T1Hier_area_left_pars_orbitalisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars orbitalis
t1.area.left.pars.orbitalis.ctx
T1Hier_area_left_pars_triangularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars triangularis
t1.area.left.pars.triangularis.ctx
T1Hier_area_left_pericalcarinedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pericalcarine
t1.area.left.pericalcarine.ctx
T1Hier_area_left_postcentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
postcentral
t1.area.left.postcent.ctx
T1Hier_area_left_posterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
posterior cingulate
t1.area.left.post.cingulate.ctx
T1Hier_area_left_precentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precentral
t1.area.left.precent.ctx
T1Hier_area_left_precuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precuneus
t1.area.left.precuneus.ctx
T1Hier_area_left_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
t1.area.left.rostral.ant.cingulate.ctx
T1Hier_area_left_rostral_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral middle frontal
t1.area.left.rostral.middle.frontal.ctx
T1Hier_area_left_superior_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior frontal
t1.area.left.sup.frontal.ctx
T1Hier_area_left_superior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior parietal
t1.area.left.sup.parietal.ctx
T1Hier_area_left_superior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior temporal
t1.area.left.sup.temporal.ctx
T1Hier_area_left_supramarginaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
supramarginal
t1.area.left.supramarginal.ctx
T1Hier_area_left_transverse_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
transverse temporal
t1.area.left.transverse.temporal.ctx
T1Hier_area_right_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
t1.area.right.caudal.ant.cingulate.ctx
T1Hier_area_right_caudal_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal middle frontal
t1.area.right.caudal.middle.frontal.ctx
T1Hier_area_right_cuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cuneus
t1.area.right.cuneus.ctx
T1Hier_area_right_entorhinaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
entorhinal
t1.area.right.entorhinal.ctx
T1Hier_area_right_fusiformdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
fusiform
t1.area.right.fusiform.ctx
T1Hier_area_right_inferior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior parietal
t1.area.right.inf.parietal.ctx
T1Hier_area_right_inferior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior temporal
t1.area.right.inf.temporal.ctx
T1Hier_area_right_insuladktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
insula
t1.area.right.insula.ctx
T1Hier_area_right_isthmus_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
isthmus cingulate
t1.area.right.isthmus.cingulate.ctx
T1Hier_area_right_lateral_occipitaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral occipital
t1.area.right.lateral.occipital.ctx
T1Hier_area_right_lateral_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
t1.area.right.lateral.orbitofrontal.ctx
T1Hier_area_right_lingualdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lingual
t1.area.right.lingual.ctx
T1Hier_area_right_medial_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
medial orbitofrontal
t1.area.right.medial.orbitofrontal.ctx
T1Hier_area_right_middle_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
middle temporal
t1.area.right.middle.temporal.ctx
T1Hier_area_right_paracentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
paracentral
t1.area.right.paracent.ctx
T1Hier_area_right_parahippocampaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.right.parahippocampal.ctx
T1Hier_area_right_pars_opercularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars opercularis
t1.area.right.pars.opercularis.ctx
T1Hier_area_right_pars_orbitalisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars orbitalis
t1.area.right.pars.orbitalis.ctx
T1Hier_area_right_pars_triangularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars triangularis
t1.area.right.pars.triangularis.ctx
T1Hier_area_right_pericalcarinedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pericalcarine
t1.area.right.pericalcarine.ctx
T1Hier_area_right_postcentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
postcentral
t1.area.right.postcent.ctx
T1Hier_area_right_posterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
posterior cingulate
t1.area.right.post.cingulate.ctx
T1Hier_area_right_precentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precentral
t1.area.right.precent.ctx
T1Hier_area_right_precuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precuneus
t1.area.right.precuneus.ctx
T1Hier_area_right_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
t1.area.right.rostral.ant.cingulate.ctx
T1Hier_area_right_rostral_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral middle frontal
t1.area.right.rostral.middle.frontal.ctx
T1Hier_area_right_superior_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior frontal
t1.area.right.sup.frontal.ctx
T1Hier_area_right_superior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior parietal
t1.area.right.sup.parietal.ctx
T1Hier_area_right_superior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior temporal
t1.area.right.sup.temporal.ctx
T1Hier_area_right_supramarginaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
supramarginal
t1.area.right.supramarginal.ctx
T1Hier_area_right_transverse_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
transverse temporal
t1.area.right.transverse.temporal.ctx
T1Hier_thk_left_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
t1.thk.left.caudal.ant.cingulate.ctx
T1Hier_thk_left_caudal_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
t1.thk.left.caudal.middle.frontal.ctx
T1Hier_thk_left_cuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cuneus
t1.thk.left.cuneus.ctx
T1Hier_thk_left_entorhinaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
entorhinal
t1.thk.left.entorhinal.ctx
T1Hier_thk_left_fusiformdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
fusiform
t1.thk.left.fusiform.ctx
T1Hier_thk_left_inferior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior parietal
t1.thk.left.inf.parietal.ctx
T1Hier_thk_left_inferior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior temporal
t1.thk.left.inf.temporal.ctx
T1Hier_thk_left_insuladktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
insula
t1.thk.left.insula.ctx
T1Hier_thk_left_isthmus_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
t1.thk.left.isthmus.cingulate.ctx
T1Hier_thk_left_lateral_occipitaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral occipital
t1.thk.left.lateral.occipital.ctx
T1Hier_thk_left_lateral_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
t1.thk.left.lateral.orbitofrontal.ctx
T1Hier_thk_left_lingualdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lingual
t1.thk.left.lingual.ctx
T1Hier_thk_left_medial_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
t1.thk.left.medial.orbitofrontal.ctx
T1Hier_thk_left_middle_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
middle temporal
t1.thk.left.middle.temporal.ctx
T1Hier_thk_left_paracentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
paracentral
t1.thk.left.paracent.ctx
T1Hier_thk_left_parahippocampaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.left.parahippocampal.ctx
T1Hier_thk_left_pars_opercularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars opercularis
t1.thk.left.pars.opercularis.ctx
T1Hier_thk_left_pars_orbitalisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars orbitalis
t1.thk.left.pars.orbitalis.ctx
T1Hier_thk_left_pars_triangularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars triangularis
t1.thk.left.pars.triangularis.ctx
T1Hier_thk_left_pericalcarinedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pericalcarine
t1.thk.left.pericalcarine.ctx
T1Hier_thk_left_postcentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
postcentral
t1.thk.left.postcent.ctx
T1Hier_thk_left_posterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
posterior cingulate
t1.thk.left.post.cingulate.ctx
T1Hier_thk_left_precentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precentral
t1.thk.left.precent.ctx
T1Hier_thk_left_precuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precuneus
t1.thk.left.precuneus.ctx
T1Hier_thk_left_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
t1.thk.left.rostral.ant.cingulate.ctx
T1Hier_thk_left_rostral_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
t1.thk.left.rostral.middle.frontal.ctx
T1Hier_thk_left_superior_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior frontal
t1.thk.left.sup.frontal.ctx
T1Hier_thk_left_superior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior parietal
t1.thk.left.sup.parietal.ctx
T1Hier_thk_left_superior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior temporal
t1.thk.left.sup.temporal.ctx
T1Hier_thk_left_supramarginaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
supramarginal
t1.thk.left.supramarginal.ctx
T1Hier_thk_left_transverse_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
transverse temporal
t1.thk.left.transverse.temporal.ctx
T1Hier_thk_right_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
t1.thk.right.caudal.ant.cingulate.ctx
T1Hier_thk_right_caudal_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
t1.thk.right.caudal.middle.frontal.ctx
T1Hier_thk_right_cuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cuneus
t1.thk.right.cuneus.ctx
T1Hier_thk_right_entorhinaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
entorhinal
t1.thk.right.entorhinal.ctx
T1Hier_thk_right_fusiformdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
fusiform
t1.thk.right.fusiform.ctx
T1Hier_thk_right_inferior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior parietal
t1.thk.right.inf.parietal.ctx
T1Hier_thk_right_inferior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior temporal
t1.thk.right.inf.temporal.ctx
T1Hier_thk_right_insuladktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
insula
t1.thk.right.insula.ctx
T1Hier_thk_right_isthmus_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
t1.thk.right.isthmus.cingulate.ctx
T1Hier_thk_right_lateral_occipitaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral occipital
t1.thk.right.lateral.occipital.ctx
T1Hier_thk_right_lateral_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
t1.thk.right.lateral.orbitofrontal.ctx
T1Hier_thk_right_lingualdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lingual
t1.thk.right.lingual.ctx
T1Hier_thk_right_medial_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
t1.thk.right.medial.orbitofrontal.ctx
T1Hier_thk_right_middle_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
middle temporal
t1.thk.right.middle.temporal.ctx
T1Hier_thk_right_paracentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
paracentral
t1.thk.right.paracent.ctx
T1Hier_thk_right_parahippocampaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.right.parahippocampal.ctx
T1Hier_thk_right_pars_opercularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars opercularis
t1.thk.right.pars.opercularis.ctx
T1Hier_thk_right_pars_orbitalisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars orbitalis
t1.thk.right.pars.orbitalis.ctx
T1Hier_thk_right_pars_triangularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars triangularis
t1.thk.right.pars.triangularis.ctx
T1Hier_thk_right_pericalcarinedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pericalcarine
t1.thk.right.pericalcarine.ctx
T1Hier_thk_right_postcentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
postcentral
t1.thk.right.postcent.ctx
T1Hier_thk_right_posterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
posterior cingulate
t1.thk.right.post.cingulate.ctx
T1Hier_thk_right_precentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precentral
t1.thk.right.precent.ctx
T1Hier_thk_right_precuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precuneus
t1.thk.right.precuneus.ctx
T1Hier_thk_right_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
t1.thk.right.rostral.ant.cingulate.ctx
T1Hier_thk_right_rostral_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
t1.thk.right.rostral.middle.frontal.ctx
T1Hier_thk_right_superior_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior frontal
t1.thk.right.sup.frontal.ctx
T1Hier_thk_right_superior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior parietal
t1.thk.right.sup.parietal.ctx
T1Hier_thk_right_superior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior temporal
t1.thk.right.sup.temporal.ctx
T1Hier_thk_right_supramarginaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
supramarginal
t1.thk.right.supramarginal.ctx
T1Hier_thk_right_transverse_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
transverse temporal
t1.thk.right.transverse.temporal.ctx
T1Hier_vol_left_ca1mtl
T1 hierarchical processing
left
MTL
geometry/volume
volca1mtl
t1.vol.left.ca1mtl
T1Hier_vol_left_dg.ca3mtl
T1 hierarchical processing
left
MTL
geometry/volume
voldg ca3mtl
t1.vol.left.dg.ca3mtl
T1Hier_vol_left_alecmtl
T1 hierarchical processing
left
MTL
geometry/volume
volalecmtl
t1.vol.left.alecmtl
T1Hier_vol_left_pmecmtl
T1 hierarchical processing
left
MTL
geometry/volume
volpmecmtl
t1.vol.left.pmecmtl
T1Hier_vol_left_parahippocampalmtl
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.left.parahippocampalmtl
T1Hier_vol_left_perirhinalmtl
T1 hierarchical processing
left
MTL
geometry/volume
volperirhinalmtl
t1.vol.left.perirhinalmtl
T1Hier_vol_left_subiculummtl
T1 hierarchical processing
left
MTL
geometry/volume
volsubiculummtl
t1.vol.left.subiculummtl
T1Hier_vol_right_ca1mtl
T1 hierarchical processing
right
MTL
geometry/volume
volca1mtl
t1.vol.right.ca1mtl
T1Hier_vol_right_dg.ca3mtl
T1 hierarchical processing
right
MTL
geometry/volume
voldg ca3mtl
t1.vol.right.dg.ca3mtl
T1Hier_vol_right_alecmtl
T1 hierarchical processing
right
MTL
geometry/volume
volalecmtl
t1.vol.right.alecmtl
T1Hier_vol_right_pmecmtl
T1 hierarchical processing
right
MTL
geometry/volume
volpmecmtl
t1.vol.right.pmecmtl
T1Hier_vol_right_parahippocampalmtl
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
parahippocampal
t1.vol.right.parahippocampalmtl
T1Hier_vol_right_perirhinalmtl
T1 hierarchical processing
right
MTL
geometry/volume
volperirhinalmtl
t1.vol.right.perirhinalmtl
T1Hier_vol_right_subiculummtl
T1 hierarchical processing
right
MTL
geometry/volume
volsubiculummtl
t1.vol.right.subiculummtl
T1Hier_area_left_ca1mtl
T1 hierarchical processing
left
MTL
geometry/area
ca1mtl
t1.area.left.ca1mtl
T1Hier_area_left_dg.ca3mtl
T1 hierarchical processing
left
MTL
geometry/area
dg ca3mtl
t1.area.left.dg.ca3mtl
T1Hier_area_left_alecmtl
T1 hierarchical processing
left
MTL
geometry/area
alecmtl
t1.area.left.alecmtl
T1Hier_area_left_pmecmtl
T1 hierarchical processing
left
MTL
geometry/area
pmecmtl
t1.area.left.pmecmtl
T1Hier_area_left_parahippocampalmtl
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.left.parahippocampalmtl
T1Hier_area_left_perirhinalmtl
T1 hierarchical processing
left
MTL
geometry/area
perirhinalmtl
t1.area.left.perirhinalmtl
T1Hier_area_left_subiculummtl
T1 hierarchical processing
left
MTL
geometry/area
subiculummtl
t1.area.left.subiculummtl
T1Hier_area_right_ca1mtl
T1 hierarchical processing
right
MTL
geometry/area
ca1mtl
t1.area.right.ca1mtl
T1Hier_area_right_dg.ca3mtl
T1 hierarchical processing
right
MTL
geometry/area
dg ca3mtl
t1.area.right.dg.ca3mtl
T1Hier_area_right_alecmtl
T1 hierarchical processing
right
MTL
geometry/area
alecmtl
t1.area.right.alecmtl
T1Hier_area_right_pmecmtl
T1 hierarchical processing
right
MTL
geometry/area
pmecmtl
t1.area.right.pmecmtl
T1Hier_area_right_parahippocampalmtl
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
parahippocampal
t1.area.right.parahippocampalmtl
T1Hier_area_right_perirhinalmtl
T1 hierarchical processing
right
MTL
geometry/area
perirhinalmtl
t1.area.right.perirhinalmtl
T1Hier_area_right_subiculummtl
T1 hierarchical processing
right
MTL
geometry/area
subiculummtl
t1.area.right.subiculummtl
T1Hier_thk_left_ca1mtl
T1 hierarchical processing
left
MTL
geometry/thickness
ca1mtl
t1.thk.left.ca1mtl
T1Hier_thk_left_dg.ca3mtl
T1 hierarchical processing
left
MTL
geometry/thickness
dg ca3mtl
t1.thk.left.dg.ca3mtl
T1Hier_thk_left_alecmtl
T1 hierarchical processing
left
MTL
geometry/thickness
alecmtl
t1.thk.left.alecmtl
T1Hier_thk_left_pmecmtl
T1 hierarchical processing
left
MTL
geometry/thickness
pmecmtl
t1.thk.left.pmecmtl
T1Hier_thk_left_parahippocampalmtl
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.left.parahippocampalmtl
T1Hier_thk_left_perirhinalmtl
T1 hierarchical processing
left
MTL
geometry/thickness
perirhinalmtl
t1.thk.left.perirhinalmtl
T1Hier_thk_left_subiculummtl
T1 hierarchical processing
left
MTL
geometry/thickness
subiculummtl
t1.thk.left.subiculummtl
T1Hier_thk_right_ca1mtl
T1 hierarchical processing
right
MTL
geometry/thickness
ca1mtl
t1.thk.right.ca1mtl
T1Hier_thk_right_dg.ca3mtl
T1 hierarchical processing
right
MTL
geometry/thickness
dg ca3mtl
t1.thk.right.dg.ca3mtl
T1Hier_thk_right_alecmtl
T1 hierarchical processing
right
MTL
geometry/thickness
alecmtl
t1.thk.right.alecmtl
T1Hier_thk_right_pmecmtl
T1 hierarchical processing
right
MTL
geometry/thickness
pmecmtl
t1.thk.right.pmecmtl
T1Hier_thk_right_parahippocampalmtl
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
parahippocampal
t1.thk.right.parahippocampalmtl
T1Hier_thk_right_perirhinalmtl
T1 hierarchical processing
right
MTL
geometry/thickness
perirhinalmtl
t1.thk.right.perirhinalmtl
T1Hier_thk_right_subiculummtl
T1 hierarchical processing
right
MTL
geometry/thickness
subiculummtl
t1.thk.right.subiculummtl
T1Hier_vol_ch13_leftbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus ch1 to ch3
t1.vol.ch13.leftbf
T1Hier_vol_ch13_rightbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus ch1 to ch3
t1.vol.ch13.rightbf
T1Hier_vol_nbm_left_antbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus anterior ch4
t1.vol.nbm.left.antbf
T1Hier_vol_nbm_left_midbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus middle ch4
t1.vol.nbm.left.midbf
T1Hier_vol_nbm_left_posbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus posterior ch4
t1.vol.nbm.left.posbf
T1Hier_vol_nbm_right_antbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus anterior ch4
t1.vol.nbm.right.antbf
T1Hier_vol_nbm_right_midbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus middle ch4
t1.vol.nbm.right.midbf
T1Hier_vol_nbm_right_posbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus posterior ch4
t1.vol.nbm.right.posbf
T1Hier_area_ch13_leftbf
T1 hierarchical processing
left
BF
geometry/area
ch13 bf
t1.area.ch13.leftbf
T1Hier_area_ch13_rightbf
T1 hierarchical processing
right
BF
geometry/area
ch13 bf
t1.area.ch13.rightbf
T1Hier_area_nbm_left_antbf
T1 hierarchical processing
left
BF
geometry/area
basal nucleus anterior ch4
t1.area.nbm.left.antbf
T1Hier_area_nbm_left_midbf
T1 hierarchical processing
left
BF
geometry/area
basal nucleus middle ch4
t1.area.nbm.left.midbf
T1Hier_area_nbm_left_posbf
T1 hierarchical processing
left
BF
geometry/area
basal nucleus posterior ch4
t1.area.nbm.left.posbf
T1Hier_area_nbm_right_antbf
T1 hierarchical processing
right
BF
geometry/area
basal nucleus anterior ch4
t1.area.nbm.right.antbf
T1Hier_area_nbm_right_midbf
T1 hierarchical processing
right
BF
geometry/area
basal nucleus middle ch4
t1.area.nbm.right.midbf
T1Hier_area_nbm_right_posbf
T1 hierarchical processing
right
BF
geometry/area
basal nucleus posterior ch4
t1.area.nbm.right.posbf
T1Hier_thk_ch13_leftbf
T1 hierarchical processing
left
BF
geometry/thickness
ch13 bf
t1.thk.ch13.leftbf
T1Hier_thk_ch13_rightbf
T1 hierarchical processing
right
BF
geometry/thickness
ch13 bf
t1.thk.ch13.rightbf
T1Hier_thk_nbm_left_antbf
T1 hierarchical processing
left
BF
geometry/thickness
basal nucleus anterior ch4
t1.thk.nbm.left.antbf
T1Hier_thk_nbm_left_midbf
T1 hierarchical processing
left
BF
geometry/thickness
basal nucleus middle ch4
t1.thk.nbm.left.midbf
T1Hier_thk_nbm_left_posbf
T1 hierarchical processing
left
BF
geometry/thickness
basal nucleus posterior ch4
t1.thk.nbm.left.posbf
T1Hier_thk_nbm_right_antbf
T1 hierarchical processing
right
BF
geometry/thickness
basal nucleus anterior ch4
t1.thk.nbm.right.antbf
T1Hier_thk_nbm_right_midbf
T1 hierarchical processing
right
BF
geometry/thickness
basal nucleus middle ch4
t1.thk.nbm.right.midbf
T1Hier_thk_nbm_right_posbf
T1 hierarchical processing
right
BF
geometry/thickness
basal nucleus posterior ch4
t1.thk.nbm.right.posbf
T1Hier_vol_bn_gp_gpe_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus externa
t1.vol.bn.gp.gpe.left
T1Hier_vol_bn_gp_gpe_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus externa
t1.vol.bn.gp.gpe.right
T1Hier_vol_bn_gp_gpi_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus interna
t1.vol.bn.gp.gpi.left
T1Hier_vol_bn_gp_gpi_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus interna
t1.vol.bn.gp.gpi.right
T1Hier_vol_bn_gp_vep_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
ventral pallidum
t1.vol.bn.gp.vep.left
T1Hier_vol_bn_gp_vep_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
ventral pallidum
t1.vol.bn.gp.vep.right
T1Hier_vol_bn_str_ca_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
caudate
t1.vol.bn.str.ca.left
T1Hier_vol_bn_str_ca_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
caudate
t1.vol.bn.str.ca.right
T1Hier_vol_bn_str_nac_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Nucleus Accumbens
t1.vol.bn.str.nac.left
T1Hier_vol_bn_str_nac_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Nucleus Accumbens
t1.vol.bn.str.nac.right
T1Hier_vol_bn_str_pu_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
putamen
t1.vol.bn.str.pu.left
T1Hier_vol_bn_str_pu_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
putamen
t1.vol.bn.str.pu.right
T1Hier_vol_die_hth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Hypothalamus
t1.vol.die.hth.left
T1Hier_vol_die_hth_mn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
mammillary nucleus
t1.vol.die.hth.mn.left
T1Hier_vol_die_hth_mn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
mammillary nucleus
t1.vol.die.hth.mn.right
T1Hier_vol_die_hth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Hypothalamus
t1.vol.die.hth.right
T1Hier_vol_die_sth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Subthalamic Nucleus
t1.vol.die.sth.left
T1Hier_vol_die_sth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Subthalamic Nucleus
t1.vol.die.sth.right
T1Hier_vol_exa_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
extended amygdala
t1.vol.exa.left
T1Hier_vol_exa_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
extended amygdala
t1.vol.exa.right
T1Hier_vol_mtg_rn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
red nucleus
t1.vol.mtg.rn.left
T1Hier_vol_mtg_rn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
red nucleus
t1.vol.mtg.rn.right
T1Hier_vol_mtg_sn_snc_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.left
T1Hier_vol_mtg_sn_snc_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.right
T1Hier_vol_mtg_sn_snr_leftcit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.left
T1Hier_vol_mtg_sn_snr_rightcit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.right
T1Hier_vol_mtg_vtr_pbp_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
t1.vol.mtg.vtr.pbp.left
T1Hier_vol_mtg_vtr_pbp_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
t1.vol.mtg.vtr.pbp.right
T1Hier_vol_mtg_vtr_vta_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Ventral Tegmental Area
t1.vol.mtg.vtr.vta.left
T1Hier_vol_mtg_vtr_vta_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Ventral Tegmental Area
t1.vol.mtg.vtr.vta.right
T1Hier_vol_referenceregion_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
​
t1.vol.referenceregion.left
T1Hier_vol_referenceregion_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
​
t1.vol.referenceregion.right
T1Hier_vol_thm_eth_hn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Habenular Nuclei
t1.vol.thm.eth.hn.left
T1Hier_vol_thm_eth_hn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Habenular Nuclei
t1.vol.thm.eth.hn.right
T1Hier_area_bn_gp_gpe_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus externa
t1.area.bn.gp.gpe.left
T1Hier_area_bn_gp_gpe_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus externa
t1.area.bn.gp.gpe.right
T1Hier_area_bn_gp_gpi_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus interna
t1.area.bn.gp.gpi.left
T1Hier_area_bn_gp_gpi_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus interna
t1.area.bn.gp.gpi.right
T1Hier_area_bn_gp_vep_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
ventral pallidum
t1.area.bn.gp.vep.left
T1Hier_area_bn_gp_vep_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
ventral pallidum
t1.area.bn.gp.vep.right
T1Hier_area_bn_str_ca_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
caudate
t1.area.bn.str.ca.left
T1Hier_area_bn_str_ca_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
caudate
t1.area.bn.str.ca.right
T1Hier_area_bn_str_nac_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Nucleus Accumbens
t1.area.bn.str.nac.left
T1Hier_area_bn_str_nac_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Nucleus Accumbens
t1.area.bn.str.nac.right
T1Hier_area_bn_str_pu_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
putamen
t1.area.bn.str.pu.left
T1Hier_area_bn_str_pu_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
putamen
t1.area.bn.str.pu.right
T1Hier_area_die_hth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Hypothalamus
t1.area.die.hth.left
T1Hier_area_die_hth_mn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
mammillary nucleus
t1.area.die.hth.mn.left
T1Hier_area_die_hth_mn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
mammillary nucleus
t1.area.die.hth.mn.right
T1Hier_area_die_hth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Hypothalamus
t1.area.die.hth.right
T1Hier_area_die_sth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Subthalamic Nucleus
t1.area.die.sth.left
T1Hier_area_die_sth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Subthalamic Nucleus
t1.area.die.sth.right
T1Hier_area_exa_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
extended amygdala
t1.area.exa.left
T1Hier_area_exa_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
extended amygdala
t1.area.exa.right
T1Hier_area_mtg_rn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
red nucleus
t1.area.mtg.rn.left
T1Hier_area_mtg_rn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
red nucleus
t1.area.mtg.rn.right
T1Hier_area_mtg_sn_snc_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.left
T1Hier_area_mtg_sn_snc_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.right
T1Hier_area_mtg_sn_snr_leftcit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.left
T1Hier_area_mtg_sn_snr_rightcit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.right
T1Hier_area_mtg_vtr_pbp_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Parabrachial Pigmented Nucleus
t1.area.mtg.vtr.pbp.left
T1Hier_area_mtg_vtr_pbp_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Parabrachial Pigmented Nucleus
t1.area.mtg.vtr.pbp.right
T1Hier_area_mtg_vtr_vta_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Ventral Tegmental Area
t1.area.mtg.vtr.vta.left
T1Hier_area_mtg_vtr_vta_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Ventral Tegmental Area
t1.area.mtg.vtr.vta.right
T1Hier_area_referenceregion_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
​
t1.area.referenceregion.left
T1Hier_area_referenceregion_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
​
t1.area.referenceregion.right
T1Hier_area_thm_eth_hn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Habenular Nuclei
t1.area.thm.eth.hn.left
T1Hier_area_thm_eth_hn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Habenular Nuclei
t1.area.thm.eth.hn.right
T1Hier_thk_bn_gp_gpe_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus externa
t1.thk.bn.gp.gpe.left
T1Hier_thk_bn_gp_gpe_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus externa
t1.thk.bn.gp.gpe.right
T1Hier_thk_bn_gp_gpi_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus interna
t1.thk.bn.gp.gpi.left
T1Hier_thk_bn_gp_gpi_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus interna
t1.thk.bn.gp.gpi.right
T1Hier_thk_bn_gp_vep_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
ventral pallidum
t1.thk.bn.gp.vep.left
T1Hier_thk_bn_gp_vep_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
ventral pallidum
t1.thk.bn.gp.vep.right
T1Hier_thk_bn_str_ca_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
caudate
t1.thk.bn.str.ca.left
T1Hier_thk_bn_str_ca_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
caudate
t1.thk.bn.str.ca.right
T1Hier_thk_bn_str_nac_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Nucleus Accumbens
t1.thk.bn.str.nac.left
T1Hier_thk_bn_str_nac_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Nucleus Accumbens
t1.thk.bn.str.nac.right
T1Hier_thk_bn_str_pu_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
putamen
t1.thk.bn.str.pu.left
T1Hier_thk_bn_str_pu_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
putamen
t1.thk.bn.str.pu.right
T1Hier_thk_die_hth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Hypothalamus
t1.thk.die.hth.left
T1Hier_thk_die_hth_mn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
mammillary nucleus
t1.thk.die.hth.mn.left
T1Hier_thk_die_hth_mn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
mammillary nucleus
t1.thk.die.hth.mn.right
T1Hier_thk_die_hth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Hypothalamus
t1.thk.die.hth.right
T1Hier_thk_die_sth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Subthalamic Nucleus
t1.thk.die.sth.left
T1Hier_thk_die_sth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Subthalamic Nucleus
t1.thk.die.sth.right
T1Hier_thk_exa_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
extended amygdala
t1.thk.exa.left
T1Hier_thk_exa_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
extended amygdala
t1.thk.exa.right
T1Hier_thk_mtg_rn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
red nucleus
t1.thk.mtg.rn.left
T1Hier_thk_mtg_rn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
red nucleus
t1.thk.mtg.rn.right
T1Hier_thk_mtg_sn_snc_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.left
T1Hier_thk_mtg_sn_snc_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.right
T1Hier_thk_mtg_sn_snr_leftcit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.left
T1Hier_thk_mtg_sn_snr_rightcit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.right
T1Hier_thk_mtg_vtr_pbp_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Parabrachial Pigmented Nucleus
t1.thk.mtg.vtr.pbp.left
T1Hier_thk_mtg_vtr_pbp_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Parabrachial Pigmented Nucleus
t1.thk.mtg.vtr.pbp.right
T1Hier_thk_mtg_vtr_vta_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Ventral Tegmental Area
t1.thk.mtg.vtr.vta.left
T1Hier_thk_mtg_vtr_vta_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Ventral Tegmental Area
t1.thk.mtg.vtr.vta.right
T1Hier_thk_referenceregion_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
​
t1.thk.referenceregion.left
T1Hier_thk_referenceregion_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
​
t1.thk.referenceregion.right
T1Hier_thk_thm_eth_hn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Habenular Nuclei
t1.thk.thm.eth.hn.left
T1Hier_thk_thm_eth_hn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Habenular Nuclei
t1.thk.thm.eth.hn.right
T1Hier_vol_bn_gp_gpe_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus externa
t1.vol.bn.gp.gpe.leftdp.
T1Hier_vol_bn_gp_gpe_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus externa
t1.vol.bn.gp.gpe.rightdp.
T1Hier_vol_bn_gp_gpi_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus interna
t1.vol.bn.gp.gpi.leftdp.
T1Hier_vol_bn_gp_gpi_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus interna
t1.vol.bn.gp.gpi.rightdp.
T1Hier_vol_bn_str_ca_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
caudate
t1.vol.bn.str.ca.leftdp.
T1Hier_vol_bn_str_ca_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
caudate
t1.vol.bn.str.ca.rightdp.
T1Hier_vol_bn_str_pu_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
putamen
t1.vol.bn.str.pu.leftdp.
T1Hier_vol_bn_str_pu_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
putamen
t1.vol.bn.str.pu.rightdp.
T1Hier_vol_mtg_rn_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
red nucleus
t1.vol.mtg.rn.leftdp.
T1Hier_vol_mtg_rn_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
red nucleus
t1.vol.mtg.rn.rightdp.
T1Hier_vol_mtg_sn_snc_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.leftdp.
T1Hier_vol_mtg_sn_snc_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.rightdp.
T1Hier_vol_mtg_sn_snr_leftdeep_cit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.leftdp.
T1Hier_vol_mtg_sn_snr_rightdeep_cit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.rightdp.
T1Hier_vol_referenceregion_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
​
t1.vol.referenceregion.leftdp.
T1Hier_vol_referenceregion_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
​
t1.vol.referenceregion.rightdp.
T1Hier_area_bn_gp_gpe_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus externa
t1.area.bn.gp.gpe.leftdp.
T1Hier_area_bn_gp_gpe_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus externa
t1.area.bn.gp.gpe.rightdp.
T1Hier_area_bn_gp_gpi_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus interna
t1.area.bn.gp.gpi.leftdp.
T1Hier_area_bn_gp_gpi_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus interna
t1.area.bn.gp.gpi.rightdp.
T1Hier_area_bn_str_ca_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
caudate
t1.area.bn.str.ca.leftdp.
T1Hier_area_bn_str_ca_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
caudate
t1.area.bn.str.ca.rightdp.
T1Hier_area_bn_str_pu_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
putamen
t1.area.bn.str.pu.leftdp.
T1Hier_area_bn_str_pu_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
putamen
t1.area.bn.str.pu.rightdp.
T1Hier_area_mtg_rn_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
red nucleus
t1.area.mtg.rn.leftdp.
T1Hier_area_mtg_rn_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
red nucleus
t1.area.mtg.rn.rightdp.
T1Hier_area_mtg_sn_snc_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.leftdp.
T1Hier_area_mtg_sn_snc_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.rightdp.
T1Hier_area_mtg_sn_snr_leftdeep_cit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.leftdp.
T1Hier_area_mtg_sn_snr_rightdeep_cit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.rightdp.
T1Hier_area_referenceregion_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
​
t1.area.referenceregion.leftdp.
T1Hier_area_referenceregion_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
​
t1.area.referenceregion.rightdp.
T1Hier_thk_bn_gp_gpe_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus externa
t1.thk.bn.gp.gpe.leftdp.
T1Hier_thk_bn_gp_gpe_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus externa
t1.thk.bn.gp.gpe.rightdp.
T1Hier_thk_bn_gp_gpi_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus interna
t1.thk.bn.gp.gpi.leftdp.
T1Hier_thk_bn_gp_gpi_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus interna
t1.thk.bn.gp.gpi.rightdp.
T1Hier_thk_bn_str_ca_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
caudate
t1.thk.bn.str.ca.leftdp.
T1Hier_thk_bn_str_ca_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
caudate
t1.thk.bn.str.ca.rightdp.
T1Hier_thk_bn_str_pu_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
putamen
t1.thk.bn.str.pu.leftdp.
T1Hier_thk_bn_str_pu_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
putamen
t1.thk.bn.str.pu.rightdp.
T1Hier_thk_mtg_rn_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
red nucleus
t1.thk.mtg.rn.leftdp.
T1Hier_thk_mtg_rn_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
red nucleus
t1.thk.mtg.rn.rightdp.
T1Hier_thk_mtg_sn_snc_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.leftdp.
T1Hier_thk_mtg_sn_snc_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.rightdp.
T1Hier_thk_mtg_sn_snr_leftdeep_cit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.leftdp.
T1Hier_thk_mtg_sn_snr_rightdeep_cit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.rightdp.
T1Hier_thk_referenceregion_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
​
t1.thk.referenceregion.leftdp.
T1Hier_thk_referenceregion_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
​
t1.thk.referenceregion.rightdp.
T1Hier_vol_mtg_sn_snc_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.leftsnseg
T1Hier_vol_mtg_sn_snc_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/volume
Substantia Nigra pars compacta
t1.vol.snc.rightsnseg
T1Hier_vol_mtg_sn_snr_leftsnseg
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.leftsnseg
T1Hier_vol_mtg_sn_snr_rightsnseg
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.vol.snr.rightsnseg
T1Hier_vol_referenceregion_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/volume
​
t1.vol.referenceregion.leftsnseg
T1Hier_vol_referenceregion_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/volume
​
t1.vol.referenceregion.rightsnseg
T1Hier_area_mtg_sn_snc_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.leftsnseg
T1Hier_area_mtg_sn_snc_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/area
Substantia Nigra pars compacta
t1.area.snc.rightsnseg
T1Hier_area_mtg_sn_snr_leftsnseg
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.leftsnseg
T1Hier_area_mtg_sn_snr_rightsnseg
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.area.snr.rightsnseg
T1Hier_area_referenceregion_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/area
​
t1.area.referenceregion.leftsnseg
T1Hier_area_referenceregion_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/area
​
t1.area.referenceregion.rightsnseg
T1Hier_thk_mtg_sn_snc_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.leftsnseg
T1Hier_thk_mtg_sn_snc_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/thickness
Substantia Nigra pars compacta
t1.thk.snc.rightsnseg
T1Hier_thk_mtg_sn_snr_leftsnseg
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.leftsnseg
T1Hier_thk_mtg_sn_snr_rightsnseg
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
t1.thk.snr.rightsnseg
T1Hier_thk_referenceregion_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/thickness
​
t1.thk.referenceregion.leftsnseg
T1Hier_thk_referenceregion_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/thickness
​
t1.thk.referenceregion.rightsnseg
T1Hier_vol_cleanupbrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.cleanupbrainstem
T1Hier_vol_medullabrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.medullabrainstem
T1Hier_vol_midbrainbrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.midbrainbrainstem
T1Hier_vol_ponsbrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
t1.vol.ponsbrainstem
T1Hier_area_cleanupbrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.cleanupbrainstem
T1Hier_area_medullabrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.medullabrainstem
T1Hier_area_midbrainbrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.midbrainbrainstem
T1Hier_area_ponsbrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
t1.area.ponsbrainstem
T1Hier_thk_cleanupbrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.cleanupbrainstem
T1Hier_thk_medullabrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.medullabrainstem
T1Hier_thk_midbrainbrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.midbrainbrainstem
T1Hier_thk_ponsbrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
t1.thk.ponsbrainstem
T1Hier_vol_l_crus_icerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.crus.icerebellum
T1Hier_vol_l_crus_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.crus.iicerebellum
T1Hier_vol_l_iiicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.iiicerebellum
T1Hier_vol_l_ivcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.ivcerebellum
T1Hier_vol_l_ixcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.ixcerebellum
T1Hier_vol_l_i_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.i.iicerebellum
T1Hier_vol_l_vcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.vcerebellum
T1Hier_vol_l_vicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.vicerebellum
T1Hier_vol_l_viibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.viibcerebellum
T1Hier_vol_l_viiiacerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.viiiacerebellum
T1Hier_vol_l_viiibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.viiibcerebellum
T1Hier_vol_l_xcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.l.xcerebellum
T1Hier_vol_r_crus_icerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.crus.icerebellum
T1Hier_vol_r_crus_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.crus.iicerebellum
T1Hier_vol_r_iiicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.iiicerebellum
T1Hier_vol_r_ivcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.ivcerebellum
T1Hier_vol_r_ixcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.ixcerebellum
T1Hier_vol_r_i_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.i.iicerebellum
T1Hier_vol_r_vcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.vcerebellum
T1Hier_vol_r_vicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.vicerebellum
T1Hier_vol_r_viibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.viibcerebellum
T1Hier_vol_r_viiiacerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.viiiacerebellum
T1Hier_vol_r_viiibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.viiibcerebellum
T1Hier_vol_r_xcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
t1.vol.r.xcerebellum
T1Hier_area_l_crus_icerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.crus.icerebellum
T1Hier_area_l_crus_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.crus.iicerebellum
T1Hier_area_l_iiicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.iiicerebellum
T1Hier_area_l_ivcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.ivcerebellum
T1Hier_area_l_ixcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.ixcerebellum
T1Hier_area_l_i_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.i.iicerebellum
T1Hier_area_l_vcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.vcerebellum
T1Hier_area_l_vicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.vicerebellum
T1Hier_area_l_viibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.viibcerebellum
T1Hier_area_l_viiiacerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.viiiacerebellum
T1Hier_area_l_viiibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.viiibcerebellum
T1Hier_area_l_xcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.l.xcerebellum
T1Hier_area_r_crus_icerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.crus.icerebellum
T1Hier_area_r_crus_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.crus.iicerebellum
T1Hier_area_r_iiicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.iiicerebellum
T1Hier_area_r_ivcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.ivcerebellum
T1Hier_area_r_ixcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.ixcerebellum
T1Hier_area_r_i_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.i.iicerebellum
T1Hier_area_r_vcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.vcerebellum
T1Hier_area_r_vicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.vicerebellum
T1Hier_area_r_viibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.viibcerebellum
T1Hier_area_r_viiiacerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.viiiacerebellum
T1Hier_area_r_viiibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.viiibcerebellum
T1Hier_area_r_xcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
t1.area.r.xcerebellum
T1Hier_thk_l_crus_icerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.crus.icerebellum
T1Hier_thk_l_crus_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.crus.iicerebellum
T1Hier_thk_l_iiicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.iiicerebellum
T1Hier_thk_l_ivcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.ivcerebellum
T1Hier_thk_l_ixcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.ixcerebellum
T1Hier_thk_l_i_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.i.iicerebellum
T1Hier_thk_l_vcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.vcerebellum
T1Hier_thk_l_vicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.vicerebellum
T1Hier_thk_l_viibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.viibcerebellum
T1Hier_thk_l_viiiacerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.viiiacerebellum
T1Hier_thk_l_viiibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.viiibcerebellum
T1Hier_thk_l_xcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.l.xcerebellum
T1Hier_thk_r_crus_icerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.crus.icerebellum
T1Hier_thk_r_crus_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.crus.iicerebellum
T1Hier_thk_r_iiicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.iiicerebellum
T1Hier_thk_r_ivcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.ivcerebellum
T1Hier_thk_r_ixcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.ixcerebellum
T1Hier_thk_r_i_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.i.iicerebellum
T1Hier_thk_r_vcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.vcerebellum
T1Hier_thk_r_vicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.vicerebellum
T1Hier_thk_r_viibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.viibcerebellum
T1Hier_thk_r_viiiacerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.viiiacerebellum
T1Hier_thk_r_viiibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.viiibcerebellum
T1Hier_thk_r_xcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
t1.thk.r.xcerebellum
T1Hier_RandBasisProj01
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj01
t1.randbasisproj01
T1Hier_RandBasisProj02
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj02
t1.randbasisproj02
T1Hier_RandBasisProj03
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj03
t1.randbasisproj03
T1Hier_RandBasisProj04
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj04
t1.randbasisproj04
T1Hier_RandBasisProj05
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj05
t1.randbasisproj05
T1Hier_RandBasisProj06
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj06
t1.randbasisproj06
T1Hier_RandBasisProj07
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj07
t1.randbasisproj07
T1Hier_RandBasisProj08
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj08
t1.randbasisproj08
T1Hier_RandBasisProj09
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj09
t1.randbasisproj09
T1Hier_RandBasisProj10
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj10
t1.randbasisproj10
T1Hier_RandBasisProjPos01
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos01
t1.randbasisprojpos01
T1Hier_RandBasisProjPos02
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos02
t1.randbasisprojpos02
T1Hier_RandBasisProjPos03
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos03
t1.randbasisprojpos03
T1Hier_RandBasisProjPos04
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos04
t1.randbasisprojpos04
T1Hier_RandBasisProjPos05
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos05
t1.randbasisprojpos05
T1Hier_RandBasisProjPos06
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos06
t1.randbasisprojpos06
T1Hier_RandBasisProjPos07
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos07
t1.randbasisprojpos07
T1Hier_RandBasisProjPos08
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos08
t1.randbasisprojpos08
T1Hier_RandBasisProjPos09
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos09
t1.randbasisprojpos09
T1Hier_RandBasisProjPos10
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos10
t1.randbasisprojpos10
T1Hier_loop_outlier_probability
T1 hierarchical processing
​
quality control metrics
QC
loop outlier probability
t1.loop.outlier.probability
T1Hier_mhdist
T1 hierarchical processing
​
quality control metrics
QC
mhdist
t1.mhdist
T1Hier_templateL1
T1 hierarchical processing
​
quality control metrics
QC
templateL1
t1.templatel1
T1Hier_evratio
T1 hierarchical processing
​
quality control metrics
QC
evratio
t1.evratio
T1Hier_resnetGrade
T1 hierarchical processing
​
quality control metrics
QC
resnetGrade
t1.resnetgrade
T1w_mean_background
T1 DiReCT thickness processing
​
ANTs
Regional average of DiReCT estimated thickness
​
t1w.mean.background
T1w_mean_left_caudal_anterior_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal anterior cingulate
t1w.mean.left.caudal.ant.cingulate
T1w_mean_left_caudal_middle_frontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal middle frontal
t1w.mean.left.caudal.middle.frontal
T1w_mean_left_cuneus
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
cuneus
t1w.mean.left.cuneus
T1w_mean_left_entorhinal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
entorhinal
t1w.mean.left.entorhinal
T1w_mean_left_fusiform
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
fusiform
t1w.mean.left.fusiform
T1w_mean_left_inferior_parietal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior parietal
t1w.mean.left.inf.parietal
T1w_mean_left_inferior_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior temporal
t1w.mean.left.inf.temporal
T1w_mean_left_insula
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
insula
t1w.mean.left.insula
T1w_mean_left_isthmus_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
isthmus cingulate
t1w.mean.left.isthmus.cingulate
T1w_mean_left_lateral_occipital
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral occipital
t1w.mean.left.lateral.occipital
T1w_mean_left_lateral_orbitofrontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral orbitofrontal
t1w.mean.left.lateral.orbitofrontal
T1w_mean_left_lingual
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lingual
t1w.mean.left.lingual
T1w_mean_left_medial_orbitofrontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
medial orbitofrontal
t1w.mean.left.medial.orbitofrontal
T1w_mean_left_middle_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
middle temporal
t1w.mean.left.middle.temporal
T1w_mean_left_paracentral
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
paracentral
t1w.mean.left.paracent
T1w_mean_left_parahippocampal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
parahippocampal
t1w.mean.left.parahippocampal
T1w_mean_left_pars_opercularis
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars opercularis
t1w.mean.left.pars.opercularis
T1w_mean_left_pars_orbitalis
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars orbitalis
t1w.mean.left.pars.orbitalis
T1w_mean_left_pars_triangularis
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars triangularis
t1w.mean.left.pars.triangularis
T1w_mean_left_pericalcarine
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pericalcarine
t1w.mean.left.pericalcarine
T1w_mean_left_postcentral
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
postcentral
t1w.mean.left.postcent
T1w_mean_left_posterior_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
posterior cingulate
t1w.mean.left.post.cingulate
T1w_mean_left_precentral
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precentral
t1w.mean.left.precent
T1w_mean_left_precuneus
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precuneus
t1w.mean.left.precuneus
T1w_mean_left_rostral_anterior_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral anterior cingulate
t1w.mean.left.rostral.ant.cingulate
T1w_mean_left_rostral_middle_frontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral middle frontal
t1w.mean.left.rostral.middle.frontal
T1w_mean_left_superior_frontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior frontal
t1w.mean.left.sup.frontal
T1w_mean_left_superior_parietal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior parietal
t1w.mean.left.sup.parietal
T1w_mean_left_superior_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior temporal
t1w.mean.left.sup.temporal
T1w_mean_left_supramarginal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
supramarginal
t1w.mean.left.supramarginal
T1w_mean_left_transverse_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
transverse temporal
t1w.mean.left.transverse.temporal
T1w_mean_right_caudal_anterior_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal anterior cingulate
t1w.mean.right.caudal.ant.cingulate
T1w_mean_right_caudal_middle_frontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal middle frontal
t1w.mean.right.caudal.middle.frontal
T1w_mean_right_cuneus
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
cuneus
t1w.mean.right.cuneus
T1w_mean_right_entorhinal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
entorhinal
t1w.mean.right.entorhinal
T1w_mean_right_fusiform
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
fusiform
t1w.mean.right.fusiform
T1w_mean_right_inferior_parietal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior parietal
t1w.mean.right.inf.parietal
T1w_mean_right_inferior_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior temporal
t1w.mean.right.inf.temporal
T1w_mean_right_insula
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
insula
t1w.mean.right.insula
T1w_mean_right_isthmus_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
isthmus cingulate
t1w.mean.right.isthmus.cingulate
T1w_mean_right_lateral_occipital
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral occipital
t1w.mean.right.lateral.occipital
T1w_mean_right_lateral_orbitofrontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral orbitofrontal
t1w.mean.right.lateral.orbitofrontal
T1w_mean_right_lingual
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lingual
t1w.mean.right.lingual
T1w_mean_right_medial_orbitofrontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
medial orbitofrontal
t1w.mean.right.medial.orbitofrontal
T1w_mean_right_middle_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
middle temporal
t1w.mean.right.middle.temporal
T1w_mean_right_paracentral
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
paracentral
t1w.mean.right.paracent
T1w_mean_right_parahippocampal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
parahippocampal
t1w.mean.right.parahippocampal
T1w_mean_right_pars_opercularis
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars opercularis
t1w.mean.right.pars.opercularis
T1w_mean_right_pars_orbitalis
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars orbitalis
t1w.mean.right.pars.orbitalis
T1w_mean_right_pars_triangularis
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars triangularis
t1w.mean.right.pars.triangularis
T1w_mean_right_pericalcarine
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pericalcarine
t1w.mean.right.pericalcarine
T1w_mean_right_postcentral
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
postcentral
t1w.mean.right.postcent
T1w_mean_right_posterior_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
posterior cingulate
t1w.mean.right.post.cingulate
T1w_mean_right_precentral
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precentral
t1w.mean.right.precent
T1w_mean_right_precuneus
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precuneus
t1w.mean.right.precuneus
T1w_mean_right_rostral_anterior_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral anterior cingulate
t1w.mean.right.rostral.ant.cingulate
T1w_mean_right_rostral_middle_frontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral middle frontal
t1w.mean.right.rostral.middle.frontal
T1w_mean_right_superior_frontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior frontal
t1w.mean.right.sup.frontal
T1w_mean_right_superior_parietal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior parietal
t1w.mean.right.sup.parietal
T1w_mean_right_superior_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior temporal
t1w.mean.right.sup.temporal
T1w_mean_right_supramarginal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
supramarginal
t1w.mean.right.supramarginal
T1w_mean_right_transverse_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
transverse temporal
t1w.mean.right.transverse.temporal
T2Flair_WMH_probability_map_mean
Flair
​
ANTs
​
​
t2flair.wmh.probability.map.mean
T2Flair_WMH_posterior_probability_map_mean
Flair
​
ANTs
​
​
t2flair.wmh.post.probability.map.mean
T2Flair_wmh_mass
Flair
​
ANTs
​
​
t2flair.wmh.mass
T2Flair_wmh_mass_prior
Flair
​
ANTs
​
​
t2flair.wmh.mass.prior
T2Flair_wmh_evr
Flair
​
ANTs
QC
​
t2flair.wmh.evr
rsfMRI_fcnxpro122_paramset
restingStatefMRI
​
yeo_homotopic
parameter id
​
rsf.paramset
rsfMRI_fcnxpro122_upsampling
restingStatefMRI
​
yeo_homotopic
upsampling parameter
​
rsf.upsampling
rsfMRI_fcnxpro122_meanBold_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.meanbold.mean
rsfMRI_fcnxpro122_TempPar_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.temppar.mean
rsfMRI_fcnxpro122_DefaultC_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.defaultc.mean
rsfMRI_fcnxpro122_DefaultB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.defaultb.mean
rsfMRI_fcnxpro122_DefaultA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.defaulta.mean
rsfMRI_fcnxpro122_ContC_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.contc.mean
rsfMRI_fcnxpro122_ContB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.contb.mean
rsfMRI_fcnxpro122_ContA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.conta.mean
rsfMRI_fcnxpro122_LimbicA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.limbica.mean
rsfMRI_fcnxpro122_LimbicB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.limbicb.mean
rsfMRI_fcnxpro122_SalVentAttnB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.salventattnb.mean
rsfMRI_fcnxpro122_SalVentAttnA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.salventattna.mean
rsfMRI_fcnxpro122_DorsAttnB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.dorsattnb.mean
rsfMRI_fcnxpro122_DorsAttnA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.dorsattna.mean
rsfMRI_fcnxpro122_SomMotB_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.sommotb.mean
rsfMRI_fcnxpro122_SomMotA_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.sommota.mean
rsfMRI_fcnxpro122_VisPeri_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.visperi.mean
rsfMRI_fcnxpro122_VisCent_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.viscent.mean
rsfMRI_fcnxpro122_fmri_template_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.fmri.template.mean
rsfMRI_fcnxpro122_brainmask_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.brainmask.mean
rsfMRI_fcnxpro122_gmmask_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.gmmask.mean
rsfMRI_fcnxpro122_alff_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.alff.mean
rsfMRI_fcnxpro122_alff_sd
restingStatefMRI
​
yeo_homotopic
global sd of image
​
rsf.alff.sd
rsfMRI_fcnxpro122_falff_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.falff.mean
rsfMRI_fcnxpro122_falff_sd
restingStatefMRI
​
yeo_homotopic
global sd of image
​
rsf.falff.sd
rsfMRI_fcnxpro122_falffPoint000_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint000.iplleft
rsfMRI_fcnxpro122_alffPoint000_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint000.iplleft
rsfMRI_fcnxpro122_perafPoint000_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint000.iplleft
rsfMRI_fcnxpro122_falffPoint001_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint001.stleft
rsfMRI_fcnxpro122_alffPoint001_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint001.stleft
rsfMRI_fcnxpro122_perafPoint001_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint001.stleft
rsfMRI_fcnxpro122_falffPoint002_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint002.stleft
rsfMRI_fcnxpro122_alffPoint002_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint002.stleft
rsfMRI_fcnxpro122_perafPoint002_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint002.stleft
rsfMRI_fcnxpro122_falffPoint003_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint003.tempoccleft
rsfMRI_fcnxpro122_alffPoint003_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint003.tempoccleft
rsfMRI_fcnxpro122_perafPoint003_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint003.tempoccleft
rsfMRI_fcnxpro122_falffPoint004_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint004.templeft
rsfMRI_fcnxpro122_alffPoint004_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint004.templeft
rsfMRI_fcnxpro122_perafPoint004_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint004.templeft
rsfMRI_fcnxpro122_falffPoint005_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint005.templeft
rsfMRI_fcnxpro122_alffPoint005_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint005.templeft
rsfMRI_fcnxpro122_perafPoint005_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint005.templeft
rsfMRI_fcnxpro122_falffPoint006_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint006.exstrinfleft
rsfMRI_fcnxpro122_alffPoint006_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint006.exstrinfleft
rsfMRI_fcnxpro122_perafPoint006_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint006.exstrinfleft
rsfMRI_fcnxpro122_falffPoint007_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint007.iplleft
rsfMRI_fcnxpro122_alffPoint007_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint007.iplleft
rsfMRI_fcnxpro122_perafPoint007_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint007.iplleft
rsfMRI_fcnxpro122_falffPoint008_PHCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint008.phcleft
rsfMRI_fcnxpro122_alffPoint008_PHCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint008.phcleft
rsfMRI_fcnxpro122_perafPoint008_PHCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint008.phcleft
rsfMRI_fcnxpro122_falffPoint009_PHCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint009.phcleft
rsfMRI_fcnxpro122_alffPoint009_PHCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint009.phcleft
rsfMRI_fcnxpro122_perafPoint009_PHCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint009.phcleft
rsfMRI_fcnxpro122_falffPoint010_PHCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint010.phcleft
rsfMRI_fcnxpro122_alffPoint010_PHCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint010.phcleft
rsfMRI_fcnxpro122_perafPoint010_PHCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint010.phcleft
rsfMRI_fcnxpro122_falffPoint011_RSCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint011.rscleft
rsfMRI_fcnxpro122_alffPoint011_RSCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint011.rscleft
rsfMRI_fcnxpro122_perafPoint011_RSCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint011.rscleft
rsfMRI_fcnxpro122_falffPoint012_RSCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint012.rscleft
rsfMRI_fcnxpro122_alffPoint012_RSCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint012.rscleft
rsfMRI_fcnxpro122_perafPoint012_RSCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint012.rscleft
rsfMRI_fcnxpro122_falffPoint013_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint013.iplleft
rsfMRI_fcnxpro122_alffPoint013_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint013.iplleft
rsfMRI_fcnxpro122_perafPoint013_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint013.iplleft
rsfMRI_fcnxpro122_falffPoint014_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint014.iplleft
rsfMRI_fcnxpro122_alffPoint014_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint014.iplleft
rsfMRI_fcnxpro122_perafPoint014_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint014.iplleft
rsfMRI_fcnxpro122_falffPoint015_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint015.iplleft
rsfMRI_fcnxpro122_alffPoint015_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint015.iplleft
rsfMRI_fcnxpro122_perafPoint015_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint015.iplleft
rsfMRI_fcnxpro122_falffPoint016_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint016.iplleft
rsfMRI_fcnxpro122_alffPoint016_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint016.iplleft
rsfMRI_fcnxpro122_perafPoint016_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint016.iplleft
rsfMRI_fcnxpro122_falffPoint017_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint017.pfcdleft
rsfMRI_fcnxpro122_alffPoint017_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint017.pfcdleft
rsfMRI_fcnxpro122_perafPoint017_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint017.pfcdleft
rsfMRI_fcnxpro122_falffPoint018_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint018.pfcdleft
rsfMRI_fcnxpro122_alffPoint018_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint018.pfcdleft
rsfMRI_fcnxpro122_perafPoint018_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint018.pfcdleft
rsfMRI_fcnxpro122_falffPoint019_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint019.pfcdleft
rsfMRI_fcnxpro122_alffPoint019_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint019.pfcdleft
rsfMRI_fcnxpro122_perafPoint019_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint019.pfcdleft
rsfMRI_fcnxpro122_falffPoint020_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint020.pfcdleft
rsfMRI_fcnxpro122_alffPoint020_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint020.pfcdleft
rsfMRI_fcnxpro122_perafPoint020_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint020.pfcdleft
rsfMRI_fcnxpro122_falffPoint021_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint021.pfcdleft
rsfMRI_fcnxpro122_alffPoint021_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint021.pfcdleft
rsfMRI_fcnxpro122_perafPoint021_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint021.pfcdleft
rsfMRI_fcnxpro122_falffPoint022_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint022.pfcdleft
rsfMRI_fcnxpro122_alffPoint022_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint022.pfcdleft
rsfMRI_fcnxpro122_perafPoint022_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint022.pfcdleft
rsfMRI_fcnxpro122_falffPoint023_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint023.pfcdleft
rsfMRI_fcnxpro122_alffPoint023_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint023.pfcdleft
rsfMRI_fcnxpro122_perafPoint023_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint023.pfcdleft
rsfMRI_fcnxpro122_falffPoint024_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint024.pfclleft
rsfMRI_fcnxpro122_alffPoint024_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint024.pfclleft
rsfMRI_fcnxpro122_perafPoint024_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint024.pfclleft
rsfMRI_fcnxpro122_falffPoint025_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint025.pfclleft
rsfMRI_fcnxpro122_alffPoint025_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint025.pfclleft
rsfMRI_fcnxpro122_perafPoint025_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint025.pfclleft
rsfMRI_fcnxpro122_falffPoint026_PFCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint026.pfcvleft
rsfMRI_fcnxpro122_alffPoint026_PFCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint026.pfcvleft
rsfMRI_fcnxpro122_perafPoint026_PFCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint026.pfcvleft
rsfMRI_fcnxpro122_falffPoint027_PFCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint027.pfcvleft
rsfMRI_fcnxpro122_alffPoint027_PFCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint027.pfcvleft
rsfMRI_fcnxpro122_perafPoint027_PFCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint027.pfcvleft
rsfMRI_fcnxpro122_falffPoint028_PFCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint028.pfcvleft
rsfMRI_fcnxpro122_alffPoint028_PFCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint028.pfcvleft
rsfMRI_fcnxpro122_perafPoint028_PFCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint028.pfcvleft
rsfMRI_fcnxpro122_falffPoint029_PFCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint029.pfcvleft
rsfMRI_fcnxpro122_alffPoint029_PFCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint029.pfcvleft
rsfMRI_fcnxpro122_perafPoint029_PFCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint029.pfcvleft
rsfMRI_fcnxpro122_falffPoint030_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint030.temppoleleft
rsfMRI_fcnxpro122_alffPoint030_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint030.temppoleleft
rsfMRI_fcnxpro122_perafPoint030_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint030.temppoleleft
rsfMRI_fcnxpro122_falffPoint031_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint031.templeft
rsfMRI_fcnxpro122_alffPoint031_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint031.templeft
rsfMRI_fcnxpro122_perafPoint031_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint031.templeft
rsfMRI_fcnxpro122_falffPoint032_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint032.templeft
rsfMRI_fcnxpro122_alffPoint032_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint032.templeft
rsfMRI_fcnxpro122_perafPoint032_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint032.templeft
rsfMRI_fcnxpro122_falffPoint033_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint033.templeft
rsfMRI_fcnxpro122_alffPoint033_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint033.templeft
rsfMRI_fcnxpro122_perafPoint033_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint033.templeft
rsfMRI_fcnxpro122_falffPoint034_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint034.templeft
rsfMRI_fcnxpro122_alffPoint034_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint034.templeft
rsfMRI_fcnxpro122_perafPoint034_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint034.templeft
rsfMRI_fcnxpro122_falffPoint035_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint035.templeft
rsfMRI_fcnxpro122_alffPoint035_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint035.templeft
rsfMRI_fcnxpro122_perafPoint035_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint035.templeft
rsfMRI_fcnxpro122_falffPoint036_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint036.templeft
rsfMRI_fcnxpro122_alffPoint036_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint036.templeft
rsfMRI_fcnxpro122_perafPoint036_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint036.templeft
rsfMRI_fcnxpro122_falffPoint037_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint037.templeft
rsfMRI_fcnxpro122_alffPoint037_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint037.templeft
rsfMRI_fcnxpro122_perafPoint037_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint037.templeft
rsfMRI_fcnxpro122_falffPoint038_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint038.templeft
rsfMRI_fcnxpro122_alffPoint038_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint038.templeft
rsfMRI_fcnxpro122_perafPoint038_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint038.templeft
rsfMRI_fcnxpro122_falffPoint039_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint039.templeft
rsfMRI_fcnxpro122_alffPoint039_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint039.templeft
rsfMRI_fcnxpro122_perafPoint039_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint039.templeft
rsfMRI_fcnxpro122_falffPoint040_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint040.templeft
rsfMRI_fcnxpro122_alffPoint040_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint040.templeft
rsfMRI_fcnxpro122_perafPoint040_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint040.templeft
rsfMRI_fcnxpro122_falffPoint041_FPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint041.fpoleleft
rsfMRI_fcnxpro122_alffPoint041_FPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint041.fpoleleft
rsfMRI_fcnxpro122_perafPoint041_FPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint041.fpoleleft
rsfMRI_fcnxpro122_falffPoint042_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint042.iplleft
rsfMRI_fcnxpro122_alffPoint042_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint042.iplleft
rsfMRI_fcnxpro122_perafPoint042_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint042.iplleft
rsfMRI_fcnxpro122_falffPoint043_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint043.iplleft
rsfMRI_fcnxpro122_alffPoint043_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint043.iplleft
rsfMRI_fcnxpro122_perafPoint043_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint043.iplleft
rsfMRI_fcnxpro122_falffPoint044_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint044.iplleft
rsfMRI_fcnxpro122_alffPoint044_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint044.iplleft
rsfMRI_fcnxpro122_perafPoint044_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint044.iplleft
rsfMRI_fcnxpro122_falffPoint045_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint045.pccleft
rsfMRI_fcnxpro122_alffPoint045_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint045.pccleft
rsfMRI_fcnxpro122_perafPoint045_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint045.pccleft
rsfMRI_fcnxpro122_falffPoint046_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint046.pccleft
rsfMRI_fcnxpro122_alffPoint046_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint046.pccleft
rsfMRI_fcnxpro122_perafPoint046_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint046.pccleft
rsfMRI_fcnxpro122_falffPoint047_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint047.pccleft
rsfMRI_fcnxpro122_alffPoint047_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint047.pccleft
rsfMRI_fcnxpro122_perafPoint047_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint047.pccleft
rsfMRI_fcnxpro122_falffPoint048_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint048.pccleft
rsfMRI_fcnxpro122_alffPoint048_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint048.pccleft
rsfMRI_fcnxpro122_perafPoint048_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint048.pccleft
rsfMRI_fcnxpro122_falffPoint049_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint049.pccleft
rsfMRI_fcnxpro122_alffPoint049_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint049.pccleft
rsfMRI_fcnxpro122_perafPoint049_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint049.pccleft
rsfMRI_fcnxpro122_falffPoint050_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint050.pccleft
rsfMRI_fcnxpro122_alffPoint050_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint050.pccleft
rsfMRI_fcnxpro122_perafPoint050_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint050.pccleft
rsfMRI_fcnxpro122_falffPoint051_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint051.pccleft
rsfMRI_fcnxpro122_alffPoint051_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint051.pccleft
rsfMRI_fcnxpro122_perafPoint051_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint051.pccleft
rsfMRI_fcnxpro122_falffPoint052_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint052.pfcdleft
rsfMRI_fcnxpro122_alffPoint052_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint052.pfcdleft
rsfMRI_fcnxpro122_perafPoint052_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint052.pfcdleft
rsfMRI_fcnxpro122_falffPoint053_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint053.pfcdleft
rsfMRI_fcnxpro122_alffPoint053_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint053.pfcdleft
rsfMRI_fcnxpro122_perafPoint053_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint053.pfcdleft
rsfMRI_fcnxpro122_falffPoint054_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint054.pfcdleft
rsfMRI_fcnxpro122_alffPoint054_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint054.pfcdleft
rsfMRI_fcnxpro122_perafPoint054_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint054.pfcdleft
rsfMRI_fcnxpro122_falffPoint055_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint055.pfcdleft
rsfMRI_fcnxpro122_alffPoint055_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint055.pfcdleft
rsfMRI_fcnxpro122_perafPoint055_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint055.pfcdleft
rsfMRI_fcnxpro122_falffPoint056_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint056.pfcmleft
rsfMRI_fcnxpro122_alffPoint056_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint056.pfcmleft
rsfMRI_fcnxpro122_perafPoint056_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint056.pfcmleft
rsfMRI_fcnxpro122_falffPoint057_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint057.pfcmleft
rsfMRI_fcnxpro122_alffPoint057_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint057.pfcmleft
rsfMRI_fcnxpro122_perafPoint057_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint057.pfcmleft
rsfMRI_fcnxpro122_falffPoint058_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint058.pfcmleft
rsfMRI_fcnxpro122_alffPoint058_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint058.pfcmleft
rsfMRI_fcnxpro122_perafPoint058_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint058.pfcmleft
rsfMRI_fcnxpro122_falffPoint059_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint059.pfcmleft
rsfMRI_fcnxpro122_alffPoint059_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint059.pfcmleft
rsfMRI_fcnxpro122_perafPoint059_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint059.pfcmleft
rsfMRI_fcnxpro122_falffPoint060_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint060.pfcmleft
rsfMRI_fcnxpro122_alffPoint060_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint060.pfcmleft
rsfMRI_fcnxpro122_perafPoint060_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint060.pfcmleft
rsfMRI_fcnxpro122_falffPoint061_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint061.pcunleft
rsfMRI_fcnxpro122_alffPoint061_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint061.pcunleft
rsfMRI_fcnxpro122_perafPoint061_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint061.pcunleft
rsfMRI_fcnxpro122_falffPoint062_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint062.pcunleft
rsfMRI_fcnxpro122_alffPoint062_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint062.pcunleft
rsfMRI_fcnxpro122_perafPoint062_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint062.pcunleft
rsfMRI_fcnxpro122_falffPoint063_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint063.pcunleft
rsfMRI_fcnxpro122_alffPoint063_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint063.pcunleft
rsfMRI_fcnxpro122_perafPoint063_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint063.pcunleft
rsfMRI_fcnxpro122_falffPoint064_PCCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint064.pccleft
rsfMRI_fcnxpro122_alffPoint064_PCCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint064.pccleft
rsfMRI_fcnxpro122_perafPoint064_PCCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint064.pccleft
rsfMRI_fcnxpro122_falffPoint065_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint065.splleft
rsfMRI_fcnxpro122_alffPoint065_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint065.splleft
rsfMRI_fcnxpro122_perafPoint065_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint065.splleft
rsfMRI_fcnxpro122_falffPoint066_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint066.pcunleft
rsfMRI_fcnxpro122_alffPoint066_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint066.pcunleft
rsfMRI_fcnxpro122_perafPoint066_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint066.pcunleft
rsfMRI_fcnxpro122_falffPoint067_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint067.pcunleft
rsfMRI_fcnxpro122_alffPoint067_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint067.pcunleft
rsfMRI_fcnxpro122_perafPoint067_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint067.pcunleft
rsfMRI_fcnxpro122_falffPoint068_pCunleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint068.pcunleft
rsfMRI_fcnxpro122_alffPoint068_pCunleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint068.pcunleft
rsfMRI_fcnxpro122_perafPoint068_pCunleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint068.pcunleft
rsfMRI_fcnxpro122_falffPoint069_FPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint069.fpoleleft
rsfMRI_fcnxpro122_alffPoint069_FPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint069.fpoleleft
rsfMRI_fcnxpro122_perafPoint069_FPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint069.fpoleleft
rsfMRI_fcnxpro122_falffPoint070_FPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint070.fpoleleft
rsfMRI_fcnxpro122_alffPoint070_FPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint070.fpoleleft
rsfMRI_fcnxpro122_perafPoint070_FPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint070.fpoleleft
rsfMRI_fcnxpro122_falffPoint071_FrMedleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint071.frmedleft
rsfMRI_fcnxpro122_alffPoint071_FrMedleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint071.frmedleft
rsfMRI_fcnxpro122_perafPoint071_FrMedleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint071.frmedleft
rsfMRI_fcnxpro122_falffPoint072_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint072.iplleft
rsfMRI_fcnxpro122_alffPoint072_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint072.iplleft
rsfMRI_fcnxpro122_perafPoint072_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint072.iplleft
rsfMRI_fcnxpro122_falffPoint073_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint073.ipsleft
rsfMRI_fcnxpro122_alffPoint073_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint073.ipsleft
rsfMRI_fcnxpro122_perafPoint073_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint073.ipsleft
rsfMRI_fcnxpro122_falffPoint074_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint074.ipsleft
rsfMRI_fcnxpro122_alffPoint074_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint074.ipsleft
rsfMRI_fcnxpro122_perafPoint074_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint074.ipsleft
rsfMRI_fcnxpro122_falffPoint075_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint075.pfcdleft
rsfMRI_fcnxpro122_alffPoint075_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint075.pfcdleft
rsfMRI_fcnxpro122_perafPoint075_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint075.pfcdleft
rsfMRI_fcnxpro122_falffPoint076_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint076.pfclleft
rsfMRI_fcnxpro122_alffPoint076_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint076.pfclleft
rsfMRI_fcnxpro122_perafPoint076_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint076.pfclleft
rsfMRI_fcnxpro122_falffPoint077_PFCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint077.pfcvleft
rsfMRI_fcnxpro122_alffPoint077_PFCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint077.pfcvleft
rsfMRI_fcnxpro122_perafPoint077_PFCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint077.pfcvleft
rsfMRI_fcnxpro122_falffPoint078_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint078.templeft
rsfMRI_fcnxpro122_alffPoint078_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint078.templeft
rsfMRI_fcnxpro122_perafPoint078_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint078.templeft
rsfMRI_fcnxpro122_falffPoint079_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint079.templeft
rsfMRI_fcnxpro122_alffPoint079_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint079.templeft
rsfMRI_fcnxpro122_perafPoint079_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint079.templeft
rsfMRI_fcnxpro122_falffPoint080_Cingmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint080.cingmleft
rsfMRI_fcnxpro122_alffPoint080_Cingmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint080.cingmleft
rsfMRI_fcnxpro122_perafPoint080_Cingmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint080.cingmleft
rsfMRI_fcnxpro122_falffPoint081_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint081.ipsleft
rsfMRI_fcnxpro122_alffPoint081_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint081.ipsleft
rsfMRI_fcnxpro122_perafPoint081_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint081.ipsleft
rsfMRI_fcnxpro122_falffPoint082_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint082.ipsleft
rsfMRI_fcnxpro122_alffPoint082_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint082.ipsleft
rsfMRI_fcnxpro122_perafPoint082_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint082.ipsleft
rsfMRI_fcnxpro122_falffPoint083_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint083.ipsleft
rsfMRI_fcnxpro122_alffPoint083_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint083.ipsleft
rsfMRI_fcnxpro122_perafPoint083_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint083.ipsleft
rsfMRI_fcnxpro122_falffPoint084_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint084.ipsleft
rsfMRI_fcnxpro122_alffPoint084_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint084.ipsleft
rsfMRI_fcnxpro122_perafPoint084_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint084.ipsleft
rsfMRI_fcnxpro122_falffPoint085_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint085.ipsleft
rsfMRI_fcnxpro122_alffPoint085_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint085.ipsleft
rsfMRI_fcnxpro122_perafPoint085_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint085.ipsleft
rsfMRI_fcnxpro122_falffPoint086_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint086.pfcdleft
rsfMRI_fcnxpro122_alffPoint086_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint086.pfcdleft
rsfMRI_fcnxpro122_perafPoint086_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint086.pfcdleft
rsfMRI_fcnxpro122_falffPoint087_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint087.pfclleft
rsfMRI_fcnxpro122_alffPoint087_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint087.pfclleft
rsfMRI_fcnxpro122_perafPoint087_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint087.pfclleft
rsfMRI_fcnxpro122_falffPoint088_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint088.pfclleft
rsfMRI_fcnxpro122_alffPoint088_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint088.pfclleft
rsfMRI_fcnxpro122_perafPoint088_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint088.pfclleft
rsfMRI_fcnxpro122_falffPoint089_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint089.pfclleft
rsfMRI_fcnxpro122_alffPoint089_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint089.pfclleft
rsfMRI_fcnxpro122_perafPoint089_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint089.pfclleft
rsfMRI_fcnxpro122_falffPoint090_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint090.pfclleft
rsfMRI_fcnxpro122_alffPoint090_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint090.pfclleft
rsfMRI_fcnxpro122_perafPoint090_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint090.pfclleft
rsfMRI_fcnxpro122_falffPoint091_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint091.pfclleft
rsfMRI_fcnxpro122_alffPoint091_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint091.pfclleft
rsfMRI_fcnxpro122_perafPoint091_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint091.pfclleft
rsfMRI_fcnxpro122_falffPoint092_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint092.pfclleft
rsfMRI_fcnxpro122_alffPoint092_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint092.pfclleft
rsfMRI_fcnxpro122_perafPoint092_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint092.pfclleft
rsfMRI_fcnxpro122_falffPoint093_PrCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint093.prcvleft
rsfMRI_fcnxpro122_alffPoint093_PrCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint093.prcvleft
rsfMRI_fcnxpro122_perafPoint093_PrCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint093.prcvleft
rsfMRI_fcnxpro122_falffPoint094_PrCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint094.prcvleft
rsfMRI_fcnxpro122_alffPoint094_PrCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint094.prcvleft
rsfMRI_fcnxpro122_perafPoint094_PrCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint094.prcvleft
rsfMRI_fcnxpro122_falffPoint095_PrCvleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint095.prcvleft
rsfMRI_fcnxpro122_alffPoint095_PrCvleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint095.prcvleft
rsfMRI_fcnxpro122_perafPoint095_PrCvleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint095.prcvleft
rsfMRI_fcnxpro122_falffPoint096_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint096.splleft
rsfMRI_fcnxpro122_alffPoint096_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint096.splleft
rsfMRI_fcnxpro122_perafPoint096_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint096.splleft
rsfMRI_fcnxpro122_falffPoint097_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint097.tempoccleft
rsfMRI_fcnxpro122_alffPoint097_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint097.tempoccleft
rsfMRI_fcnxpro122_perafPoint097_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint097.tempoccleft
rsfMRI_fcnxpro122_falffPoint098_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint098.insleft
rsfMRI_fcnxpro122_alffPoint098_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint098.insleft
rsfMRI_fcnxpro122_perafPoint098_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint098.insleft
rsfMRI_fcnxpro122_falffPoint099_PHCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint099.phcleft
rsfMRI_fcnxpro122_alffPoint099_PHCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint099.phcleft
rsfMRI_fcnxpro122_perafPoint099_PHCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint099.phcleft
rsfMRI_fcnxpro122_falffPoint100_PHCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint100.phcleft
rsfMRI_fcnxpro122_alffPoint100_PHCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint100.phcleft
rsfMRI_fcnxpro122_perafPoint100_PHCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint100.phcleft
rsfMRI_fcnxpro122_falffPoint101_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint101.stleft
rsfMRI_fcnxpro122_alffPoint101_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint101.stleft
rsfMRI_fcnxpro122_perafPoint101_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint101.stleft
rsfMRI_fcnxpro122_falffPoint102_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint102.temppoleleft
rsfMRI_fcnxpro122_alffPoint102_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint102.temppoleleft
rsfMRI_fcnxpro122_perafPoint102_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint102.temppoleleft
rsfMRI_fcnxpro122_falffPoint103_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint103.temppoleleft
rsfMRI_fcnxpro122_alffPoint103_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint103.temppoleleft
rsfMRI_fcnxpro122_perafPoint103_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint103.temppoleleft
rsfMRI_fcnxpro122_falffPoint104_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint104.temppoleleft
rsfMRI_fcnxpro122_alffPoint104_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint104.temppoleleft
rsfMRI_fcnxpro122_perafPoint104_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint104.temppoleleft
rsfMRI_fcnxpro122_falffPoint105_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint105.temppoleleft
rsfMRI_fcnxpro122_alffPoint105_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint105.temppoleleft
rsfMRI_fcnxpro122_perafPoint105_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint105.temppoleleft
rsfMRI_fcnxpro122_falffPoint106_TempPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint106.temppoleleft
rsfMRI_fcnxpro122_alffPoint106_TempPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint106.temppoleleft
rsfMRI_fcnxpro122_perafPoint106_TempPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint106.temppoleleft
rsfMRI_fcnxpro122_falffPoint107_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint107.templeft
rsfMRI_fcnxpro122_alffPoint107_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint107.templeft
rsfMRI_fcnxpro122_perafPoint107_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint107.templeft
rsfMRI_fcnxpro122_falffPoint108_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint108.templeft
rsfMRI_fcnxpro122_alffPoint108_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint108.templeft
rsfMRI_fcnxpro122_perafPoint108_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint108.templeft
rsfMRI_fcnxpro122_falffPoint109_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint109.templeft
rsfMRI_fcnxpro122_alffPoint109_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint109.templeft
rsfMRI_fcnxpro122_perafPoint109_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint109.templeft
rsfMRI_fcnxpro122_falffPoint110_Templeft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint110.templeft
rsfMRI_fcnxpro122_alffPoint110_Templeft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint110.templeft
rsfMRI_fcnxpro122_perafPoint110_Templeft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint110.templeft
rsfMRI_fcnxpro122_falffPoint111_FPoleleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint111.fpoleleft
rsfMRI_fcnxpro122_alffPoint111_FPoleleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint111.fpoleleft
rsfMRI_fcnxpro122_perafPoint111_FPoleleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint111.fpoleleft
rsfMRI_fcnxpro122_falffPoint112_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint112.ofcleft
rsfMRI_fcnxpro122_alffPoint112_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint112.ofcleft
rsfMRI_fcnxpro122_perafPoint112_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint112.ofcleft
rsfMRI_fcnxpro122_falffPoint113_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint113.ofcleft
rsfMRI_fcnxpro122_alffPoint113_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint113.ofcleft
rsfMRI_fcnxpro122_perafPoint113_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint113.ofcleft
rsfMRI_fcnxpro122_falffPoint114_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint114.ofcleft
rsfMRI_fcnxpro122_alffPoint114_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint114.ofcleft
rsfMRI_fcnxpro122_perafPoint114_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint114.ofcleft
rsfMRI_fcnxpro122_falffPoint115_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint115.ofcleft
rsfMRI_fcnxpro122_alffPoint115_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint115.ofcleft
rsfMRI_fcnxpro122_perafPoint115_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint115.ofcleft
rsfMRI_fcnxpro122_falffPoint116_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint116.ofcleft
rsfMRI_fcnxpro122_alffPoint116_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint116.ofcleft
rsfMRI_fcnxpro122_perafPoint116_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint116.ofcleft
rsfMRI_fcnxpro122_falffPoint117_OFCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint117.ofcleft
rsfMRI_fcnxpro122_alffPoint117_OFCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint117.ofcleft
rsfMRI_fcnxpro122_perafPoint117_OFCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint117.ofcleft
rsfMRI_fcnxpro122_falffPoint118_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint118.pfcmleft
rsfMRI_fcnxpro122_alffPoint118_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint118.pfcmleft
rsfMRI_fcnxpro122_perafPoint118_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint118.pfcmleft
rsfMRI_fcnxpro122_falffPoint119_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint119.pfcmleft
rsfMRI_fcnxpro122_alffPoint119_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint119.pfcmleft
rsfMRI_fcnxpro122_perafPoint119_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint119.pfcmleft
rsfMRI_fcnxpro122_falffPoint120_FrMedleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint120.frmedleft
rsfMRI_fcnxpro122_alffPoint120_FrMedleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint120.frmedleft
rsfMRI_fcnxpro122_perafPoint120_FrMedleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint120.frmedleft
rsfMRI_fcnxpro122_falffPoint121_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint121.insleft
rsfMRI_fcnxpro122_alffPoint121_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint121.insleft
rsfMRI_fcnxpro122_perafPoint121_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint121.insleft
rsfMRI_fcnxpro122_falffPoint122_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint122.insleft
rsfMRI_fcnxpro122_alffPoint122_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint122.insleft
rsfMRI_fcnxpro122_perafPoint122_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint122.insleft
rsfMRI_fcnxpro122_falffPoint123_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint123.insleft
rsfMRI_fcnxpro122_alffPoint123_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint123.insleft
rsfMRI_fcnxpro122_perafPoint123_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint123.insleft
rsfMRI_fcnxpro122_falffPoint124_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint124.pfclleft
rsfMRI_fcnxpro122_alffPoint124_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint124.pfclleft
rsfMRI_fcnxpro122_perafPoint124_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint124.pfclleft
rsfMRI_fcnxpro122_falffPoint125_PFClleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint125.pfclleft
rsfMRI_fcnxpro122_alffPoint125_PFClleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint125.pfclleft
rsfMRI_fcnxpro122_perafPoint125_PFClleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint125.pfclleft
rsfMRI_fcnxpro122_falffPoint126_PFCmleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint126.pfcmleft
rsfMRI_fcnxpro122_alffPoint126_PFCmleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint126.pfcmleft
rsfMRI_fcnxpro122_perafPoint126_PFCmleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint126.pfcmleft
rsfMRI_fcnxpro122_falffPoint127_FrMedleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint127.frmedleft
rsfMRI_fcnxpro122_alffPoint127_FrMedleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint127.frmedleft
rsfMRI_fcnxpro122_perafPoint127_FrMedleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint127.frmedleft
rsfMRI_fcnxpro122_falffPoint128_FrMedleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint128.frmedleft
rsfMRI_fcnxpro122_alffPoint128_FrMedleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint128.frmedleft
rsfMRI_fcnxpro122_perafPoint128_FrMedleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint128.frmedleft
rsfMRI_fcnxpro122_falffPoint129_FrMedleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint129.frmedleft
rsfMRI_fcnxpro122_alffPoint129_FrMedleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint129.frmedleft
rsfMRI_fcnxpro122_perafPoint129_FrMedleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint129.frmedleft
rsfMRI_fcnxpro122_falffPoint130_FrOperleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint130.froperleft
rsfMRI_fcnxpro122_alffPoint130_FrOperleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint130.froperleft
rsfMRI_fcnxpro122_perafPoint130_FrOperleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint130.froperleft
rsfMRI_fcnxpro122_falffPoint131_FrOperleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint131.froperleft
rsfMRI_fcnxpro122_alffPoint131_FrOperleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint131.froperleft
rsfMRI_fcnxpro122_perafPoint131_FrOperleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint131.froperleft
rsfMRI_fcnxpro122_falffPoint132_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint132.iplleft
rsfMRI_fcnxpro122_alffPoint132_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint132.iplleft
rsfMRI_fcnxpro122_perafPoint132_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint132.iplleft
rsfMRI_fcnxpro122_falffPoint133_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint133.iplleft
rsfMRI_fcnxpro122_alffPoint133_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint133.iplleft
rsfMRI_fcnxpro122_perafPoint133_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint133.iplleft
rsfMRI_fcnxpro122_falffPoint134_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint134.insleft
rsfMRI_fcnxpro122_alffPoint134_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint134.insleft
rsfMRI_fcnxpro122_perafPoint134_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint134.insleft
rsfMRI_fcnxpro122_falffPoint135_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint135.insleft
rsfMRI_fcnxpro122_alffPoint135_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint135.insleft
rsfMRI_fcnxpro122_perafPoint135_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint135.insleft
rsfMRI_fcnxpro122_falffPoint136_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint136.insleft
rsfMRI_fcnxpro122_alffPoint136_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint136.insleft
rsfMRI_fcnxpro122_perafPoint136_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint136.insleft
rsfMRI_fcnxpro122_falffPoint137_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint137.insleft
rsfMRI_fcnxpro122_alffPoint137_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint137.insleft
rsfMRI_fcnxpro122_perafPoint137_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint137.insleft
rsfMRI_fcnxpro122_falffPoint138_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint138.insleft
rsfMRI_fcnxpro122_alffPoint138_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint138.insleft
rsfMRI_fcnxpro122_perafPoint138_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint138.insleft
rsfMRI_fcnxpro122_falffPoint139_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint139.splleft
rsfMRI_fcnxpro122_alffPoint139_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint139.splleft
rsfMRI_fcnxpro122_perafPoint139_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint139.splleft
rsfMRI_fcnxpro122_falffPoint140_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint140.splleft
rsfMRI_fcnxpro122_alffPoint140_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint140.splleft
rsfMRI_fcnxpro122_perafPoint140_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint140.splleft
rsfMRI_fcnxpro122_falffPoint141_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint141.splleft
rsfMRI_fcnxpro122_alffPoint141_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint141.splleft
rsfMRI_fcnxpro122_perafPoint141_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint141.splleft
rsfMRI_fcnxpro122_falffPoint142_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint142.iplleft
rsfMRI_fcnxpro122_alffPoint142_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint142.iplleft
rsfMRI_fcnxpro122_perafPoint142_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint142.iplleft
rsfMRI_fcnxpro122_falffPoint143_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint143.iplleft
rsfMRI_fcnxpro122_alffPoint143_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint143.iplleft
rsfMRI_fcnxpro122_perafPoint143_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint143.iplleft
rsfMRI_fcnxpro122_falffPoint144_PFCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint144.pfcdleft
rsfMRI_fcnxpro122_alffPoint144_PFCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint144.pfcdleft
rsfMRI_fcnxpro122_perafPoint144_PFCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint144.pfcdleft
rsfMRI_fcnxpro122_falffPoint145_PostCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint145.postcleft
rsfMRI_fcnxpro122_alffPoint145_PostCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint145.postcleft
rsfMRI_fcnxpro122_perafPoint145_PostCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint145.postcleft
rsfMRI_fcnxpro122_falffPoint146_PostCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint146.postcleft
rsfMRI_fcnxpro122_alffPoint146_PostCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint146.postcleft
rsfMRI_fcnxpro122_perafPoint146_PostCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint146.postcleft
rsfMRI_fcnxpro122_falffPoint147_PostCleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint147.postcleft
rsfMRI_fcnxpro122_alffPoint147_PostCleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint147.postcleft
rsfMRI_fcnxpro122_perafPoint147_PostCleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint147.postcleft
rsfMRI_fcnxpro122_falffPoint148_PrCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint148.prcdleft
rsfMRI_fcnxpro122_alffPoint148_PrCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint148.prcdleft
rsfMRI_fcnxpro122_perafPoint148_PrCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint148.prcdleft
rsfMRI_fcnxpro122_falffPoint149_PrCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint149.prcdleft
rsfMRI_fcnxpro122_alffPoint149_PrCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint149.prcdleft
rsfMRI_fcnxpro122_perafPoint149_PrCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint149.prcdleft
rsfMRI_fcnxpro122_falffPoint150_PrCdleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint150.prcdleft
rsfMRI_fcnxpro122_alffPoint150_PrCdleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint150.prcdleft
rsfMRI_fcnxpro122_perafPoint150_PrCdleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint150.prcdleft
rsfMRI_fcnxpro122_falffPoint151_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint151.splleft
rsfMRI_fcnxpro122_alffPoint151_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint151.splleft
rsfMRI_fcnxpro122_perafPoint151_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint151.splleft
rsfMRI_fcnxpro122_falffPoint152_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint152.splleft
rsfMRI_fcnxpro122_alffPoint152_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint152.splleft
rsfMRI_fcnxpro122_perafPoint152_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint152.splleft
rsfMRI_fcnxpro122_falffPoint153_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint153.splleft
rsfMRI_fcnxpro122_alffPoint153_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint153.splleft
rsfMRI_fcnxpro122_perafPoint153_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint153.splleft
rsfMRI_fcnxpro122_falffPoint154_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint154.splleft
rsfMRI_fcnxpro122_alffPoint154_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint154.splleft
rsfMRI_fcnxpro122_perafPoint154_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint154.splleft
rsfMRI_fcnxpro122_falffPoint155_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint155.tempoccleft
rsfMRI_fcnxpro122_alffPoint155_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint155.tempoccleft
rsfMRI_fcnxpro122_perafPoint155_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint155.tempoccleft
rsfMRI_fcnxpro122_falffPoint156_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint156.exstrleft
rsfMRI_fcnxpro122_alffPoint156_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint156.exstrleft
rsfMRI_fcnxpro122_perafPoint156_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint156.exstrleft
rsfMRI_fcnxpro122_falffPoint157_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint157.exstrleft
rsfMRI_fcnxpro122_alffPoint157_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint157.exstrleft
rsfMRI_fcnxpro122_perafPoint157_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint157.exstrleft
rsfMRI_fcnxpro122_falffPoint158_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint158.exstrleft
rsfMRI_fcnxpro122_alffPoint158_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint158.exstrleft
rsfMRI_fcnxpro122_perafPoint158_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint158.exstrleft
rsfMRI_fcnxpro122_falffPoint159_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint159.exstrleft
rsfMRI_fcnxpro122_alffPoint159_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint159.exstrleft
rsfMRI_fcnxpro122_perafPoint159_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint159.exstrleft
rsfMRI_fcnxpro122_falffPoint160_IPSleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint160.ipsleft
rsfMRI_fcnxpro122_alffPoint160_IPSleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint160.ipsleft
rsfMRI_fcnxpro122_perafPoint160_IPSleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint160.ipsleft
rsfMRI_fcnxpro122_falffPoint161_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint161.splleft
rsfMRI_fcnxpro122_alffPoint161_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint161.splleft
rsfMRI_fcnxpro122_perafPoint161_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint161.splleft
rsfMRI_fcnxpro122_falffPoint162_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint162.splleft
rsfMRI_fcnxpro122_alffPoint162_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint162.splleft
rsfMRI_fcnxpro122_perafPoint162_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint162.splleft
rsfMRI_fcnxpro122_falffPoint163_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint163.splleft
rsfMRI_fcnxpro122_alffPoint163_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint163.splleft
rsfMRI_fcnxpro122_perafPoint163_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint163.splleft
rsfMRI_fcnxpro122_falffPoint164_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint164.splleft
rsfMRI_fcnxpro122_alffPoint164_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint164.splleft
rsfMRI_fcnxpro122_perafPoint164_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint164.splleft
rsfMRI_fcnxpro122_falffPoint165_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint165.splleft
rsfMRI_fcnxpro122_alffPoint165_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint165.splleft
rsfMRI_fcnxpro122_perafPoint165_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint165.splleft
rsfMRI_fcnxpro122_falffPoint166_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint166.splleft
rsfMRI_fcnxpro122_alffPoint166_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint166.splleft
rsfMRI_fcnxpro122_perafPoint166_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint166.splleft
rsfMRI_fcnxpro122_falffPoint167_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint167.tempoccleft
rsfMRI_fcnxpro122_alffPoint167_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint167.tempoccleft
rsfMRI_fcnxpro122_perafPoint167_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint167.tempoccleft
rsfMRI_fcnxpro122_falffPoint168_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint168.tempoccleft
rsfMRI_fcnxpro122_alffPoint168_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint168.tempoccleft
rsfMRI_fcnxpro122_perafPoint168_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint168.tempoccleft
rsfMRI_fcnxpro122_falffPoint169_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint169.tempoccleft
rsfMRI_fcnxpro122_alffPoint169_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint169.tempoccleft
rsfMRI_fcnxpro122_perafPoint169_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint169.tempoccleft
rsfMRI_fcnxpro122_falffPoint170_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint170.tempoccleft
rsfMRI_fcnxpro122_alffPoint170_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint170.tempoccleft
rsfMRI_fcnxpro122_perafPoint170_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint170.tempoccleft
rsfMRI_fcnxpro122_falffPoint171_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint171.tempoccleft
rsfMRI_fcnxpro122_alffPoint171_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint171.tempoccleft
rsfMRI_fcnxpro122_perafPoint171_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint171.tempoccleft
rsfMRI_fcnxpro122_falffPoint172_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint172.tempoccleft
rsfMRI_fcnxpro122_alffPoint172_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint172.tempoccleft
rsfMRI_fcnxpro122_perafPoint172_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint172.tempoccleft
rsfMRI_fcnxpro122_falffPoint173_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint173.tempoccleft
rsfMRI_fcnxpro122_alffPoint173_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint173.tempoccleft
rsfMRI_fcnxpro122_perafPoint173_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint173.tempoccleft
rsfMRI_fcnxpro122_falffPoint174_TempOccleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint174.tempoccleft
rsfMRI_fcnxpro122_alffPoint174_TempOccleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint174.tempoccleft
rsfMRI_fcnxpro122_perafPoint174_TempOccleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint174.tempoccleft
rsfMRI_fcnxpro122_falffPoint175_1left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint175.1left
rsfMRI_fcnxpro122_alffPoint175_1left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint175.1left
rsfMRI_fcnxpro122_perafPoint175_1left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint175.1left
rsfMRI_fcnxpro122_falffPoint176_2left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint176.2left
rsfMRI_fcnxpro122_alffPoint176_2left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint176.2left
rsfMRI_fcnxpro122_perafPoint176_2left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint176.2left
rsfMRI_fcnxpro122_falffPoint177_3left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint177.3left
rsfMRI_fcnxpro122_alffPoint177_3left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint177.3left
rsfMRI_fcnxpro122_perafPoint177_3left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint177.3left
rsfMRI_fcnxpro122_falffPoint178_4left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint178.4left
rsfMRI_fcnxpro122_alffPoint178_4left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint178.4left
rsfMRI_fcnxpro122_perafPoint178_4left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint178.4left
rsfMRI_fcnxpro122_falffPoint179_5left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint179.5left
rsfMRI_fcnxpro122_alffPoint179_5left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint179.5left
rsfMRI_fcnxpro122_perafPoint179_5left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint179.5left
rsfMRI_fcnxpro122_falffPoint180_6left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint180.6left
rsfMRI_fcnxpro122_alffPoint180_6left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint180.6left
rsfMRI_fcnxpro122_perafPoint180_6left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint180.6left
rsfMRI_fcnxpro122_falffPoint181_IPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint181.iplleft
rsfMRI_fcnxpro122_alffPoint181_IPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint181.iplleft
rsfMRI_fcnxpro122_perafPoint181_IPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint181.iplleft
rsfMRI_fcnxpro122_falffPoint182_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint182.insleft
rsfMRI_fcnxpro122_alffPoint182_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint182.insleft
rsfMRI_fcnxpro122_perafPoint182_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint182.insleft
rsfMRI_fcnxpro122_falffPoint183_Insleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint183.insleft
rsfMRI_fcnxpro122_alffPoint183_Insleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint183.insleft
rsfMRI_fcnxpro122_perafPoint183_Insleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint183.insleft
rsfMRI_fcnxpro122_falffPoint184_ParOperleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint184.paroperleft
rsfMRI_fcnxpro122_alffPoint184_ParOperleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint184.paroperleft
rsfMRI_fcnxpro122_perafPoint184_ParOperleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint184.paroperleft
rsfMRI_fcnxpro122_falffPoint185_ParOperleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint185.paroperleft
rsfMRI_fcnxpro122_alffPoint185_ParOperleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint185.paroperleft
rsfMRI_fcnxpro122_perafPoint185_ParOperleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint185.paroperleft
rsfMRI_fcnxpro122_falffPoint186_ParOperleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint186.paroperleft
rsfMRI_fcnxpro122_alffPoint186_ParOperleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint186.paroperleft
rsfMRI_fcnxpro122_perafPoint186_ParOperleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint186.paroperleft
rsfMRI_fcnxpro122_falffPoint187_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint187.stleft
rsfMRI_fcnxpro122_alffPoint187_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint187.stleft
rsfMRI_fcnxpro122_perafPoint187_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint187.stleft
rsfMRI_fcnxpro122_falffPoint188_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint188.stleft
rsfMRI_fcnxpro122_alffPoint188_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint188.stleft
rsfMRI_fcnxpro122_perafPoint188_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint188.stleft
rsfMRI_fcnxpro122_falffPoint189_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint189.stleft
rsfMRI_fcnxpro122_alffPoint189_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint189.stleft
rsfMRI_fcnxpro122_perafPoint189_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint189.stleft
rsfMRI_fcnxpro122_falffPoint190_STleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint190.stleft
rsfMRI_fcnxpro122_alffPoint190_STleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint190.stleft
rsfMRI_fcnxpro122_perafPoint190_STleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint190.stleft
rsfMRI_fcnxpro122_falffPoint191_1left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint191.1left
rsfMRI_fcnxpro122_alffPoint191_1left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint191.1left
rsfMRI_fcnxpro122_perafPoint191_1left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint191.1left
rsfMRI_fcnxpro122_falffPoint192_10left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint192.10left
rsfMRI_fcnxpro122_alffPoint192_10left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint192.10left
rsfMRI_fcnxpro122_perafPoint192_10left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint192.10left
rsfMRI_fcnxpro122_falffPoint193_11left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint193.11left
rsfMRI_fcnxpro122_alffPoint193_11left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint193.11left
rsfMRI_fcnxpro122_perafPoint193_11left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint193.11left
rsfMRI_fcnxpro122_falffPoint194_12left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint194.12left
rsfMRI_fcnxpro122_alffPoint194_12left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint194.12left
rsfMRI_fcnxpro122_perafPoint194_12left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint194.12left
rsfMRI_fcnxpro122_falffPoint195_13left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint195.13left
rsfMRI_fcnxpro122_alffPoint195_13left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint195.13left
rsfMRI_fcnxpro122_perafPoint195_13left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint195.13left
rsfMRI_fcnxpro122_falffPoint196_14left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint196.14left
rsfMRI_fcnxpro122_alffPoint196_14left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint196.14left
rsfMRI_fcnxpro122_perafPoint196_14left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint196.14left
rsfMRI_fcnxpro122_falffPoint197_15left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint197.15left
rsfMRI_fcnxpro122_alffPoint197_15left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint197.15left
rsfMRI_fcnxpro122_perafPoint197_15left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint197.15left
rsfMRI_fcnxpro122_falffPoint198_16left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint198.16left
rsfMRI_fcnxpro122_alffPoint198_16left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint198.16left
rsfMRI_fcnxpro122_perafPoint198_16left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint198.16left
rsfMRI_fcnxpro122_falffPoint199_17left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint199.17left
rsfMRI_fcnxpro122_alffPoint199_17left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint199.17left
rsfMRI_fcnxpro122_perafPoint199_17left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint199.17left
rsfMRI_fcnxpro122_falffPoint200_18left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint200.18left
rsfMRI_fcnxpro122_alffPoint200_18left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint200.18left
rsfMRI_fcnxpro122_perafPoint200_18left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint200.18left
rsfMRI_fcnxpro122_falffPoint201_19left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint201.19left
rsfMRI_fcnxpro122_alffPoint201_19left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint201.19left
rsfMRI_fcnxpro122_perafPoint201_19left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint201.19left
rsfMRI_fcnxpro122_falffPoint202_2left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint202.2left
rsfMRI_fcnxpro122_alffPoint202_2left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint202.2left
rsfMRI_fcnxpro122_perafPoint202_2left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint202.2left
rsfMRI_fcnxpro122_falffPoint203_20left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint203.20left
rsfMRI_fcnxpro122_alffPoint203_20left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint203.20left
rsfMRI_fcnxpro122_perafPoint203_20left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint203.20left
rsfMRI_fcnxpro122_falffPoint204_21left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint204.21left
rsfMRI_fcnxpro122_alffPoint204_21left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint204.21left
rsfMRI_fcnxpro122_perafPoint204_21left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint204.21left
rsfMRI_fcnxpro122_falffPoint205_22left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint205.22left
rsfMRI_fcnxpro122_alffPoint205_22left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint205.22left
rsfMRI_fcnxpro122_perafPoint205_22left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint205.22left
rsfMRI_fcnxpro122_falffPoint206_23left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint206.23left
rsfMRI_fcnxpro122_alffPoint206_23left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint206.23left
rsfMRI_fcnxpro122_perafPoint206_23left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint206.23left
rsfMRI_fcnxpro122_falffPoint207_24left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint207.24left
rsfMRI_fcnxpro122_alffPoint207_24left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint207.24left
rsfMRI_fcnxpro122_perafPoint207_24left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint207.24left
rsfMRI_fcnxpro122_falffPoint208_25left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint208.25left
rsfMRI_fcnxpro122_alffPoint208_25left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint208.25left
rsfMRI_fcnxpro122_perafPoint208_25left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint208.25left
rsfMRI_fcnxpro122_falffPoint209_26left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint209.26left
rsfMRI_fcnxpro122_alffPoint209_26left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint209.26left
rsfMRI_fcnxpro122_perafPoint209_26left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint209.26left
rsfMRI_fcnxpro122_falffPoint210_27left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint210.27left
rsfMRI_fcnxpro122_alffPoint210_27left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint210.27left
rsfMRI_fcnxpro122_perafPoint210_27left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint210.27left
rsfMRI_fcnxpro122_falffPoint211_28left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint211.28left
rsfMRI_fcnxpro122_alffPoint211_28left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint211.28left
rsfMRI_fcnxpro122_perafPoint211_28left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint211.28left
rsfMRI_fcnxpro122_falffPoint212_29left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint212.29left
rsfMRI_fcnxpro122_alffPoint212_29left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint212.29left
rsfMRI_fcnxpro122_perafPoint212_29left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint212.29left
rsfMRI_fcnxpro122_falffPoint213_3left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint213.3left
rsfMRI_fcnxpro122_alffPoint213_3left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint213.3left
rsfMRI_fcnxpro122_perafPoint213_3left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint213.3left
rsfMRI_fcnxpro122_falffPoint214_4left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint214.4left
rsfMRI_fcnxpro122_alffPoint214_4left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint214.4left
rsfMRI_fcnxpro122_perafPoint214_4left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint214.4left
rsfMRI_fcnxpro122_falffPoint215_5left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint215.5left
rsfMRI_fcnxpro122_alffPoint215_5left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint215.5left
rsfMRI_fcnxpro122_perafPoint215_5left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint215.5left
rsfMRI_fcnxpro122_falffPoint216_6left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint216.6left
rsfMRI_fcnxpro122_alffPoint216_6left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint216.6left
rsfMRI_fcnxpro122_perafPoint216_6left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint216.6left
rsfMRI_fcnxpro122_falffPoint217_7left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint217.7left
rsfMRI_fcnxpro122_alffPoint217_7left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint217.7left
rsfMRI_fcnxpro122_perafPoint217_7left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint217.7left
rsfMRI_fcnxpro122_falffPoint218_8left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint218.8left
rsfMRI_fcnxpro122_alffPoint218_8left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint218.8left
rsfMRI_fcnxpro122_perafPoint218_8left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint218.8left
rsfMRI_fcnxpro122_falffPoint219_9left
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint219.9left
rsfMRI_fcnxpro122_alffPoint219_9left
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint219.9left
rsfMRI_fcnxpro122_perafPoint219_9left
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint219.9left
rsfMRI_fcnxpro122_falffPoint220_SPLleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint220.splleft
rsfMRI_fcnxpro122_alffPoint220_SPLleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint220.splleft
rsfMRI_fcnxpro122_perafPoint220_SPLleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint220.splleft
rsfMRI_fcnxpro122_falffPoint221_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint221.exstrleft
rsfMRI_fcnxpro122_alffPoint221_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint221.exstrleft
rsfMRI_fcnxpro122_perafPoint221_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint221.exstrleft
rsfMRI_fcnxpro122_falffPoint222_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint222.exstrinfleft
rsfMRI_fcnxpro122_alffPoint222_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint222.exstrinfleft
rsfMRI_fcnxpro122_perafPoint222_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint222.exstrinfleft
rsfMRI_fcnxpro122_falffPoint223_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint223.exstrinfleft
rsfMRI_fcnxpro122_alffPoint223_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint223.exstrinfleft
rsfMRI_fcnxpro122_perafPoint223_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint223.exstrinfleft
rsfMRI_fcnxpro122_falffPoint224_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint224.exstrinfleft
rsfMRI_fcnxpro122_alffPoint224_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint224.exstrinfleft
rsfMRI_fcnxpro122_perafPoint224_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint224.exstrinfleft
rsfMRI_fcnxpro122_falffPoint225_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint225.exstrinfleft
rsfMRI_fcnxpro122_alffPoint225_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint225.exstrinfleft
rsfMRI_fcnxpro122_perafPoint225_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint225.exstrinfleft
rsfMRI_fcnxpro122_falffPoint226_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint226.exstrinfleft
rsfMRI_fcnxpro122_alffPoint226_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint226.exstrinfleft
rsfMRI_fcnxpro122_perafPoint226_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint226.exstrinfleft
rsfMRI_fcnxpro122_falffPoint227_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint227.exstrsupleft
rsfMRI_fcnxpro122_alffPoint227_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint227.exstrsupleft
rsfMRI_fcnxpro122_perafPoint227_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint227.exstrsupleft
rsfMRI_fcnxpro122_falffPoint228_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint228.exstrsupleft
rsfMRI_fcnxpro122_alffPoint228_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint228.exstrsupleft
rsfMRI_fcnxpro122_perafPoint228_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint228.exstrsupleft
rsfMRI_fcnxpro122_falffPoint229_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint229.exstrsupleft
rsfMRI_fcnxpro122_alffPoint229_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint229.exstrsupleft
rsfMRI_fcnxpro122_perafPoint229_ExStrSupleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint229.exstrsupleft
rsfMRI_fcnxpro122_falffPoint230_Striateleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint230.striateleft
rsfMRI_fcnxpro122_alffPoint230_Striateleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint230.striateleft
rsfMRI_fcnxpro122_perafPoint230_Striateleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint230.striateleft
rsfMRI_fcnxpro122_falffPoint231_Striateleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint231.striateleft
rsfMRI_fcnxpro122_alffPoint231_Striateleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint231.striateleft
rsfMRI_fcnxpro122_perafPoint231_Striateleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint231.striateleft
rsfMRI_fcnxpro122_falffPoint232_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint232.exstrinfleft
rsfMRI_fcnxpro122_alffPoint232_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint232.exstrinfleft
rsfMRI_fcnxpro122_perafPoint232_ExStrInfleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint232.exstrinfleft
rsfMRI_fcnxpro122_falffPoint233_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint233.exstrleft
rsfMRI_fcnxpro122_alffPoint233_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint233.exstrleft
rsfMRI_fcnxpro122_perafPoint233_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint233.exstrleft
rsfMRI_fcnxpro122_falffPoint234_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint234.exstrleft
rsfMRI_fcnxpro122_alffPoint234_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint234.exstrleft
rsfMRI_fcnxpro122_perafPoint234_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint234.exstrleft
rsfMRI_fcnxpro122_falffPoint235_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint235.exstrleft
rsfMRI_fcnxpro122_alffPoint235_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint235.exstrleft
rsfMRI_fcnxpro122_perafPoint235_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint235.exstrleft
rsfMRI_fcnxpro122_falffPoint236_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint236.exstrleft
rsfMRI_fcnxpro122_alffPoint236_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint236.exstrleft
rsfMRI_fcnxpro122_perafPoint236_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint236.exstrleft
rsfMRI_fcnxpro122_falffPoint237_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint237.exstrleft
rsfMRI_fcnxpro122_alffPoint237_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint237.exstrleft
rsfMRI_fcnxpro122_perafPoint237_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint237.exstrleft
rsfMRI_fcnxpro122_falffPoint238_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint238.exstrleft
rsfMRI_fcnxpro122_alffPoint238_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint238.exstrleft
rsfMRI_fcnxpro122_perafPoint238_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint238.exstrleft
rsfMRI_fcnxpro122_falffPoint239_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint239.exstrleft
rsfMRI_fcnxpro122_alffPoint239_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint239.exstrleft
rsfMRI_fcnxpro122_perafPoint239_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint239.exstrleft
rsfMRI_fcnxpro122_falffPoint240_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint240.exstrleft
rsfMRI_fcnxpro122_alffPoint240_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint240.exstrleft
rsfMRI_fcnxpro122_perafPoint240_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint240.exstrleft
rsfMRI_fcnxpro122_falffPoint241_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint241.exstrleft
rsfMRI_fcnxpro122_alffPoint241_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint241.exstrleft
rsfMRI_fcnxpro122_perafPoint241_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint241.exstrleft
rsfMRI_fcnxpro122_falffPoint242_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint242.exstrleft
rsfMRI_fcnxpro122_alffPoint242_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint242.exstrleft
rsfMRI_fcnxpro122_perafPoint242_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint242.exstrleft
rsfMRI_fcnxpro122_falffPoint243_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint243.exstrleft
rsfMRI_fcnxpro122_alffPoint243_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint243.exstrleft
rsfMRI_fcnxpro122_perafPoint243_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint243.exstrleft
rsfMRI_fcnxpro122_falffPoint244_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint244.exstrleft
rsfMRI_fcnxpro122_alffPoint244_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint244.exstrleft
rsfMRI_fcnxpro122_perafPoint244_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint244.exstrleft
rsfMRI_fcnxpro122_falffPoint245_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint245.exstrleft
rsfMRI_fcnxpro122_alffPoint245_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint245.exstrleft
rsfMRI_fcnxpro122_perafPoint245_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint245.exstrleft
rsfMRI_fcnxpro122_falffPoint246_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint246.exstrleft
rsfMRI_fcnxpro122_alffPoint246_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint246.exstrleft
rsfMRI_fcnxpro122_perafPoint246_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint246.exstrleft
rsfMRI_fcnxpro122_falffPoint247_ExStrleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint247.exstrleft
rsfMRI_fcnxpro122_alffPoint247_ExStrleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint247.exstrleft
rsfMRI_fcnxpro122_perafPoint247_ExStrleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint247.exstrleft
rsfMRI_fcnxpro122_falffPoint248_Striateleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint248.striateleft
rsfMRI_fcnxpro122_alffPoint248_Striateleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint248.striateleft
rsfMRI_fcnxpro122_perafPoint248_Striateleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint248.striateleft
rsfMRI_fcnxpro122_falffPoint249_Striateleft
restingStatefMRI
left
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint249.striateleft
rsfMRI_fcnxpro122_alffPoint249_Striateleft
restingStatefMRI
left
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint249.striateleft
rsfMRI_fcnxpro122_perafPoint249_Striateleft
restingStatefMRI
left
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint249.striateleft
rsfMRI_fcnxpro122_falffPoint000_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint000.iplright
rsfMRI_fcnxpro122_alffPoint000_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint000.iplright
rsfMRI_fcnxpro122_perafPoint000_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint000.iplright
rsfMRI_fcnxpro122_falffPoint001_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint001.stright
rsfMRI_fcnxpro122_alffPoint001_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint001.stright
rsfMRI_fcnxpro122_perafPoint001_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint001.stright
rsfMRI_fcnxpro122_falffPoint002_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint002.stright
rsfMRI_fcnxpro122_alffPoint002_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint002.stright
rsfMRI_fcnxpro122_perafPoint002_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint002.stright
rsfMRI_fcnxpro122_falffPoint003_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint003.tempoccright
rsfMRI_fcnxpro122_alffPoint003_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint003.tempoccright
rsfMRI_fcnxpro122_perafPoint003_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint003.tempoccright
rsfMRI_fcnxpro122_falffPoint004_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint004.tempright
rsfMRI_fcnxpro122_alffPoint004_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint004.tempright
rsfMRI_fcnxpro122_perafPoint004_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint004.tempright
rsfMRI_fcnxpro122_falffPoint005_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint005.tempright
rsfMRI_fcnxpro122_alffPoint005_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint005.tempright
rsfMRI_fcnxpro122_perafPoint005_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint005.tempright
rsfMRI_fcnxpro122_falffPoint006_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint006.exstrinfright
rsfMRI_fcnxpro122_alffPoint006_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint006.exstrinfright
rsfMRI_fcnxpro122_perafPoint006_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint006.exstrinfright
rsfMRI_fcnxpro122_falffPoint007_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint007.iplright
rsfMRI_fcnxpro122_alffPoint007_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint007.iplright
rsfMRI_fcnxpro122_perafPoint007_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint007.iplright
rsfMRI_fcnxpro122_falffPoint008_PHCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint008.phcright
rsfMRI_fcnxpro122_alffPoint008_PHCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint008.phcright
rsfMRI_fcnxpro122_perafPoint008_PHCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint008.phcright
rsfMRI_fcnxpro122_falffPoint009_PHCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint009.phcright
rsfMRI_fcnxpro122_alffPoint009_PHCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint009.phcright
rsfMRI_fcnxpro122_perafPoint009_PHCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint009.phcright
rsfMRI_fcnxpro122_falffPoint010_PHCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint010.phcright
rsfMRI_fcnxpro122_alffPoint010_PHCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint010.phcright
rsfMRI_fcnxpro122_perafPoint010_PHCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint010.phcright
rsfMRI_fcnxpro122_falffPoint011_RSCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint011.rscright
rsfMRI_fcnxpro122_alffPoint011_RSCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint011.rscright
rsfMRI_fcnxpro122_perafPoint011_RSCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint011.rscright
rsfMRI_fcnxpro122_falffPoint012_RSCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint012.rscright
rsfMRI_fcnxpro122_alffPoint012_RSCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint012.rscright
rsfMRI_fcnxpro122_perafPoint012_RSCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint012.rscright
rsfMRI_fcnxpro122_falffPoint013_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint013.iplright
rsfMRI_fcnxpro122_alffPoint013_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint013.iplright
rsfMRI_fcnxpro122_perafPoint013_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint013.iplright
rsfMRI_fcnxpro122_falffPoint014_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint014.iplright
rsfMRI_fcnxpro122_alffPoint014_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint014.iplright
rsfMRI_fcnxpro122_perafPoint014_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint014.iplright
rsfMRI_fcnxpro122_falffPoint015_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint015.iplright
rsfMRI_fcnxpro122_alffPoint015_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint015.iplright
rsfMRI_fcnxpro122_perafPoint015_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint015.iplright
rsfMRI_fcnxpro122_falffPoint016_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint016.iplright
rsfMRI_fcnxpro122_alffPoint016_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint016.iplright
rsfMRI_fcnxpro122_perafPoint016_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint016.iplright
rsfMRI_fcnxpro122_falffPoint017_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint017.pfcdright
rsfMRI_fcnxpro122_alffPoint017_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint017.pfcdright
rsfMRI_fcnxpro122_perafPoint017_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint017.pfcdright
rsfMRI_fcnxpro122_falffPoint018_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint018.pfcdright
rsfMRI_fcnxpro122_alffPoint018_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint018.pfcdright
rsfMRI_fcnxpro122_perafPoint018_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint018.pfcdright
rsfMRI_fcnxpro122_falffPoint019_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint019.pfcdright
rsfMRI_fcnxpro122_alffPoint019_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint019.pfcdright
rsfMRI_fcnxpro122_perafPoint019_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint019.pfcdright
rsfMRI_fcnxpro122_falffPoint020_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint020.pfcdright
rsfMRI_fcnxpro122_alffPoint020_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint020.pfcdright
rsfMRI_fcnxpro122_perafPoint020_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint020.pfcdright
rsfMRI_fcnxpro122_falffPoint021_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint021.pfcdright
rsfMRI_fcnxpro122_alffPoint021_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint021.pfcdright
rsfMRI_fcnxpro122_perafPoint021_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint021.pfcdright
rsfMRI_fcnxpro122_falffPoint022_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint022.pfcdright
rsfMRI_fcnxpro122_alffPoint022_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint022.pfcdright
rsfMRI_fcnxpro122_perafPoint022_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint022.pfcdright
rsfMRI_fcnxpro122_falffPoint023_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint023.pfcdright
rsfMRI_fcnxpro122_alffPoint023_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint023.pfcdright
rsfMRI_fcnxpro122_perafPoint023_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint023.pfcdright
rsfMRI_fcnxpro122_falffPoint024_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint024.pfclright
rsfMRI_fcnxpro122_alffPoint024_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint024.pfclright
rsfMRI_fcnxpro122_perafPoint024_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint024.pfclright
rsfMRI_fcnxpro122_falffPoint025_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint025.pfclright
rsfMRI_fcnxpro122_alffPoint025_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint025.pfclright
rsfMRI_fcnxpro122_perafPoint025_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint025.pfclright
rsfMRI_fcnxpro122_falffPoint026_PFCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint026.pfcvright
rsfMRI_fcnxpro122_alffPoint026_PFCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint026.pfcvright
rsfMRI_fcnxpro122_perafPoint026_PFCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint026.pfcvright
rsfMRI_fcnxpro122_falffPoint027_PFCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint027.pfcvright
rsfMRI_fcnxpro122_alffPoint027_PFCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint027.pfcvright
rsfMRI_fcnxpro122_perafPoint027_PFCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint027.pfcvright
rsfMRI_fcnxpro122_falffPoint028_PFCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint028.pfcvright
rsfMRI_fcnxpro122_alffPoint028_PFCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint028.pfcvright
rsfMRI_fcnxpro122_perafPoint028_PFCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint028.pfcvright
rsfMRI_fcnxpro122_falffPoint029_PFCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint029.pfcvright
rsfMRI_fcnxpro122_alffPoint029_PFCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint029.pfcvright
rsfMRI_fcnxpro122_perafPoint029_PFCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint029.pfcvright
rsfMRI_fcnxpro122_falffPoint030_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint030.temppoleright
rsfMRI_fcnxpro122_alffPoint030_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint030.temppoleright
rsfMRI_fcnxpro122_perafPoint030_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint030.temppoleright
rsfMRI_fcnxpro122_falffPoint031_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint031.tempright
rsfMRI_fcnxpro122_alffPoint031_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint031.tempright
rsfMRI_fcnxpro122_perafPoint031_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint031.tempright
rsfMRI_fcnxpro122_falffPoint032_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint032.tempright
rsfMRI_fcnxpro122_alffPoint032_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint032.tempright
rsfMRI_fcnxpro122_perafPoint032_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint032.tempright
rsfMRI_fcnxpro122_falffPoint033_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint033.tempright
rsfMRI_fcnxpro122_alffPoint033_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint033.tempright
rsfMRI_fcnxpro122_perafPoint033_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint033.tempright
rsfMRI_fcnxpro122_falffPoint034_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint034.tempright
rsfMRI_fcnxpro122_alffPoint034_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint034.tempright
rsfMRI_fcnxpro122_perafPoint034_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint034.tempright
rsfMRI_fcnxpro122_falffPoint035_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint035.tempright
rsfMRI_fcnxpro122_alffPoint035_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint035.tempright
rsfMRI_fcnxpro122_perafPoint035_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint035.tempright
rsfMRI_fcnxpro122_falffPoint036_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint036.tempright
rsfMRI_fcnxpro122_alffPoint036_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint036.tempright
rsfMRI_fcnxpro122_perafPoint036_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint036.tempright
rsfMRI_fcnxpro122_falffPoint037_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint037.tempright
rsfMRI_fcnxpro122_alffPoint037_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint037.tempright
rsfMRI_fcnxpro122_perafPoint037_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint037.tempright
rsfMRI_fcnxpro122_falffPoint038_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint038.tempright
rsfMRI_fcnxpro122_alffPoint038_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint038.tempright
rsfMRI_fcnxpro122_perafPoint038_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint038.tempright
rsfMRI_fcnxpro122_falffPoint039_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint039.tempright
rsfMRI_fcnxpro122_alffPoint039_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint039.tempright
rsfMRI_fcnxpro122_perafPoint039_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint039.tempright
rsfMRI_fcnxpro122_falffPoint040_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint040.tempright
rsfMRI_fcnxpro122_alffPoint040_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint040.tempright
rsfMRI_fcnxpro122_perafPoint040_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint040.tempright
rsfMRI_fcnxpro122_falffPoint041_FPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint041.fpoleright
rsfMRI_fcnxpro122_alffPoint041_FPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint041.fpoleright
rsfMRI_fcnxpro122_perafPoint041_FPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint041.fpoleright
rsfMRI_fcnxpro122_falffPoint042_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint042.iplright
rsfMRI_fcnxpro122_alffPoint042_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint042.iplright
rsfMRI_fcnxpro122_perafPoint042_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint042.iplright
rsfMRI_fcnxpro122_falffPoint043_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint043.iplright
rsfMRI_fcnxpro122_alffPoint043_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint043.iplright
rsfMRI_fcnxpro122_perafPoint043_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint043.iplright
rsfMRI_fcnxpro122_falffPoint044_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint044.iplright
rsfMRI_fcnxpro122_alffPoint044_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint044.iplright
rsfMRI_fcnxpro122_perafPoint044_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint044.iplright
rsfMRI_fcnxpro122_falffPoint045_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint045.pccright
rsfMRI_fcnxpro122_alffPoint045_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint045.pccright
rsfMRI_fcnxpro122_perafPoint045_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint045.pccright
rsfMRI_fcnxpro122_falffPoint046_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint046.pccright
rsfMRI_fcnxpro122_alffPoint046_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint046.pccright
rsfMRI_fcnxpro122_perafPoint046_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint046.pccright
rsfMRI_fcnxpro122_falffPoint047_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint047.pccright
rsfMRI_fcnxpro122_alffPoint047_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint047.pccright
rsfMRI_fcnxpro122_perafPoint047_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint047.pccright
rsfMRI_fcnxpro122_falffPoint048_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint048.pccright
rsfMRI_fcnxpro122_alffPoint048_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint048.pccright
rsfMRI_fcnxpro122_perafPoint048_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint048.pccright
rsfMRI_fcnxpro122_falffPoint049_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint049.pccright
rsfMRI_fcnxpro122_alffPoint049_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint049.pccright
rsfMRI_fcnxpro122_perafPoint049_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint049.pccright
rsfMRI_fcnxpro122_falffPoint050_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint050.pccright
rsfMRI_fcnxpro122_alffPoint050_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint050.pccright
rsfMRI_fcnxpro122_perafPoint050_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint050.pccright
rsfMRI_fcnxpro122_falffPoint051_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint051.pccright
rsfMRI_fcnxpro122_alffPoint051_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint051.pccright
rsfMRI_fcnxpro122_perafPoint051_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint051.pccright
rsfMRI_fcnxpro122_falffPoint052_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint052.pfcdright
rsfMRI_fcnxpro122_alffPoint052_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint052.pfcdright
rsfMRI_fcnxpro122_perafPoint052_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint052.pfcdright
rsfMRI_fcnxpro122_falffPoint053_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint053.pfcdright
rsfMRI_fcnxpro122_alffPoint053_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint053.pfcdright
rsfMRI_fcnxpro122_perafPoint053_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint053.pfcdright
rsfMRI_fcnxpro122_falffPoint054_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint054.pfcdright
rsfMRI_fcnxpro122_alffPoint054_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint054.pfcdright
rsfMRI_fcnxpro122_perafPoint054_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint054.pfcdright
rsfMRI_fcnxpro122_falffPoint055_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint055.pfcdright
rsfMRI_fcnxpro122_alffPoint055_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint055.pfcdright
rsfMRI_fcnxpro122_perafPoint055_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint055.pfcdright
rsfMRI_fcnxpro122_falffPoint056_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint056.pfcmright
rsfMRI_fcnxpro122_alffPoint056_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint056.pfcmright
rsfMRI_fcnxpro122_perafPoint056_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint056.pfcmright
rsfMRI_fcnxpro122_falffPoint057_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint057.pfcmright
rsfMRI_fcnxpro122_alffPoint057_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint057.pfcmright
rsfMRI_fcnxpro122_perafPoint057_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint057.pfcmright
rsfMRI_fcnxpro122_falffPoint058_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint058.pfcmright
rsfMRI_fcnxpro122_alffPoint058_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint058.pfcmright
rsfMRI_fcnxpro122_perafPoint058_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint058.pfcmright
rsfMRI_fcnxpro122_falffPoint059_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint059.pfcmright
rsfMRI_fcnxpro122_alffPoint059_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint059.pfcmright
rsfMRI_fcnxpro122_perafPoint059_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint059.pfcmright
rsfMRI_fcnxpro122_falffPoint060_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint060.pfcmright
rsfMRI_fcnxpro122_alffPoint060_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint060.pfcmright
rsfMRI_fcnxpro122_perafPoint060_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint060.pfcmright
rsfMRI_fcnxpro122_falffPoint061_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint061.pcunright
rsfMRI_fcnxpro122_alffPoint061_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint061.pcunright
rsfMRI_fcnxpro122_perafPoint061_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint061.pcunright
rsfMRI_fcnxpro122_falffPoint062_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint062.pcunright
rsfMRI_fcnxpro122_alffPoint062_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint062.pcunright
rsfMRI_fcnxpro122_perafPoint062_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint062.pcunright
rsfMRI_fcnxpro122_falffPoint063_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint063.pcunright
rsfMRI_fcnxpro122_alffPoint063_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint063.pcunright
rsfMRI_fcnxpro122_perafPoint063_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint063.pcunright
rsfMRI_fcnxpro122_falffPoint064_PCCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint064.pccright
rsfMRI_fcnxpro122_alffPoint064_PCCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint064.pccright
rsfMRI_fcnxpro122_perafPoint064_PCCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint064.pccright
rsfMRI_fcnxpro122_falffPoint065_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint065.splright
rsfMRI_fcnxpro122_alffPoint065_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint065.splright
rsfMRI_fcnxpro122_perafPoint065_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint065.splright
rsfMRI_fcnxpro122_falffPoint066_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint066.pcunright
rsfMRI_fcnxpro122_alffPoint066_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint066.pcunright
rsfMRI_fcnxpro122_perafPoint066_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint066.pcunright
rsfMRI_fcnxpro122_falffPoint067_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint067.pcunright
rsfMRI_fcnxpro122_alffPoint067_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint067.pcunright
rsfMRI_fcnxpro122_perafPoint067_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint067.pcunright
rsfMRI_fcnxpro122_falffPoint068_pCunright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint068.pcunright
rsfMRI_fcnxpro122_alffPoint068_pCunright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint068.pcunright
rsfMRI_fcnxpro122_perafPoint068_pCunright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint068.pcunright
rsfMRI_fcnxpro122_falffPoint069_FPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint069.fpoleright
rsfMRI_fcnxpro122_alffPoint069_FPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint069.fpoleright
rsfMRI_fcnxpro122_perafPoint069_FPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint069.fpoleright
rsfMRI_fcnxpro122_falffPoint070_FPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint070.fpoleright
rsfMRI_fcnxpro122_alffPoint070_FPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint070.fpoleright
rsfMRI_fcnxpro122_perafPoint070_FPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint070.fpoleright
rsfMRI_fcnxpro122_falffPoint071_FrMedright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint071.frmedright
rsfMRI_fcnxpro122_alffPoint071_FrMedright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint071.frmedright
rsfMRI_fcnxpro122_perafPoint071_FrMedright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint071.frmedright
rsfMRI_fcnxpro122_falffPoint072_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint072.iplright
rsfMRI_fcnxpro122_alffPoint072_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint072.iplright
rsfMRI_fcnxpro122_perafPoint072_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint072.iplright
rsfMRI_fcnxpro122_falffPoint073_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint073.ipsright
rsfMRI_fcnxpro122_alffPoint073_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint073.ipsright
rsfMRI_fcnxpro122_perafPoint073_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint073.ipsright
rsfMRI_fcnxpro122_falffPoint074_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint074.ipsright
rsfMRI_fcnxpro122_alffPoint074_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint074.ipsright
rsfMRI_fcnxpro122_perafPoint074_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint074.ipsright
rsfMRI_fcnxpro122_falffPoint075_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint075.pfcdright
rsfMRI_fcnxpro122_alffPoint075_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint075.pfcdright
rsfMRI_fcnxpro122_perafPoint075_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint075.pfcdright
rsfMRI_fcnxpro122_falffPoint076_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint076.pfclright
rsfMRI_fcnxpro122_alffPoint076_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint076.pfclright
rsfMRI_fcnxpro122_perafPoint076_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint076.pfclright
rsfMRI_fcnxpro122_falffPoint077_PFCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint077.pfcvright
rsfMRI_fcnxpro122_alffPoint077_PFCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint077.pfcvright
rsfMRI_fcnxpro122_perafPoint077_PFCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint077.pfcvright
rsfMRI_fcnxpro122_falffPoint078_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint078.tempright
rsfMRI_fcnxpro122_alffPoint078_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint078.tempright
rsfMRI_fcnxpro122_perafPoint078_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint078.tempright
rsfMRI_fcnxpro122_falffPoint079_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint079.tempright
rsfMRI_fcnxpro122_alffPoint079_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint079.tempright
rsfMRI_fcnxpro122_perafPoint079_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint079.tempright
rsfMRI_fcnxpro122_falffPoint080_Cingmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint080.cingmright
rsfMRI_fcnxpro122_alffPoint080_Cingmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint080.cingmright
rsfMRI_fcnxpro122_perafPoint080_Cingmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint080.cingmright
rsfMRI_fcnxpro122_falffPoint081_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint081.ipsright
rsfMRI_fcnxpro122_alffPoint081_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint081.ipsright
rsfMRI_fcnxpro122_perafPoint081_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint081.ipsright
rsfMRI_fcnxpro122_falffPoint082_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint082.ipsright
rsfMRI_fcnxpro122_alffPoint082_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint082.ipsright
rsfMRI_fcnxpro122_perafPoint082_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint082.ipsright
rsfMRI_fcnxpro122_falffPoint083_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint083.ipsright
rsfMRI_fcnxpro122_alffPoint083_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint083.ipsright
rsfMRI_fcnxpro122_perafPoint083_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint083.ipsright
rsfMRI_fcnxpro122_falffPoint084_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint084.ipsright
rsfMRI_fcnxpro122_alffPoint084_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint084.ipsright
rsfMRI_fcnxpro122_perafPoint084_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint084.ipsright
rsfMRI_fcnxpro122_falffPoint085_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint085.ipsright
rsfMRI_fcnxpro122_alffPoint085_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint085.ipsright
rsfMRI_fcnxpro122_perafPoint085_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint085.ipsright
rsfMRI_fcnxpro122_falffPoint086_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint086.pfcdright
rsfMRI_fcnxpro122_alffPoint086_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint086.pfcdright
rsfMRI_fcnxpro122_perafPoint086_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint086.pfcdright
rsfMRI_fcnxpro122_falffPoint087_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint087.pfclright
rsfMRI_fcnxpro122_alffPoint087_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint087.pfclright
rsfMRI_fcnxpro122_perafPoint087_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint087.pfclright
rsfMRI_fcnxpro122_falffPoint088_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint088.pfclright
rsfMRI_fcnxpro122_alffPoint088_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint088.pfclright
rsfMRI_fcnxpro122_perafPoint088_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint088.pfclright
rsfMRI_fcnxpro122_falffPoint089_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint089.pfclright
rsfMRI_fcnxpro122_alffPoint089_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint089.pfclright
rsfMRI_fcnxpro122_perafPoint089_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint089.pfclright
rsfMRI_fcnxpro122_falffPoint090_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint090.pfclright
rsfMRI_fcnxpro122_alffPoint090_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint090.pfclright
rsfMRI_fcnxpro122_perafPoint090_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint090.pfclright
rsfMRI_fcnxpro122_falffPoint091_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint091.pfclright
rsfMRI_fcnxpro122_alffPoint091_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint091.pfclright
rsfMRI_fcnxpro122_perafPoint091_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint091.pfclright
rsfMRI_fcnxpro122_falffPoint092_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint092.pfclright
rsfMRI_fcnxpro122_alffPoint092_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint092.pfclright
rsfMRI_fcnxpro122_perafPoint092_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint092.pfclright
rsfMRI_fcnxpro122_falffPoint093_PrCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint093.prcvright
rsfMRI_fcnxpro122_alffPoint093_PrCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint093.prcvright
rsfMRI_fcnxpro122_perafPoint093_PrCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint093.prcvright
rsfMRI_fcnxpro122_falffPoint094_PrCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint094.prcvright
rsfMRI_fcnxpro122_alffPoint094_PrCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint094.prcvright
rsfMRI_fcnxpro122_perafPoint094_PrCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint094.prcvright
rsfMRI_fcnxpro122_falffPoint095_PrCvright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint095.prcvright
rsfMRI_fcnxpro122_alffPoint095_PrCvright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint095.prcvright
rsfMRI_fcnxpro122_perafPoint095_PrCvright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint095.prcvright
rsfMRI_fcnxpro122_falffPoint096_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint096.splright
rsfMRI_fcnxpro122_alffPoint096_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint096.splright
rsfMRI_fcnxpro122_perafPoint096_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint096.splright
rsfMRI_fcnxpro122_falffPoint097_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint097.tempoccright
rsfMRI_fcnxpro122_alffPoint097_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint097.tempoccright
rsfMRI_fcnxpro122_perafPoint097_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint097.tempoccright
rsfMRI_fcnxpro122_falffPoint098_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint098.insright
rsfMRI_fcnxpro122_alffPoint098_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint098.insright
rsfMRI_fcnxpro122_perafPoint098_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint098.insright
rsfMRI_fcnxpro122_falffPoint099_PHCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint099.phcright
rsfMRI_fcnxpro122_alffPoint099_PHCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint099.phcright
rsfMRI_fcnxpro122_perafPoint099_PHCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint099.phcright
rsfMRI_fcnxpro122_falffPoint100_PHCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint100.phcright
rsfMRI_fcnxpro122_alffPoint100_PHCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint100.phcright
rsfMRI_fcnxpro122_perafPoint100_PHCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint100.phcright
rsfMRI_fcnxpro122_falffPoint101_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint101.stright
rsfMRI_fcnxpro122_alffPoint101_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint101.stright
rsfMRI_fcnxpro122_perafPoint101_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint101.stright
rsfMRI_fcnxpro122_falffPoint102_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint102.temppoleright
rsfMRI_fcnxpro122_alffPoint102_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint102.temppoleright
rsfMRI_fcnxpro122_perafPoint102_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint102.temppoleright
rsfMRI_fcnxpro122_falffPoint103_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint103.temppoleright
rsfMRI_fcnxpro122_alffPoint103_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint103.temppoleright
rsfMRI_fcnxpro122_perafPoint103_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint103.temppoleright
rsfMRI_fcnxpro122_falffPoint104_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint104.temppoleright
rsfMRI_fcnxpro122_alffPoint104_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint104.temppoleright
rsfMRI_fcnxpro122_perafPoint104_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint104.temppoleright
rsfMRI_fcnxpro122_falffPoint105_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint105.temppoleright
rsfMRI_fcnxpro122_alffPoint105_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint105.temppoleright
rsfMRI_fcnxpro122_perafPoint105_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint105.temppoleright
rsfMRI_fcnxpro122_falffPoint106_TempPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint106.temppoleright
rsfMRI_fcnxpro122_alffPoint106_TempPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint106.temppoleright
rsfMRI_fcnxpro122_perafPoint106_TempPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint106.temppoleright
rsfMRI_fcnxpro122_falffPoint107_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint107.tempright
rsfMRI_fcnxpro122_alffPoint107_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint107.tempright
rsfMRI_fcnxpro122_perafPoint107_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint107.tempright
rsfMRI_fcnxpro122_falffPoint108_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint108.tempright
rsfMRI_fcnxpro122_alffPoint108_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint108.tempright
rsfMRI_fcnxpro122_perafPoint108_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint108.tempright
rsfMRI_fcnxpro122_falffPoint109_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint109.tempright
rsfMRI_fcnxpro122_alffPoint109_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint109.tempright
rsfMRI_fcnxpro122_perafPoint109_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint109.tempright
rsfMRI_fcnxpro122_falffPoint110_Tempright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint110.tempright
rsfMRI_fcnxpro122_alffPoint110_Tempright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint110.tempright
rsfMRI_fcnxpro122_perafPoint110_Tempright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint110.tempright
rsfMRI_fcnxpro122_falffPoint111_FPoleright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint111.fpoleright
rsfMRI_fcnxpro122_alffPoint111_FPoleright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint111.fpoleright
rsfMRI_fcnxpro122_perafPoint111_FPoleright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint111.fpoleright
rsfMRI_fcnxpro122_falffPoint112_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint112.ofcright
rsfMRI_fcnxpro122_alffPoint112_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint112.ofcright
rsfMRI_fcnxpro122_perafPoint112_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint112.ofcright
rsfMRI_fcnxpro122_falffPoint113_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint113.ofcright
rsfMRI_fcnxpro122_alffPoint113_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint113.ofcright
rsfMRI_fcnxpro122_perafPoint113_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint113.ofcright
rsfMRI_fcnxpro122_falffPoint114_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint114.ofcright
rsfMRI_fcnxpro122_alffPoint114_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint114.ofcright
rsfMRI_fcnxpro122_perafPoint114_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint114.ofcright
rsfMRI_fcnxpro122_falffPoint115_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint115.ofcright
rsfMRI_fcnxpro122_alffPoint115_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint115.ofcright
rsfMRI_fcnxpro122_perafPoint115_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint115.ofcright
rsfMRI_fcnxpro122_falffPoint116_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint116.ofcright
rsfMRI_fcnxpro122_alffPoint116_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint116.ofcright
rsfMRI_fcnxpro122_perafPoint116_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint116.ofcright
rsfMRI_fcnxpro122_falffPoint117_OFCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint117.ofcright
rsfMRI_fcnxpro122_alffPoint117_OFCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint117.ofcright
rsfMRI_fcnxpro122_perafPoint117_OFCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint117.ofcright
rsfMRI_fcnxpro122_falffPoint118_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint118.pfcmright
rsfMRI_fcnxpro122_alffPoint118_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint118.pfcmright
rsfMRI_fcnxpro122_perafPoint118_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint118.pfcmright
rsfMRI_fcnxpro122_falffPoint119_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint119.pfcmright
rsfMRI_fcnxpro122_alffPoint119_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint119.pfcmright
rsfMRI_fcnxpro122_perafPoint119_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint119.pfcmright
rsfMRI_fcnxpro122_falffPoint120_FrMedright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint120.frmedright
rsfMRI_fcnxpro122_alffPoint120_FrMedright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint120.frmedright
rsfMRI_fcnxpro122_perafPoint120_FrMedright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint120.frmedright
rsfMRI_fcnxpro122_falffPoint121_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint121.insright
rsfMRI_fcnxpro122_alffPoint121_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint121.insright
rsfMRI_fcnxpro122_perafPoint121_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint121.insright
rsfMRI_fcnxpro122_falffPoint122_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint122.insright
rsfMRI_fcnxpro122_alffPoint122_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint122.insright
rsfMRI_fcnxpro122_perafPoint122_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint122.insright
rsfMRI_fcnxpro122_falffPoint123_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint123.insright
rsfMRI_fcnxpro122_alffPoint123_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint123.insright
rsfMRI_fcnxpro122_perafPoint123_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint123.insright
rsfMRI_fcnxpro122_falffPoint124_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint124.pfclright
rsfMRI_fcnxpro122_alffPoint124_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint124.pfclright
rsfMRI_fcnxpro122_perafPoint124_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint124.pfclright
rsfMRI_fcnxpro122_falffPoint125_PFClright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint125.pfclright
rsfMRI_fcnxpro122_alffPoint125_PFClright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint125.pfclright
rsfMRI_fcnxpro122_perafPoint125_PFClright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint125.pfclright
rsfMRI_fcnxpro122_falffPoint126_PFCmright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint126.pfcmright
rsfMRI_fcnxpro122_alffPoint126_PFCmright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint126.pfcmright
rsfMRI_fcnxpro122_perafPoint126_PFCmright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint126.pfcmright
rsfMRI_fcnxpro122_falffPoint127_FrMedright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint127.frmedright
rsfMRI_fcnxpro122_alffPoint127_FrMedright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint127.frmedright
rsfMRI_fcnxpro122_perafPoint127_FrMedright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint127.frmedright
rsfMRI_fcnxpro122_falffPoint128_FrMedright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint128.frmedright
rsfMRI_fcnxpro122_alffPoint128_FrMedright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint128.frmedright
rsfMRI_fcnxpro122_perafPoint128_FrMedright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint128.frmedright
rsfMRI_fcnxpro122_falffPoint129_FrMedright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint129.frmedright
rsfMRI_fcnxpro122_alffPoint129_FrMedright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint129.frmedright
rsfMRI_fcnxpro122_perafPoint129_FrMedright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint129.frmedright
rsfMRI_fcnxpro122_falffPoint130_FrOperright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint130.froperright
rsfMRI_fcnxpro122_alffPoint130_FrOperright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint130.froperright
rsfMRI_fcnxpro122_perafPoint130_FrOperright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint130.froperright
rsfMRI_fcnxpro122_falffPoint131_FrOperright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint131.froperright
rsfMRI_fcnxpro122_alffPoint131_FrOperright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint131.froperright
rsfMRI_fcnxpro122_perafPoint131_FrOperright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint131.froperright
rsfMRI_fcnxpro122_falffPoint132_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint132.iplright
rsfMRI_fcnxpro122_alffPoint132_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint132.iplright
rsfMRI_fcnxpro122_perafPoint132_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint132.iplright
rsfMRI_fcnxpro122_falffPoint133_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint133.iplright
rsfMRI_fcnxpro122_alffPoint133_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint133.iplright
rsfMRI_fcnxpro122_perafPoint133_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint133.iplright
rsfMRI_fcnxpro122_falffPoint134_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint134.insright
rsfMRI_fcnxpro122_alffPoint134_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint134.insright
rsfMRI_fcnxpro122_perafPoint134_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint134.insright
rsfMRI_fcnxpro122_falffPoint135_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint135.insright
rsfMRI_fcnxpro122_alffPoint135_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint135.insright
rsfMRI_fcnxpro122_perafPoint135_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint135.insright
rsfMRI_fcnxpro122_falffPoint136_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint136.insright
rsfMRI_fcnxpro122_alffPoint136_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint136.insright
rsfMRI_fcnxpro122_perafPoint136_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint136.insright
rsfMRI_fcnxpro122_falffPoint137_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint137.insright
rsfMRI_fcnxpro122_alffPoint137_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint137.insright
rsfMRI_fcnxpro122_perafPoint137_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint137.insright
rsfMRI_fcnxpro122_falffPoint138_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint138.insright
rsfMRI_fcnxpro122_alffPoint138_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint138.insright
rsfMRI_fcnxpro122_perafPoint138_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint138.insright
rsfMRI_fcnxpro122_falffPoint139_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint139.splright
rsfMRI_fcnxpro122_alffPoint139_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint139.splright
rsfMRI_fcnxpro122_perafPoint139_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint139.splright
rsfMRI_fcnxpro122_falffPoint140_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint140.splright
rsfMRI_fcnxpro122_alffPoint140_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint140.splright
rsfMRI_fcnxpro122_perafPoint140_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint140.splright
rsfMRI_fcnxpro122_falffPoint141_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint141.splright
rsfMRI_fcnxpro122_alffPoint141_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint141.splright
rsfMRI_fcnxpro122_perafPoint141_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint141.splright
rsfMRI_fcnxpro122_falffPoint142_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint142.iplright
rsfMRI_fcnxpro122_alffPoint142_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint142.iplright
rsfMRI_fcnxpro122_perafPoint142_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint142.iplright
rsfMRI_fcnxpro122_falffPoint143_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint143.iplright
rsfMRI_fcnxpro122_alffPoint143_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint143.iplright
rsfMRI_fcnxpro122_perafPoint143_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint143.iplright
rsfMRI_fcnxpro122_falffPoint144_PFCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint144.pfcdright
rsfMRI_fcnxpro122_alffPoint144_PFCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint144.pfcdright
rsfMRI_fcnxpro122_perafPoint144_PFCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint144.pfcdright
rsfMRI_fcnxpro122_falffPoint145_PostCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint145.postcright
rsfMRI_fcnxpro122_alffPoint145_PostCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint145.postcright
rsfMRI_fcnxpro122_perafPoint145_PostCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint145.postcright
rsfMRI_fcnxpro122_falffPoint146_PostCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint146.postcright
rsfMRI_fcnxpro122_alffPoint146_PostCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint146.postcright
rsfMRI_fcnxpro122_perafPoint146_PostCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint146.postcright
rsfMRI_fcnxpro122_falffPoint147_PostCright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint147.postcright
rsfMRI_fcnxpro122_alffPoint147_PostCright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint147.postcright
rsfMRI_fcnxpro122_perafPoint147_PostCright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint147.postcright
rsfMRI_fcnxpro122_falffPoint148_PrCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint148.prcdright
rsfMRI_fcnxpro122_alffPoint148_PrCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint148.prcdright
rsfMRI_fcnxpro122_perafPoint148_PrCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint148.prcdright
rsfMRI_fcnxpro122_falffPoint149_PrCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint149.prcdright
rsfMRI_fcnxpro122_alffPoint149_PrCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint149.prcdright
rsfMRI_fcnxpro122_perafPoint149_PrCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint149.prcdright
rsfMRI_fcnxpro122_falffPoint150_PrCdright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint150.prcdright
rsfMRI_fcnxpro122_alffPoint150_PrCdright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint150.prcdright
rsfMRI_fcnxpro122_perafPoint150_PrCdright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint150.prcdright
rsfMRI_fcnxpro122_falffPoint151_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint151.splright
rsfMRI_fcnxpro122_alffPoint151_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint151.splright
rsfMRI_fcnxpro122_perafPoint151_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint151.splright
rsfMRI_fcnxpro122_falffPoint152_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint152.splright
rsfMRI_fcnxpro122_alffPoint152_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint152.splright
rsfMRI_fcnxpro122_perafPoint152_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint152.splright
rsfMRI_fcnxpro122_falffPoint153_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint153.splright
rsfMRI_fcnxpro122_alffPoint153_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint153.splright
rsfMRI_fcnxpro122_perafPoint153_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint153.splright
rsfMRI_fcnxpro122_falffPoint154_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint154.splright
rsfMRI_fcnxpro122_alffPoint154_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint154.splright
rsfMRI_fcnxpro122_perafPoint154_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint154.splright
rsfMRI_fcnxpro122_falffPoint155_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint155.tempoccright
rsfMRI_fcnxpro122_alffPoint155_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint155.tempoccright
rsfMRI_fcnxpro122_perafPoint155_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint155.tempoccright
rsfMRI_fcnxpro122_falffPoint156_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint156.exstrright
rsfMRI_fcnxpro122_alffPoint156_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint156.exstrright
rsfMRI_fcnxpro122_perafPoint156_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint156.exstrright
rsfMRI_fcnxpro122_falffPoint157_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint157.exstrright
rsfMRI_fcnxpro122_alffPoint157_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint157.exstrright
rsfMRI_fcnxpro122_perafPoint157_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint157.exstrright
rsfMRI_fcnxpro122_falffPoint158_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint158.exstrright
rsfMRI_fcnxpro122_alffPoint158_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint158.exstrright
rsfMRI_fcnxpro122_perafPoint158_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint158.exstrright
rsfMRI_fcnxpro122_falffPoint159_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint159.exstrright
rsfMRI_fcnxpro122_alffPoint159_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint159.exstrright
rsfMRI_fcnxpro122_perafPoint159_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint159.exstrright
rsfMRI_fcnxpro122_falffPoint160_IPSright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint160.ipsright
rsfMRI_fcnxpro122_alffPoint160_IPSright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint160.ipsright
rsfMRI_fcnxpro122_perafPoint160_IPSright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint160.ipsright
rsfMRI_fcnxpro122_falffPoint161_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint161.splright
rsfMRI_fcnxpro122_alffPoint161_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint161.splright
rsfMRI_fcnxpro122_perafPoint161_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint161.splright
rsfMRI_fcnxpro122_falffPoint162_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint162.splright
rsfMRI_fcnxpro122_alffPoint162_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint162.splright
rsfMRI_fcnxpro122_perafPoint162_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint162.splright
rsfMRI_fcnxpro122_falffPoint163_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint163.splright
rsfMRI_fcnxpro122_alffPoint163_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint163.splright
rsfMRI_fcnxpro122_perafPoint163_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint163.splright
rsfMRI_fcnxpro122_falffPoint164_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint164.splright
rsfMRI_fcnxpro122_alffPoint164_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint164.splright
rsfMRI_fcnxpro122_perafPoint164_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint164.splright
rsfMRI_fcnxpro122_falffPoint165_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint165.splright
rsfMRI_fcnxpro122_alffPoint165_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint165.splright
rsfMRI_fcnxpro122_perafPoint165_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint165.splright
rsfMRI_fcnxpro122_falffPoint166_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint166.splright
rsfMRI_fcnxpro122_alffPoint166_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint166.splright
rsfMRI_fcnxpro122_perafPoint166_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint166.splright
rsfMRI_fcnxpro122_falffPoint167_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint167.tempoccright
rsfMRI_fcnxpro122_alffPoint167_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint167.tempoccright
rsfMRI_fcnxpro122_perafPoint167_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint167.tempoccright
rsfMRI_fcnxpro122_falffPoint168_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint168.tempoccright
rsfMRI_fcnxpro122_alffPoint168_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint168.tempoccright
rsfMRI_fcnxpro122_perafPoint168_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint168.tempoccright
rsfMRI_fcnxpro122_falffPoint169_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint169.tempoccright
rsfMRI_fcnxpro122_alffPoint169_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint169.tempoccright
rsfMRI_fcnxpro122_perafPoint169_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint169.tempoccright
rsfMRI_fcnxpro122_falffPoint170_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint170.tempoccright
rsfMRI_fcnxpro122_alffPoint170_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint170.tempoccright
rsfMRI_fcnxpro122_perafPoint170_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint170.tempoccright
rsfMRI_fcnxpro122_falffPoint171_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint171.tempoccright
rsfMRI_fcnxpro122_alffPoint171_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint171.tempoccright
rsfMRI_fcnxpro122_perafPoint171_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint171.tempoccright
rsfMRI_fcnxpro122_falffPoint172_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint172.tempoccright
rsfMRI_fcnxpro122_alffPoint172_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint172.tempoccright
rsfMRI_fcnxpro122_perafPoint172_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint172.tempoccright
rsfMRI_fcnxpro122_falffPoint173_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint173.tempoccright
rsfMRI_fcnxpro122_alffPoint173_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint173.tempoccright
rsfMRI_fcnxpro122_perafPoint173_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint173.tempoccright
rsfMRI_fcnxpro122_falffPoint174_TempOccright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint174.tempoccright
rsfMRI_fcnxpro122_alffPoint174_TempOccright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint174.tempoccright
rsfMRI_fcnxpro122_perafPoint174_TempOccright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint174.tempoccright
rsfMRI_fcnxpro122_falffPoint175_1right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint175.1right
rsfMRI_fcnxpro122_alffPoint175_1right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint175.1right
rsfMRI_fcnxpro122_perafPoint175_1right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint175.1right
rsfMRI_fcnxpro122_falffPoint176_2right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint176.2right
rsfMRI_fcnxpro122_alffPoint176_2right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint176.2right
rsfMRI_fcnxpro122_perafPoint176_2right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint176.2right
rsfMRI_fcnxpro122_falffPoint177_3right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint177.3right
rsfMRI_fcnxpro122_alffPoint177_3right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint177.3right
rsfMRI_fcnxpro122_perafPoint177_3right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint177.3right
rsfMRI_fcnxpro122_falffPoint178_4right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint178.4right
rsfMRI_fcnxpro122_alffPoint178_4right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint178.4right
rsfMRI_fcnxpro122_perafPoint178_4right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint178.4right
rsfMRI_fcnxpro122_falffPoint179_5right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint179.5right
rsfMRI_fcnxpro122_alffPoint179_5right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint179.5right
rsfMRI_fcnxpro122_perafPoint179_5right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint179.5right
rsfMRI_fcnxpro122_falffPoint180_6right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint180.6right
rsfMRI_fcnxpro122_alffPoint180_6right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint180.6right
rsfMRI_fcnxpro122_perafPoint180_6right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint180.6right
rsfMRI_fcnxpro122_falffPoint181_IPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint181.iplright
rsfMRI_fcnxpro122_alffPoint181_IPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint181.iplright
rsfMRI_fcnxpro122_perafPoint181_IPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint181.iplright
rsfMRI_fcnxpro122_falffPoint182_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint182.insright
rsfMRI_fcnxpro122_alffPoint182_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint182.insright
rsfMRI_fcnxpro122_perafPoint182_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint182.insright
rsfMRI_fcnxpro122_falffPoint183_Insright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint183.insright
rsfMRI_fcnxpro122_alffPoint183_Insright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint183.insright
rsfMRI_fcnxpro122_perafPoint183_Insright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint183.insright
rsfMRI_fcnxpro122_falffPoint184_ParOperright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint184.paroperright
rsfMRI_fcnxpro122_alffPoint184_ParOperright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint184.paroperright
rsfMRI_fcnxpro122_perafPoint184_ParOperright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint184.paroperright
rsfMRI_fcnxpro122_falffPoint185_ParOperright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint185.paroperright
rsfMRI_fcnxpro122_alffPoint185_ParOperright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint185.paroperright
rsfMRI_fcnxpro122_perafPoint185_ParOperright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint185.paroperright
rsfMRI_fcnxpro122_falffPoint186_ParOperright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint186.paroperright
rsfMRI_fcnxpro122_alffPoint186_ParOperright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint186.paroperright
rsfMRI_fcnxpro122_perafPoint186_ParOperright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint186.paroperright
rsfMRI_fcnxpro122_falffPoint187_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint187.stright
rsfMRI_fcnxpro122_alffPoint187_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint187.stright
rsfMRI_fcnxpro122_perafPoint187_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint187.stright
rsfMRI_fcnxpro122_falffPoint188_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint188.stright
rsfMRI_fcnxpro122_alffPoint188_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint188.stright
rsfMRI_fcnxpro122_perafPoint188_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint188.stright
rsfMRI_fcnxpro122_falffPoint189_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint189.stright
rsfMRI_fcnxpro122_alffPoint189_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint189.stright
rsfMRI_fcnxpro122_perafPoint189_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint189.stright
rsfMRI_fcnxpro122_falffPoint190_STright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint190.stright
rsfMRI_fcnxpro122_alffPoint190_STright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint190.stright
rsfMRI_fcnxpro122_perafPoint190_STright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint190.stright
rsfMRI_fcnxpro122_falffPoint191_1right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint191.1right
rsfMRI_fcnxpro122_alffPoint191_1right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint191.1right
rsfMRI_fcnxpro122_perafPoint191_1right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint191.1right
rsfMRI_fcnxpro122_falffPoint192_10right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint192.10right
rsfMRI_fcnxpro122_alffPoint192_10right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint192.10right
rsfMRI_fcnxpro122_perafPoint192_10right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint192.10right
rsfMRI_fcnxpro122_falffPoint193_11right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint193.11right
rsfMRI_fcnxpro122_alffPoint193_11right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint193.11right
rsfMRI_fcnxpro122_perafPoint193_11right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint193.11right
rsfMRI_fcnxpro122_falffPoint194_12right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint194.12right
rsfMRI_fcnxpro122_alffPoint194_12right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint194.12right
rsfMRI_fcnxpro122_perafPoint194_12right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint194.12right
rsfMRI_fcnxpro122_falffPoint195_13right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint195.13right
rsfMRI_fcnxpro122_alffPoint195_13right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint195.13right
rsfMRI_fcnxpro122_perafPoint195_13right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint195.13right
rsfMRI_fcnxpro122_falffPoint196_14right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint196.14right
rsfMRI_fcnxpro122_alffPoint196_14right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint196.14right
rsfMRI_fcnxpro122_perafPoint196_14right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint196.14right
rsfMRI_fcnxpro122_falffPoint197_15right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint197.15right
rsfMRI_fcnxpro122_alffPoint197_15right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint197.15right
rsfMRI_fcnxpro122_perafPoint197_15right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint197.15right
rsfMRI_fcnxpro122_falffPoint198_16right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint198.16right
rsfMRI_fcnxpro122_alffPoint198_16right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint198.16right
rsfMRI_fcnxpro122_perafPoint198_16right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint198.16right
rsfMRI_fcnxpro122_falffPoint199_17right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint199.17right
rsfMRI_fcnxpro122_alffPoint199_17right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint199.17right
rsfMRI_fcnxpro122_perafPoint199_17right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint199.17right
rsfMRI_fcnxpro122_falffPoint200_18right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint200.18right
rsfMRI_fcnxpro122_alffPoint200_18right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint200.18right
rsfMRI_fcnxpro122_perafPoint200_18right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint200.18right
rsfMRI_fcnxpro122_falffPoint201_19right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint201.19right
rsfMRI_fcnxpro122_alffPoint201_19right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint201.19right
rsfMRI_fcnxpro122_perafPoint201_19right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint201.19right
rsfMRI_fcnxpro122_falffPoint202_2right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint202.2right
rsfMRI_fcnxpro122_alffPoint202_2right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint202.2right
rsfMRI_fcnxpro122_perafPoint202_2right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint202.2right
rsfMRI_fcnxpro122_falffPoint203_20right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint203.20right
rsfMRI_fcnxpro122_alffPoint203_20right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint203.20right
rsfMRI_fcnxpro122_perafPoint203_20right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint203.20right
rsfMRI_fcnxpro122_falffPoint204_21right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint204.21right
rsfMRI_fcnxpro122_alffPoint204_21right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint204.21right
rsfMRI_fcnxpro122_perafPoint204_21right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint204.21right
rsfMRI_fcnxpro122_falffPoint205_22right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint205.22right
rsfMRI_fcnxpro122_alffPoint205_22right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint205.22right
rsfMRI_fcnxpro122_perafPoint205_22right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint205.22right
rsfMRI_fcnxpro122_falffPoint206_23right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint206.23right
rsfMRI_fcnxpro122_alffPoint206_23right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint206.23right
rsfMRI_fcnxpro122_perafPoint206_23right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint206.23right
rsfMRI_fcnxpro122_falffPoint207_24right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint207.24right
rsfMRI_fcnxpro122_alffPoint207_24right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint207.24right
rsfMRI_fcnxpro122_perafPoint207_24right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint207.24right
rsfMRI_fcnxpro122_falffPoint208_25right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint208.25right
rsfMRI_fcnxpro122_alffPoint208_25right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint208.25right
rsfMRI_fcnxpro122_perafPoint208_25right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint208.25right
rsfMRI_fcnxpro122_falffPoint209_26right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint209.26right
rsfMRI_fcnxpro122_alffPoint209_26right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint209.26right
rsfMRI_fcnxpro122_perafPoint209_26right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint209.26right
rsfMRI_fcnxpro122_falffPoint210_27right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint210.27right
rsfMRI_fcnxpro122_alffPoint210_27right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint210.27right
rsfMRI_fcnxpro122_perafPoint210_27right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint210.27right
rsfMRI_fcnxpro122_falffPoint211_28right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint211.28right
rsfMRI_fcnxpro122_alffPoint211_28right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint211.28right
rsfMRI_fcnxpro122_perafPoint211_28right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint211.28right
rsfMRI_fcnxpro122_falffPoint212_29right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint212.29right
rsfMRI_fcnxpro122_alffPoint212_29right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint212.29right
rsfMRI_fcnxpro122_perafPoint212_29right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint212.29right
rsfMRI_fcnxpro122_falffPoint213_3right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint213.3right
rsfMRI_fcnxpro122_alffPoint213_3right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint213.3right
rsfMRI_fcnxpro122_perafPoint213_3right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint213.3right
rsfMRI_fcnxpro122_falffPoint214_4right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint214.4right
rsfMRI_fcnxpro122_alffPoint214_4right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint214.4right
rsfMRI_fcnxpro122_perafPoint214_4right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint214.4right
rsfMRI_fcnxpro122_falffPoint215_5right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint215.5right
rsfMRI_fcnxpro122_alffPoint215_5right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint215.5right
rsfMRI_fcnxpro122_perafPoint215_5right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint215.5right
rsfMRI_fcnxpro122_falffPoint216_6right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint216.6right
rsfMRI_fcnxpro122_alffPoint216_6right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint216.6right
rsfMRI_fcnxpro122_perafPoint216_6right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint216.6right
rsfMRI_fcnxpro122_falffPoint217_7right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint217.7right
rsfMRI_fcnxpro122_alffPoint217_7right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint217.7right
rsfMRI_fcnxpro122_perafPoint217_7right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint217.7right
rsfMRI_fcnxpro122_falffPoint218_8right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint218.8right
rsfMRI_fcnxpro122_alffPoint218_8right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint218.8right
rsfMRI_fcnxpro122_perafPoint218_8right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint218.8right
rsfMRI_fcnxpro122_falffPoint219_9right
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint219.9right
rsfMRI_fcnxpro122_alffPoint219_9right
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint219.9right
rsfMRI_fcnxpro122_perafPoint219_9right
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint219.9right
rsfMRI_fcnxpro122_falffPoint220_SPLright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint220.splright
rsfMRI_fcnxpro122_alffPoint220_SPLright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint220.splright
rsfMRI_fcnxpro122_perafPoint220_SPLright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint220.splright
rsfMRI_fcnxpro122_falffPoint221_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint221.exstrright
rsfMRI_fcnxpro122_alffPoint221_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint221.exstrright
rsfMRI_fcnxpro122_perafPoint221_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint221.exstrright
rsfMRI_fcnxpro122_falffPoint222_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint222.exstrinfright
rsfMRI_fcnxpro122_alffPoint222_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint222.exstrinfright
rsfMRI_fcnxpro122_perafPoint222_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint222.exstrinfright
rsfMRI_fcnxpro122_falffPoint223_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint223.exstrinfright
rsfMRI_fcnxpro122_alffPoint223_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint223.exstrinfright
rsfMRI_fcnxpro122_perafPoint223_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint223.exstrinfright
rsfMRI_fcnxpro122_falffPoint224_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint224.exstrinfright
rsfMRI_fcnxpro122_alffPoint224_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint224.exstrinfright
rsfMRI_fcnxpro122_perafPoint224_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint224.exstrinfright
rsfMRI_fcnxpro122_falffPoint225_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint225.exstrinfright
rsfMRI_fcnxpro122_alffPoint225_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint225.exstrinfright
rsfMRI_fcnxpro122_perafPoint225_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint225.exstrinfright
rsfMRI_fcnxpro122_falffPoint226_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint226.exstrinfright
rsfMRI_fcnxpro122_alffPoint226_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint226.exstrinfright
rsfMRI_fcnxpro122_perafPoint226_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint226.exstrinfright
rsfMRI_fcnxpro122_falffPoint227_ExStrSupright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint227.exstrsupright
rsfMRI_fcnxpro122_alffPoint227_ExStrSupright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint227.exstrsupright
rsfMRI_fcnxpro122_perafPoint227_ExStrSupright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint227.exstrsupright
rsfMRI_fcnxpro122_falffPoint228_ExStrSupright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint228.exstrsupright
rsfMRI_fcnxpro122_alffPoint228_ExStrSupright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint228.exstrsupright
rsfMRI_fcnxpro122_perafPoint228_ExStrSupright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint228.exstrsupright
rsfMRI_fcnxpro122_falffPoint229_ExStrSupright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint229.exstrsupright
rsfMRI_fcnxpro122_alffPoint229_ExStrSupright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint229.exstrsupright
rsfMRI_fcnxpro122_perafPoint229_ExStrSupright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint229.exstrsupright
rsfMRI_fcnxpro122_falffPoint230_Striateright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint230.striateright
rsfMRI_fcnxpro122_alffPoint230_Striateright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint230.striateright
rsfMRI_fcnxpro122_perafPoint230_Striateright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint230.striateright
rsfMRI_fcnxpro122_falffPoint231_Striateright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint231.striateright
rsfMRI_fcnxpro122_alffPoint231_Striateright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint231.striateright
rsfMRI_fcnxpro122_perafPoint231_Striateright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint231.striateright
rsfMRI_fcnxpro122_falffPoint232_ExStrInfright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint232.exstrinfright
rsfMRI_fcnxpro122_alffPoint232_ExStrInfright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint232.exstrinfright
rsfMRI_fcnxpro122_perafPoint232_ExStrInfright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint232.exstrinfright
rsfMRI_fcnxpro122_falffPoint233_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint233.exstrright
rsfMRI_fcnxpro122_alffPoint233_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint233.exstrright
rsfMRI_fcnxpro122_perafPoint233_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint233.exstrright
rsfMRI_fcnxpro122_falffPoint234_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint234.exstrright
rsfMRI_fcnxpro122_alffPoint234_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint234.exstrright
rsfMRI_fcnxpro122_perafPoint234_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint234.exstrright
rsfMRI_fcnxpro122_falffPoint235_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint235.exstrright
rsfMRI_fcnxpro122_alffPoint235_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint235.exstrright
rsfMRI_fcnxpro122_perafPoint235_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint235.exstrright
rsfMRI_fcnxpro122_falffPoint236_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint236.exstrright
rsfMRI_fcnxpro122_alffPoint236_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint236.exstrright
rsfMRI_fcnxpro122_perafPoint236_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint236.exstrright
rsfMRI_fcnxpro122_falffPoint237_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint237.exstrright
rsfMRI_fcnxpro122_alffPoint237_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint237.exstrright
rsfMRI_fcnxpro122_perafPoint237_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint237.exstrright
rsfMRI_fcnxpro122_falffPoint238_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint238.exstrright
rsfMRI_fcnxpro122_alffPoint238_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint238.exstrright
rsfMRI_fcnxpro122_perafPoint238_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint238.exstrright
rsfMRI_fcnxpro122_falffPoint239_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint239.exstrright
rsfMRI_fcnxpro122_alffPoint239_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint239.exstrright
rsfMRI_fcnxpro122_perafPoint239_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint239.exstrright
rsfMRI_fcnxpro122_falffPoint240_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint240.exstrright
rsfMRI_fcnxpro122_alffPoint240_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint240.exstrright
rsfMRI_fcnxpro122_perafPoint240_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint240.exstrright
rsfMRI_fcnxpro122_falffPoint241_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint241.exstrright
rsfMRI_fcnxpro122_alffPoint241_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint241.exstrright
rsfMRI_fcnxpro122_perafPoint241_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint241.exstrright
rsfMRI_fcnxpro122_falffPoint242_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint242.exstrright
rsfMRI_fcnxpro122_alffPoint242_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint242.exstrright
rsfMRI_fcnxpro122_perafPoint242_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint242.exstrright
rsfMRI_fcnxpro122_falffPoint243_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint243.exstrright
rsfMRI_fcnxpro122_alffPoint243_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint243.exstrright
rsfMRI_fcnxpro122_perafPoint243_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint243.exstrright
rsfMRI_fcnxpro122_falffPoint244_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint244.exstrright
rsfMRI_fcnxpro122_alffPoint244_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint244.exstrright
rsfMRI_fcnxpro122_perafPoint244_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint244.exstrright
rsfMRI_fcnxpro122_falffPoint245_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint245.exstrright
rsfMRI_fcnxpro122_alffPoint245_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint245.exstrright
rsfMRI_fcnxpro122_perafPoint245_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint245.exstrright
rsfMRI_fcnxpro122_falffPoint246_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint246.exstrright
rsfMRI_fcnxpro122_alffPoint246_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint246.exstrright
rsfMRI_fcnxpro122_perafPoint246_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint246.exstrright
rsfMRI_fcnxpro122_falffPoint247_ExStrright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint247.exstrright
rsfMRI_fcnxpro122_alffPoint247_ExStrright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint247.exstrright
rsfMRI_fcnxpro122_perafPoint247_ExStrright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint247.exstrright
rsfMRI_fcnxpro122_falffPoint248_Striateright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint248.striateright
rsfMRI_fcnxpro122_alffPoint248_Striateright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint248.striateright
rsfMRI_fcnxpro122_perafPoint248_Striateright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint248.striateright
rsfMRI_fcnxpro122_falffPoint249_Striateright
restingStatefMRI
right
yeo_homotopic
fractional amplitude of low frequency fluctuations fALFF
unlabeled / likely somatosensory
rsf.falffpoint249.striateright
rsfMRI_fcnxpro122_alffPoint249_Striateright
restingStatefMRI
right
yeo_homotopic
amplitude of low frequency fluctuations ALFF
unlabeled / likely somatosensory
rsf.alffpoint249.striateright
rsfMRI_fcnxpro122_perafPoint249_Striateright
restingStatefMRI
right
yeo_homotopic
percent absolute fluctuation
unlabeled / likely somatosensory
rsf.perafpoint249.striateright
rsfMRI_fcnxpro122_DefaultMode_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.defaultmode.mean
rsfMRI_fcnxpro122_Visual_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.visual.mean
rsfMRI_fcnxpro122_PerAF_mean
restingStatefMRI
​
yeo_homotopic
global mean of image
​
rsf.peraf.mean
rsfMRI_fcnxpro122_tsnr_mean
restingStatefMRI
​
yeo_homotopic
mean TSNR in time series
​
rsf.tsnr.mean
rsfMRI_fcnxpro122_ssnr_mean
restingStatefMRI
​
yeo_homotopic
mean spatial SNR in mean bold
​
rsf.ssnr.mean
rsfMRI_fcnxpro122_dvars_mean
restingStatefMRI
​
yeo_homotopic
mean DVARS
​
rsf.dvars.mean
rsfMRI_fcnxpro122_bandpass_freq_0
restingStatefMRI
​
yeo_homotopic
band pass frequency limit
​
rsf.bandpass.freq.0
rsfMRI_fcnxpro122_bandpass_freq_1
restingStatefMRI
​
yeo_homotopic
band pass frequency limit
​
rsf.bandpass.freq.1
rsfMRI_fcnxpro122_censor
restingStatefMRI
​
yeo_homotopic
ignore
​
rsf.censor
rsfMRI_fcnxpro122_spatial_smoothing
restingStatefMRI
​
yeo_homotopic
spatial smoothing parameter
​
rsf.spatial.smoothing
rsfMRI_fcnxpro122_outlier_threshold
restingStatefMRI
​
yeo_homotopic
outlier threshold parameter
​
rsf.outlier.threshold
rsfMRI_fcnxpro122_FD_threshold
restingStatefMRI
​
yeo_homotopic
FD threshold paramter
​
rsf.fd.threshold
rsfMRI_fcnxpro122_high_motion_count
restingStatefMRI
​
yeo_homotopic
high motion count
​
rsf.high.motion.count
rsfMRI_fcnxpro122_high_motion_pct
restingStatefMRI
​
yeo_homotopic
percent high motion count
​
rsf.high.motion.pct
rsfMRI_fcnxpro122_despiking_count_summary
restingStatefMRI
​
yeo_homotopic
changes made in despiking
​
rsf.despiking.count.summary
rsfMRI_fcnxpro122_FD_max
restingStatefMRI
​
yeo_homotopic
max framewise displacement
​
rsf.fd.max
rsfMRI_fcnxpro122_FD_mean
restingStatefMRI
​
yeo_homotopic
mean framewise displacement
​
rsf.fd.mean
rsfMRI_fcnxpro122_bold_evr
restingStatefMRI
​
yeo_homotopic
eigenvector ratio for mean bold
​
rsf.bold.evr
rsfMRI_fcnxpro122_n_outliers
restingStatefMRI
​
yeo_homotopic
number of outlier volumes
​
rsf.n.outliers
rsfMRI_fcnxpro122_nc_wm
restingStatefMRI
​
yeo_homotopic
number of white matter compcor components
​
rsf.nc.wm
rsfMRI_fcnxpro122_nc_csf
restingStatefMRI
​
yeo_homotopic
number of csf compcor components
​
rsf.nc.csf
rsfMRI_fcnxpro122_minutes_original_data
restingStatefMRI
​
yeo_homotopic
minutes of rs imaging
​
rsf.minutes.original.data
rsfMRI_fcnxpro122_minutes_censored_data
restingStatefMRI
​
yeo_homotopic
minutes of rs imaging after censoring
​
rsf.minutes.censored.data
rsfMRI_fcnxpro122_TempPar_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.temppar
rsfMRI_fcnxpro122_TempPar_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.defaultc
rsfMRI_fcnxpro122_TempPar_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.defaultb
rsfMRI_fcnxpro122_TempPar_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.defaulta
rsfMRI_fcnxpro122_TempPar_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.contc
rsfMRI_fcnxpro122_TempPar_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.contb
rsfMRI_fcnxpro122_TempPar_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.conta
rsfMRI_fcnxpro122_TempPar_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.limbica
rsfMRI_fcnxpro122_TempPar_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.limbicb
rsfMRI_fcnxpro122_TempPar_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.salventattnb
rsfMRI_fcnxpro122_TempPar_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.salventattna
rsfMRI_fcnxpro122_TempPar_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.dorsattnb
rsfMRI_fcnxpro122_TempPar_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.dorsattna
rsfMRI_fcnxpro122_TempPar_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.sommotb
rsfMRI_fcnxpro122_TempPar_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.sommota
rsfMRI_fcnxpro122_TempPar_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.visperi
rsfMRI_fcnxpro122_TempPar_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.temppar.2.viscent
rsfMRI_fcnxpro122_DefaultC_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.temppar
rsfMRI_fcnxpro122_DefaultC_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.defaultc
rsfMRI_fcnxpro122_DefaultC_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.defaultb
rsfMRI_fcnxpro122_DefaultC_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.defaulta
rsfMRI_fcnxpro122_DefaultC_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.contc
rsfMRI_fcnxpro122_DefaultC_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.contb
rsfMRI_fcnxpro122_DefaultC_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.conta
rsfMRI_fcnxpro122_DefaultC_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.limbica
rsfMRI_fcnxpro122_DefaultC_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.limbicb
rsfMRI_fcnxpro122_DefaultC_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.salventattnb
rsfMRI_fcnxpro122_DefaultC_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.salventattna
rsfMRI_fcnxpro122_DefaultC_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.dorsattnb
rsfMRI_fcnxpro122_DefaultC_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.dorsattna
rsfMRI_fcnxpro122_DefaultC_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.sommotb
rsfMRI_fcnxpro122_DefaultC_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.sommota
rsfMRI_fcnxpro122_DefaultC_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.visperi
rsfMRI_fcnxpro122_DefaultC_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultc.2.viscent
rsfMRI_fcnxpro122_DefaultB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.temppar
rsfMRI_fcnxpro122_DefaultB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.defaultc
rsfMRI_fcnxpro122_DefaultB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.defaultb
rsfMRI_fcnxpro122_DefaultB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.defaulta
rsfMRI_fcnxpro122_DefaultB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.contc
rsfMRI_fcnxpro122_DefaultB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.contb
rsfMRI_fcnxpro122_DefaultB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.conta
rsfMRI_fcnxpro122_DefaultB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.limbica
rsfMRI_fcnxpro122_DefaultB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.limbicb
rsfMRI_fcnxpro122_DefaultB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.salventattnb
rsfMRI_fcnxpro122_DefaultB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.salventattna
rsfMRI_fcnxpro122_DefaultB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.dorsattnb
rsfMRI_fcnxpro122_DefaultB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.dorsattna
rsfMRI_fcnxpro122_DefaultB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.sommotb
rsfMRI_fcnxpro122_DefaultB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.sommota
rsfMRI_fcnxpro122_DefaultB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.visperi
rsfMRI_fcnxpro122_DefaultB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaultb.2.viscent
rsfMRI_fcnxpro122_DefaultA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.temppar
rsfMRI_fcnxpro122_DefaultA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.defaultc
rsfMRI_fcnxpro122_DefaultA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.defaultb
rsfMRI_fcnxpro122_DefaultA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.defaulta
rsfMRI_fcnxpro122_DefaultA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.contc
rsfMRI_fcnxpro122_DefaultA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.contb
rsfMRI_fcnxpro122_DefaultA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.conta
rsfMRI_fcnxpro122_DefaultA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.limbica
rsfMRI_fcnxpro122_DefaultA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.limbicb
rsfMRI_fcnxpro122_DefaultA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.salventattnb
rsfMRI_fcnxpro122_DefaultA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.salventattna
rsfMRI_fcnxpro122_DefaultA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.dorsattnb
rsfMRI_fcnxpro122_DefaultA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.dorsattna
rsfMRI_fcnxpro122_DefaultA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.sommotb
rsfMRI_fcnxpro122_DefaultA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.sommota
rsfMRI_fcnxpro122_DefaultA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.visperi
rsfMRI_fcnxpro122_DefaultA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.defaulta.2.viscent
rsfMRI_fcnxpro122_ContC_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.temppar
rsfMRI_fcnxpro122_ContC_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.defaultc
rsfMRI_fcnxpro122_ContC_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.defaultb
rsfMRI_fcnxpro122_ContC_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.defaulta
rsfMRI_fcnxpro122_ContC_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.contc
rsfMRI_fcnxpro122_ContC_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.contb
rsfMRI_fcnxpro122_ContC_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.conta
rsfMRI_fcnxpro122_ContC_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.limbica
rsfMRI_fcnxpro122_ContC_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.limbicb
rsfMRI_fcnxpro122_ContC_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.salventattnb
rsfMRI_fcnxpro122_ContC_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.salventattna
rsfMRI_fcnxpro122_ContC_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.dorsattnb
rsfMRI_fcnxpro122_ContC_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.dorsattna
rsfMRI_fcnxpro122_ContC_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.sommotb
rsfMRI_fcnxpro122_ContC_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.sommota
rsfMRI_fcnxpro122_ContC_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.visperi
rsfMRI_fcnxpro122_ContC_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contc.2.viscent
rsfMRI_fcnxpro122_ContB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.temppar
rsfMRI_fcnxpro122_ContB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.defaultc
rsfMRI_fcnxpro122_ContB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.defaultb
rsfMRI_fcnxpro122_ContB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.defaulta
rsfMRI_fcnxpro122_ContB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.contc
rsfMRI_fcnxpro122_ContB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.contb
rsfMRI_fcnxpro122_ContB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.conta
rsfMRI_fcnxpro122_ContB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.limbica
rsfMRI_fcnxpro122_ContB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.limbicb
rsfMRI_fcnxpro122_ContB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.salventattnb
rsfMRI_fcnxpro122_ContB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.salventattna
rsfMRI_fcnxpro122_ContB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.dorsattnb
rsfMRI_fcnxpro122_ContB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.dorsattna
rsfMRI_fcnxpro122_ContB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.sommotb
rsfMRI_fcnxpro122_ContB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.sommota
rsfMRI_fcnxpro122_ContB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.visperi
rsfMRI_fcnxpro122_ContB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.contb.2.viscent
rsfMRI_fcnxpro122_ContA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.temppar
rsfMRI_fcnxpro122_ContA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.defaultc
rsfMRI_fcnxpro122_ContA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.defaultb
rsfMRI_fcnxpro122_ContA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.defaulta
rsfMRI_fcnxpro122_ContA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.contc
rsfMRI_fcnxpro122_ContA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.contb
rsfMRI_fcnxpro122_ContA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.conta
rsfMRI_fcnxpro122_ContA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.limbica
rsfMRI_fcnxpro122_ContA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.limbicb
rsfMRI_fcnxpro122_ContA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.salventattnb
rsfMRI_fcnxpro122_ContA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.salventattna
rsfMRI_fcnxpro122_ContA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.dorsattnb
rsfMRI_fcnxpro122_ContA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.dorsattna
rsfMRI_fcnxpro122_ContA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.sommotb
rsfMRI_fcnxpro122_ContA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.sommota
rsfMRI_fcnxpro122_ContA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.visperi
rsfMRI_fcnxpro122_ContA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.conta.2.viscent
rsfMRI_fcnxpro122_LimbicA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.temppar
rsfMRI_fcnxpro122_LimbicA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.defaultc
rsfMRI_fcnxpro122_LimbicA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.defaultb
rsfMRI_fcnxpro122_LimbicA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.defaulta
rsfMRI_fcnxpro122_LimbicA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.contc
rsfMRI_fcnxpro122_LimbicA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.contb
rsfMRI_fcnxpro122_LimbicA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.conta
rsfMRI_fcnxpro122_LimbicA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.limbica
rsfMRI_fcnxpro122_LimbicA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.limbicb
rsfMRI_fcnxpro122_LimbicA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.salventattnb
rsfMRI_fcnxpro122_LimbicA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.salventattna
rsfMRI_fcnxpro122_LimbicA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.dorsattnb
rsfMRI_fcnxpro122_LimbicA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.dorsattna
rsfMRI_fcnxpro122_LimbicA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.sommotb
rsfMRI_fcnxpro122_LimbicA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.sommota
rsfMRI_fcnxpro122_LimbicA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.visperi
rsfMRI_fcnxpro122_LimbicA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbica.2.viscent
rsfMRI_fcnxpro122_LimbicB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.temppar
rsfMRI_fcnxpro122_LimbicB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.defaultc
rsfMRI_fcnxpro122_LimbicB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.defaultb
rsfMRI_fcnxpro122_LimbicB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.defaulta
rsfMRI_fcnxpro122_LimbicB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.contc
rsfMRI_fcnxpro122_LimbicB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.contb
rsfMRI_fcnxpro122_LimbicB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.conta
rsfMRI_fcnxpro122_LimbicB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.limbica
rsfMRI_fcnxpro122_LimbicB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.limbicb
rsfMRI_fcnxpro122_LimbicB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.salventattnb
rsfMRI_fcnxpro122_LimbicB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.salventattna
rsfMRI_fcnxpro122_LimbicB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.dorsattnb
rsfMRI_fcnxpro122_LimbicB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.dorsattna
rsfMRI_fcnxpro122_LimbicB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.sommotb
rsfMRI_fcnxpro122_LimbicB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.sommota
rsfMRI_fcnxpro122_LimbicB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.visperi
rsfMRI_fcnxpro122_LimbicB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.limbicb.2.viscent
rsfMRI_fcnxpro122_SalVentAttnB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.temppar
rsfMRI_fcnxpro122_SalVentAttnB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.defaultc
rsfMRI_fcnxpro122_SalVentAttnB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.defaultb
rsfMRI_fcnxpro122_SalVentAttnB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.defaulta
rsfMRI_fcnxpro122_SalVentAttnB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.contc
rsfMRI_fcnxpro122_SalVentAttnB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.contb
rsfMRI_fcnxpro122_SalVentAttnB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.conta
rsfMRI_fcnxpro122_SalVentAttnB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.limbica
rsfMRI_fcnxpro122_SalVentAttnB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.limbicb
rsfMRI_fcnxpro122_SalVentAttnB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.salventattnb
rsfMRI_fcnxpro122_SalVentAttnB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.salventattna
rsfMRI_fcnxpro122_SalVentAttnB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.dorsattnb
rsfMRI_fcnxpro122_SalVentAttnB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.dorsattna
rsfMRI_fcnxpro122_SalVentAttnB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.sommotb
rsfMRI_fcnxpro122_SalVentAttnB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.sommota
rsfMRI_fcnxpro122_SalVentAttnB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.visperi
rsfMRI_fcnxpro122_SalVentAttnB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattnb.2.viscent
rsfMRI_fcnxpro122_SalVentAttnA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.temppar
rsfMRI_fcnxpro122_SalVentAttnA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.defaultc
rsfMRI_fcnxpro122_SalVentAttnA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.defaultb
rsfMRI_fcnxpro122_SalVentAttnA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.defaulta
rsfMRI_fcnxpro122_SalVentAttnA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.contc
rsfMRI_fcnxpro122_SalVentAttnA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.contb
rsfMRI_fcnxpro122_SalVentAttnA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.conta
rsfMRI_fcnxpro122_SalVentAttnA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.limbica
rsfMRI_fcnxpro122_SalVentAttnA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.limbicb
rsfMRI_fcnxpro122_SalVentAttnA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.salventattnb
rsfMRI_fcnxpro122_SalVentAttnA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.salventattna
rsfMRI_fcnxpro122_SalVentAttnA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.dorsattnb
rsfMRI_fcnxpro122_SalVentAttnA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.dorsattna
rsfMRI_fcnxpro122_SalVentAttnA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.sommotb
rsfMRI_fcnxpro122_SalVentAttnA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.sommota
rsfMRI_fcnxpro122_SalVentAttnA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.visperi
rsfMRI_fcnxpro122_SalVentAttnA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.salventattna.2.viscent
rsfMRI_fcnxpro122_DorsAttnB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.temppar
rsfMRI_fcnxpro122_DorsAttnB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.defaultc
rsfMRI_fcnxpro122_DorsAttnB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.defaultb
rsfMRI_fcnxpro122_DorsAttnB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.defaulta
rsfMRI_fcnxpro122_DorsAttnB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.contc
rsfMRI_fcnxpro122_DorsAttnB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.contb
rsfMRI_fcnxpro122_DorsAttnB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.conta
rsfMRI_fcnxpro122_DorsAttnB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.limbica
rsfMRI_fcnxpro122_DorsAttnB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.limbicb
rsfMRI_fcnxpro122_DorsAttnB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.salventattnb
rsfMRI_fcnxpro122_DorsAttnB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.salventattna
rsfMRI_fcnxpro122_DorsAttnB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.dorsattnb
rsfMRI_fcnxpro122_DorsAttnB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.dorsattna
rsfMRI_fcnxpro122_DorsAttnB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.sommotb
rsfMRI_fcnxpro122_DorsAttnB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.sommota
rsfMRI_fcnxpro122_DorsAttnB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.visperi
rsfMRI_fcnxpro122_DorsAttnB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattnb.2.viscent
rsfMRI_fcnxpro122_DorsAttnA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.temppar
rsfMRI_fcnxpro122_DorsAttnA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.defaultc
rsfMRI_fcnxpro122_DorsAttnA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.defaultb
rsfMRI_fcnxpro122_DorsAttnA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.defaulta
rsfMRI_fcnxpro122_DorsAttnA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.contc
rsfMRI_fcnxpro122_DorsAttnA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.contb
rsfMRI_fcnxpro122_DorsAttnA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.conta
rsfMRI_fcnxpro122_DorsAttnA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.limbica
rsfMRI_fcnxpro122_DorsAttnA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.limbicb
rsfMRI_fcnxpro122_DorsAttnA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.salventattnb
rsfMRI_fcnxpro122_DorsAttnA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.salventattna
rsfMRI_fcnxpro122_DorsAttnA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.dorsattnb
rsfMRI_fcnxpro122_DorsAttnA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.dorsattna
rsfMRI_fcnxpro122_DorsAttnA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.sommotb
rsfMRI_fcnxpro122_DorsAttnA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.sommota
rsfMRI_fcnxpro122_DorsAttnA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.visperi
rsfMRI_fcnxpro122_DorsAttnA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.dorsattna.2.viscent
rsfMRI_fcnxpro122_SomMotB_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.temppar
rsfMRI_fcnxpro122_SomMotB_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.defaultc
rsfMRI_fcnxpro122_SomMotB_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.defaultb
rsfMRI_fcnxpro122_SomMotB_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.defaulta
rsfMRI_fcnxpro122_SomMotB_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.contc
rsfMRI_fcnxpro122_SomMotB_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.contb
rsfMRI_fcnxpro122_SomMotB_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.conta
rsfMRI_fcnxpro122_SomMotB_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.limbica
rsfMRI_fcnxpro122_SomMotB_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.limbicb
rsfMRI_fcnxpro122_SomMotB_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.salventattnb
rsfMRI_fcnxpro122_SomMotB_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.salventattna
rsfMRI_fcnxpro122_SomMotB_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.dorsattnb
rsfMRI_fcnxpro122_SomMotB_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.dorsattna
rsfMRI_fcnxpro122_SomMotB_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.sommotb
rsfMRI_fcnxpro122_SomMotB_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.sommota
rsfMRI_fcnxpro122_SomMotB_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.visperi
rsfMRI_fcnxpro122_SomMotB_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommotb.2.viscent
rsfMRI_fcnxpro122_SomMotA_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.temppar
rsfMRI_fcnxpro122_SomMotA_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.defaultc
rsfMRI_fcnxpro122_SomMotA_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.defaultb
rsfMRI_fcnxpro122_SomMotA_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.defaulta
rsfMRI_fcnxpro122_SomMotA_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.contc
rsfMRI_fcnxpro122_SomMotA_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.contb
rsfMRI_fcnxpro122_SomMotA_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.conta
rsfMRI_fcnxpro122_SomMotA_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.limbica
rsfMRI_fcnxpro122_SomMotA_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.limbicb
rsfMRI_fcnxpro122_SomMotA_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.salventattnb
rsfMRI_fcnxpro122_SomMotA_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.salventattna
rsfMRI_fcnxpro122_SomMotA_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.dorsattnb
rsfMRI_fcnxpro122_SomMotA_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.dorsattna
rsfMRI_fcnxpro122_SomMotA_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.sommotb
rsfMRI_fcnxpro122_SomMotA_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.sommota
rsfMRI_fcnxpro122_SomMotA_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.visperi
rsfMRI_fcnxpro122_SomMotA_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.sommota.2.viscent
rsfMRI_fcnxpro122_VisPeri_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.temppar
rsfMRI_fcnxpro122_VisPeri_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.defaultc
rsfMRI_fcnxpro122_VisPeri_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.defaultb
rsfMRI_fcnxpro122_VisPeri_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.defaulta
rsfMRI_fcnxpro122_VisPeri_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.contc
rsfMRI_fcnxpro122_VisPeri_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.contb
rsfMRI_fcnxpro122_VisPeri_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.conta
rsfMRI_fcnxpro122_VisPeri_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.limbica
rsfMRI_fcnxpro122_VisPeri_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.limbicb
rsfMRI_fcnxpro122_VisPeri_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.salventattnb
rsfMRI_fcnxpro122_VisPeri_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.salventattna
rsfMRI_fcnxpro122_VisPeri_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.dorsattnb
rsfMRI_fcnxpro122_VisPeri_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.dorsattna
rsfMRI_fcnxpro122_VisPeri_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.sommotb
rsfMRI_fcnxpro122_VisPeri_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.sommota
rsfMRI_fcnxpro122_VisPeri_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.visperi
rsfMRI_fcnxpro122_VisPeri_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.visperi.2.viscent
rsfMRI_fcnxpro122_VisCent_2_TempPar
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.temppar
rsfMRI_fcnxpro122_VisCent_2_DefaultC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.defaultc
rsfMRI_fcnxpro122_VisCent_2_DefaultB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.defaultb
rsfMRI_fcnxpro122_VisCent_2_DefaultA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.defaulta
rsfMRI_fcnxpro122_VisCent_2_ContC
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.contc
rsfMRI_fcnxpro122_VisCent_2_ContB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.contb
rsfMRI_fcnxpro122_VisCent_2_ContA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.conta
rsfMRI_fcnxpro122_VisCent_2_LimbicA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.limbica
rsfMRI_fcnxpro122_VisCent_2_LimbicB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.limbicb
rsfMRI_fcnxpro122_VisCent_2_SalVentAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.salventattnb
rsfMRI_fcnxpro122_VisCent_2_SalVentAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.salventattna
rsfMRI_fcnxpro122_VisCent_2_DorsAttnB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.dorsattnb
rsfMRI_fcnxpro122_VisCent_2_DorsAttnA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.dorsattna
rsfMRI_fcnxpro122_VisCent_2_SomMotB
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.sommotb
rsfMRI_fcnxpro122_VisCent_2_SomMotA
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.sommota
rsfMRI_fcnxpro122_VisCent_2_VisPeri
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.visperi
rsfMRI_fcnxpro122_VisCent_2_VisCent
restingStatefMRI
​
yeo_homotopic
network correlation
unlabeled / likely somatosensory
rsf.viscent.2.viscent
NM2DMT_mean_bn_gp_gpe_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
globus pallidus externa
nm2dmt.mean.bn.gp.gpe.left
NM2DMT_mean_bn_gp_gpe_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
globus pallidus externa
nm2dmt.mean.bn.gp.gpe.right
NM2DMT_mean_bn_gp_gpi_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
globus pallidus interna
nm2dmt.mean.bn.gp.gpi.left
NM2DMT_mean_bn_gp_gpi_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
globus pallidus interna
nm2dmt.mean.bn.gp.gpi.right
NM2DMT_mean_bn_str_pu_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
putamen
nm2dmt.mean.bn.str.pu.left
NM2DMT_mean_bn_str_pu_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
putamen
nm2dmt.mean.bn.str.pu.right
NM2DMT_mean_mtg_rn_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
red nucleus
nm2dmt.mean.mtg.rn.left
NM2DMT_mean_mtg_rn_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
red nucleus
nm2dmt.mean.mtg.rn.right
NM2DMT_mean_mtg_sn_snc_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
Substantia Nigra pars compacta
nm2dmt.mean.snc.left
NM2DMT_mean_mtg_sn_snc_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
Substantia Nigra pars compacta
nm2dmt.mean.snc.right
NM2DMT_mean_mtg_sn_snr_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
Substantia Nigra pars reticulated
nm2dmt.mean.snr.left
NM2DMT_mean_mtg_sn_snr_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
Substantia Nigra pars reticulated
nm2dmt.mean.snr.right
NM2DMT_mean_referenceregion_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
​
nm2dmt.mean.referenceregion.left
NM2DMT_mean_referenceregion_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
​
nm2dmt.mean.referenceregion.right
NM2DMT_NM_avg_mean
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.avg.mean
NM2DMT_NM_avg_cropped_mean
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.avg.cropped.mean
NM2DMT_NM_labels_mean
Neuromelanin
​
ANTs
​
​
nm2dmt.nm.labels.mean
NM2DMT_NM_midbrainROI_mean
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
nm2dmt.nm.midbrainroi.mean
NM2DMT_t1_to_NM_mean
Neuromelanin
​
ANTs
​
​
nm2dmt.t1.to.nm.mean
NM2DMT_NM_volume_substantianigra
Neuromelanin
​
ANTs
geometry/volume
NM2DMT NMsubstantianigra
nm2dmt.nm.volume.substantianigra
NM2DMT_NM_q0pt05
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
nm2dmt.nm.q0pt05
NM2DMT_NM_q0pt10
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
nm2dmt.nm.q0pt10
NM2DMT_NM_q0pt90
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
nm2dmt.nm.q0pt90
NM2DMT_NM_q0pt95
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
nm2dmt.nm.q0pt95
NM2DMT_NM_substantianigra_z_coordinate
Neuromelanin
​
ANTs
Estimate of the normalize (zero to one) z-coordinate of the substantia nigra in a neuromelanin scan; higher values mean higher in the slab
​
nm2dmt.nm.substantianigra.z.coordinate
NM2DMT_NM_evr
Neuromelanin
​
ANTs
QC
​
nm2dmt.nm.evr
NM2DMT_NM_count
Neuromelanin
​
ANTs
count of neuromelanin scans that were averaged at this date
​
nm2dmt.nm.count
DTI_mean_fa.anterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
anterior corona radiata
dti.fa.ant.cor.rad.left
DTI_mean_fa.anterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
anterior corona radiata
dti.fa.ant.cor.rad.right
DTI_mean_fa.anterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
anterior limb of internal capsule
dti.fa.ant.int.cap.left
DTI_mean_fa.anterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
anterior limb of internal capsule
dti.fa.ant.int.cap.right
DTI_mean_fa.body_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
body of corpus callosum
dti.fa.body.of.corpus.callosum
DTI_mean_fa.cerebral_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
cerebral peduncle
dti.fa.cerebral.peduncle.left
DTI_mean_fa.cerebral_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
cerebral peduncle
dti.fa.cerebral.peduncle.right
DTI_mean_fa.cingulum_.cingulate_gyrus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
cingulum cingulate gyrus
dti.fa.cingulum.cingulate.gyrus.left
DTI_mean_fa.cingulum_.cingulate_gyrus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
cingulum cingulate gyrus
dti.fa.cingulum.cingulate.gyrus.right
DTI_mean_fa.cingulum_.hippocampus..left.jhu_icbm_labels_1mm
DTI
left
desikan-killiany-tourville
fractional anisotropy
hippocampus
dti.fa.cingulum.hippocampus.left
DTI_mean_fa.cingulum_.hippocampus..right.jhu_icbm_labels_1mm
DTI
right
desikan-killiany-tourville
fractional anisotropy
hippocampus
dti.fa.cingulum.hippocampus.right
DTI_mean_fa.corticospinal_tract.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
corticospinal tract
dti.fa.corticospinal.tract.left
DTI_mean_fa.corticospinal_tract.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
corticospinal tract
dti.fa.corticospinal.tract.right
DTI_mean_fa.external_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
external capsule
dti.fa.ext.cap.left
DTI_mean_fa.external_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
external capsule
dti.fa.ext.cap.right
DTI_mean_fa.fornix_.column_and_body_of_fornix..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
fornix column and body of fornix
dti.fa.fornix.column.and.body.of.fornix.
DTI_mean_fa.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
fornix cres stria terminalis can not be resolved with current resolution
dti.fa.fornixleft
DTI_mean_fa.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
fornix cres stria terminalis can not be resolved with current resolution
dti.fa.fornixright
DTI_mean_fa.genu_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
genu of corpus callosum
dti.fa.genu.of.corpus.callosum
DTI_mean_fa.inferior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
inferior cerebellar peduncle
dti.fa.inf.cereb.ped.left
DTI_mean_fa.inferior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
inferior cerebellar peduncle
dti.fa.inf.cereb.ped.right
DTI_mean_fa.inferior_fronto.occipital_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
inferior fronto occipital fasciculus
dti.fa.inf.frnt.occ.fasciculus.left
DTI_mean_fa.inferior_fronto.occipital_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
inferior fronto occipital fasciculus
dti.fa.inf.frnt.occ.fasciculus.right
DTI_mean_fa.medial_lemniscus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
medial lemniscus
dti.fa.medial.lemniscus.left
DTI_mean_fa.medial_lemniscus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
medial lemniscus
dti.fa.medial.lemniscus.right
DTI_mean_fa.middle_cerebellar_peduncle.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
middle cerebellar peduncle
dti.fa.middle.cereb.ped
DTI_mean_fa.pontine_crossing_tract_.a_part_of_mcp..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
pontine crossing tract a part of mcp
dti.fa.pontine.
DTI_mean_fa.posterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
posterior corona radiata
dti.fa.post.cor.rad.left
DTI_mean_fa.posterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
posterior corona radiata
dti.fa.post.cor.rad.right
DTI_mean_fa.posterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
posterior limb of internal capsule
dti.fa.post.int.cap.left
DTI_mean_fa.posterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
posterior limb of internal capsule
dti.fa.post.int.cap.right
DTI_mean_fa.posterior_thalamic_radiation_.include_optic_radiation..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
posterior thalamic radiation include optic radiation
dti.fa.post.thalamic.radiation.optic.radiation.left
DTI_mean_fa.posterior_thalamic_radiation_.include_optic_radiation..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
posterior thalamic radiation include optic radiation
dti.fa.post.thalamic.radiation.optic.radiation.right
DTI_mean_fa.retrolenticular_part_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
retrolenticular part of internal capsule
dti.fa.rent.int.cap.left
DTI_mean_fa.retrolenticular_part_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
retrolenticular part of internal capsule
dti.fa.rent.int.cap.right
DTI_mean_fa.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
sagittal stratum include inferior longitidinal fasciculus and inferior fronto occipital fasciculus
dti.fa.ilf.and.ifoleft
DTI_mean_fa.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
sagittal stratum include inferior longitidinal fasciculus and inferior fronto occipital fasciculus
dti.fa.ilf.and.iforight
DTI_mean_fa.splenium_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
splenium of corpus callosum
dti.fa.splenium.of.corpus.callosum
DTI_mean_fa.superior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
superior cerebellar peduncle
dti.fa.sup.cereb.ped.left
DTI_mean_fa.superior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
superior cerebellar peduncle
dti.fa.sup.cereb.ped.right
DTI_mean_fa.superior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
superior corona radiata
dti.fa.sup.cor.rad.left
DTI_mean_fa.superior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
superior corona radiata
dti.fa.sup.cor.rad.right
DTI_mean_fa.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
superior fronto occipital fasciculus could be a part of anterior internal capsule
dti.fa.sup.frnt.occ.fasc.left
DTI_mean_fa.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
superior fronto occipital fasciculus could be a part of anterior internal capsule
dti.fa.sup.frnt.occ.fasc.right
DTI_mean_fa.superior_longitudinal_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
superior longitudinal fasciculus
dti.fa.sup.l.fasc.left
DTI_mean_fa.superior_longitudinal_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
superior longitudinal fasciculus
dti.fa.sup.l.fasc.right
DTI_mean_fa.tapetum.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
tapetum
dti.fa.tapetum.left
DTI_mean_fa.tapetum.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
tapetum
dti.fa.tapetum.right
DTI_mean_fa.uncinate_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
uncinate fasciculus
dti.fa.uncinate.fasciculus.left
DTI_mean_fa.uncinate_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
uncinate fasciculus
dti.fa.uncinate.fasciculus.right
DTI_mean_fa.unclassified.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
unclassified
dti.fa.unclassified
DTI_mean_md.anterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
anterior corona radiata
dti.mean.md.ant.cor.rad.left
DTI_mean_md.anterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
anterior corona radiata
dti.mean.md.ant.cor.rad.right
DTI_mean_md.anterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
anterior limb of internal capsule
dti.mean.md.ant.int.cap.left
DTI_mean_md.anterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
anterior limb of internal capsule
dti.mean.md.ant.int.cap.right
DTI_mean_md.body_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
body of corpus callosum
dti.mean.md.body.of.corpus.callosum
DTI_mean_md.cerebral_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
cerebral peduncle
dti.mean.md.cerebral.peduncle.left
DTI_mean_md.cerebral_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
cerebral peduncle
dti.mean.md.cerebral.peduncle.right
DTI_mean_md.cingulum_.cingulate_gyrus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
cingulum cingulate gyrus
dti.mean.md.cingulum.cingulate.gyrus.left
DTI_mean_md.cingulum_.cingulate_gyrus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
cingulum cingulate gyrus
dti.mean.md.cingulum.cingulate.gyrus.right
DTI_mean_md.cingulum_.hippocampus..left.jhu_icbm_labels_1mm
DTI
left
desikan-killiany-tourville
mean diffusion
hippocampus
dti.mean.md.cingulum.hippocampus.left
DTI_mean_md.cingulum_.hippocampus..right.jhu_icbm_labels_1mm
DTI
right
desikan-killiany-tourville
mean diffusion
hippocampus
dti.mean.md.cingulum.hippocampus.right
DTI_mean_md.corticospinal_tract.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
corticospinal tract
dti.mean.md.corticospinal.tract.left
DTI_mean_md.corticospinal_tract.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
corticospinal tract
dti.mean.md.corticospinal.tract.right
DTI_mean_md.external_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
external capsule
dti.mean.md.ext.cap.left
DTI_mean_md.external_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
external capsule
dti.mean.md.ext.cap.right
DTI_mean_md.fornix_.column_and_body_of_fornix..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
fornix column and body of fornix
dti.mean.md.fornix.column.and.body.of.fornix.
DTI_mean_md.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
fornix cres stria terminalis can not be resolved with current resolution
dti.mean.md.fornixleft
DTI_mean_md.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
fornix cres stria terminalis can not be resolved with current resolution
dti.mean.md.fornixright
DTI_mean_md.genu_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
genu of corpus callosum
dti.mean.md.genu.of.corpus.callosum
DTI_mean_md.inferior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
inferior cerebellar peduncle
dti.mean.md.inf.cereb.ped.left
DTI_mean_md.inferior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
inferior cerebellar peduncle
dti.mean.md.inf.cereb.ped.right
DTI_mean_md.inferior_fronto.occipital_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
inferior fronto occipital fasciculus
dti.mean.md.inf.frnt.occ.fasciculus.left
DTI_mean_md.inferior_fronto.occipital_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
inferior fronto occipital fasciculus
dti.mean.md.inf.frnt.occ.fasciculus.right
DTI_mean_md.medial_lemniscus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
medial lemniscus
dti.mean.md.medial.lemniscus.left
DTI_mean_md.medial_lemniscus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
medial lemniscus
dti.mean.md.medial.lemniscus.right
DTI_mean_md.middle_cerebellar_peduncle.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
middle cerebellar peduncle
dti.mean.md.middle.cereb.ped
DTI_mean_md.pontine_crossing_tract_.a_part_of_mcp..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
pontine crossing tract a part of mcp
dti.mean.md.pontine.
DTI_mean_md.posterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
posterior corona radiata
dti.mean.md.post.cor.rad.left
DTI_mean_md.posterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
posterior corona radiata
dti.mean.md.post.cor.rad.right
DTI_mean_md.posterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
posterior limb of internal capsule
dti.mean.md.post.int.cap.left
DTI_mean_md.posterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
posterior limb of internal capsule
dti.mean.md.post.int.cap.right
DTI_mean_md.posterior_thalamic_radiation_.include_optic_radiation..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
posterior thalamic radiation include optic radiation
dti.mean.md.post.thalamic.radiation.optic.radiation.left
DTI_mean_md.posterior_thalamic_radiation_.include_optic_radiation..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
posterior thalamic radiation include optic radiation
dti.mean.md.post.thalamic.radiation.optic.radiation.right
DTI_mean_md.retrolenticular_part_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
retrolenticular part of internal capsule
dti.mean.md.rent.int.cap.left
DTI_mean_md.retrolenticular_part_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
retrolenticular part of internal capsule
dti.mean.md.rent.int.cap.right
DTI_mean_md.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
sagittal stratum include inferior longitidinal fasciculus and inferior fronto occipital fasciculus
dti.mean.md.ilf.and.ifoleft
DTI_mean_md.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
sagittal stratum include inferior longitidinal fasciculus and inferior fronto occipital fasciculus
dti.mean.md.ilf.and.iforight
DTI_mean_md.splenium_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
splenium of corpus callosum
dti.mean.md.splenium.of.corpus.callosum
DTI_mean_md.superior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
superior cerebellar peduncle
dti.mean.md.sup.cereb.ped.left
DTI_mean_md.superior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
superior cerebellar peduncle
dti.mean.md.sup.cereb.ped.right
DTI_mean_md.superior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
superior corona radiata
dti.mean.md.sup.cor.rad.left
DTI_mean_md.superior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
superior corona radiata
dti.mean.md.sup.cor.rad.right
DTI_mean_md.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
superior fronto occipital fasciculus could be a part of anterior internal capsule
dti.mean.md.sup.frnt.occ.fasc.left
DTI_mean_md.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
superior fronto occipital fasciculus could be a part of anterior internal capsule
dti.mean.md.sup.frnt.occ.fasc.right
DTI_mean_md.superior_longitudinal_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
superior longitudinal fasciculus
dti.mean.md.sup.l.fasc.left
DTI_mean_md.superior_longitudinal_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
superior longitudinal fasciculus
dti.mean.md.sup.l.fasc.right
DTI_mean_md.tapetum.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
tapetum
dti.mean.md.tapetum.left
DTI_mean_md.tapetum.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
tapetum
dti.mean.md.tapetum.right
DTI_mean_md.uncinate_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
uncinate fasciculus
dti.mean.md.uncinate.fasciculus.left
DTI_mean_md.uncinate_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
uncinate fasciculus
dti.mean.md.uncinate.fasciculus.right
DTI_mean_md.unclassified.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
unclassified
dti.mean.md.unclassified
DTI_mean_fa_background
DTI
​
ANTs
fractional anisotropy
background
dti.fa.background
DTI_mean_fa_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
caudal anterior cingulate
dti.fa.left.caudal.ant.cingulate
DTI_mean_fa_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
caudal middle frontal
dti.fa.left.caudal.middle.frontal
DTI_mean_fa_left_cuneus
DTI
left
desikan-killiany-tourville
fractional anisotropy
cuneus
dti.fa.left.cuneus
DTI_mean_fa_left_entorhinal
DTI
left
desikan-killiany-tourville
fractional anisotropy
entorhinal
dti.fa.left.entorhinal
DTI_mean_fa_left_fusiform
DTI
left
desikan-killiany-tourville
fractional anisotropy
fusiform
dti.fa.left.fusiform
DTI_mean_fa_left_inferior_parietal
DTI
left
desikan-killiany-tourville
fractional anisotropy
inferior parietal
dti.fa.left.inf.parietal
DTI_mean_fa_left_inferior_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
inferior temporal
dti.fa.left.inf.temporal
DTI_mean_fa_left_insula
DTI
left
desikan-killiany-tourville
fractional anisotropy
insula
dti.fa.left.insula
DTI_mean_fa_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
isthmus cingulate
dti.fa.left.isthmus.cingulate
DTI_mean_fa_left_lateral_occipital
DTI
left
desikan-killiany-tourville
fractional anisotropy
lateral occipital
dti.fa.left.lateral.occipital
DTI_mean_fa_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
lateral orbitofrontal
dti.fa.left.lateral.orbitofrontal
DTI_mean_fa_left_lingual
DTI
left
desikan-killiany-tourville
fractional anisotropy
lingual
dti.fa.left.lingual
DTI_mean_fa_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
medial orbitofrontal
dti.fa.left.medial.orbitofrontal
DTI_mean_fa_left_middle_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
middle temporal
dti.fa.left.middle.temporal
DTI_mean_fa_left_paracentral
DTI
left
desikan-killiany-tourville
fractional anisotropy
paracentral
dti.fa.left.paracent
DTI_mean_fa_left_parahippocampal
DTI
left
desikan-killiany-tourville
fractional anisotropy
parahippocampal
dti.fa.left.parahippocampal
DTI_mean_fa_left_pars_opercularis
DTI
left
desikan-killiany-tourville
fractional anisotropy
pars opercularis
dti.fa.left.pars.opercularis
DTI_mean_fa_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
fractional anisotropy
pars orbitalis
dti.fa.left.pars.orbitalis
DTI_mean_fa_left_pars_triangularis
DTI
left
desikan-killiany-tourville
fractional anisotropy
pars triangularis
dti.fa.left.pars.triangularis
DTI_mean_fa_left_pericalcarine
DTI
left
desikan-killiany-tourville
fractional anisotropy
pericalcarine
dti.fa.left.pericalcarine
DTI_mean_fa_left_postcentral
DTI
left
desikan-killiany-tourville
fractional anisotropy
postcentral
dti.fa.left.postcent
DTI_mean_fa_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
posterior cingulate
dti.fa.left.post.cingulate
DTI_mean_fa_left_precentral
DTI
left
desikan-killiany-tourville
fractional anisotropy
precentral
dti.fa.left.precent
DTI_mean_fa_left_precuneus
DTI
left
desikan-killiany-tourville
fractional anisotropy
precuneus
dti.fa.left.precuneus
DTI_mean_fa_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
rostral anterior cingulate
dti.fa.left.rostral.ant.cingulate
DTI_mean_fa_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
rostral middle frontal
dti.fa.left.rostral.middle.frontal
DTI_mean_fa_left_superior_frontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
superior frontal
dti.fa.left.sup.frontal
DTI_mean_fa_left_superior_parietal
DTI
left
desikan-killiany-tourville
fractional anisotropy
superior parietal
dti.fa.left.sup.parietal
DTI_mean_fa_left_superior_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
superior temporal
dti.fa.left.sup.temporal
DTI_mean_fa_left_supramarginal
DTI
left
desikan-killiany-tourville
fractional anisotropy
supramarginal
dti.fa.left.supramarginal
DTI_mean_fa_left_transverse_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
transverse temporal
dti.fa.left.transverse.temporal
DTI_mean_fa_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
caudal anterior cingulate
dti.fa.right.caudal.ant.cingulate
DTI_mean_fa_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
caudal middle frontal
dti.fa.right.caudal.middle.frontal
DTI_mean_fa_right_cuneus
DTI
right
desikan-killiany-tourville
fractional anisotropy
cuneus
dti.fa.right.cuneus
DTI_mean_fa_right_entorhinal
DTI
right
desikan-killiany-tourville
fractional anisotropy
entorhinal
dti.fa.right.entorhinal
DTI_mean_fa_right_fusiform
DTI
right
desikan-killiany-tourville
fractional anisotropy
fusiform
dti.fa.right.fusiform
DTI_mean_fa_right_inferior_parietal
DTI
right
desikan-killiany-tourville
fractional anisotropy
inferior parietal
dti.fa.right.inf.parietal
DTI_mean_fa_right_inferior_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
inferior temporal
dti.fa.right.inf.temporal
DTI_mean_fa_right_insula
DTI
right
desikan-killiany-tourville
fractional anisotropy
insula
dti.fa.right.insula
DTI_mean_fa_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
isthmus cingulate
dti.fa.right.isthmus.cingulate
DTI_mean_fa_right_lateral_occipital
DTI
right
desikan-killiany-tourville
fractional anisotropy
lateral occipital
dti.fa.right.lateral.occipital
DTI_mean_fa_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
lateral orbitofrontal
dti.fa.right.lateral.orbitofrontal
DTI_mean_fa_right_lingual
DTI
right
desikan-killiany-tourville
fractional anisotropy
lingual
dti.fa.right.lingual
DTI_mean_fa_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
medial orbitofrontal
dti.fa.right.medial.orbitofrontal
DTI_mean_fa_right_middle_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
middle temporal
dti.fa.right.middle.temporal
DTI_mean_fa_right_paracentral
DTI
right
desikan-killiany-tourville
fractional anisotropy
paracentral
dti.fa.right.paracent
DTI_mean_fa_right_parahippocampal
DTI
right
desikan-killiany-tourville
fractional anisotropy
parahippocampal
dti.fa.right.parahippocampal
DTI_mean_fa_right_pars_opercularis
DTI
right
desikan-killiany-tourville
fractional anisotropy
pars opercularis
dti.fa.right.pars.opercularis
DTI_mean_fa_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
fractional anisotropy
pars orbitalis
dti.fa.right.pars.orbitalis
DTI_mean_fa_right_pars_triangularis
DTI
right
desikan-killiany-tourville
fractional anisotropy
pars triangularis
dti.fa.right.pars.triangularis
DTI_mean_fa_right_pericalcarine
DTI
right
desikan-killiany-tourville
fractional anisotropy
pericalcarine
dti.fa.right.pericalcarine
DTI_mean_fa_right_postcentral
DTI
right
desikan-killiany-tourville
fractional anisotropy
postcentral
dti.fa.right.postcent
DTI_mean_fa_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
posterior cingulate
dti.fa.right.post.cingulate
DTI_mean_fa_right_precentral
DTI
right
desikan-killiany-tourville
fractional anisotropy
precentral
dti.fa.right.precent
DTI_mean_fa_right_precuneus
DTI
right
desikan-killiany-tourville
fractional anisotropy
precuneus
dti.fa.right.precuneus
DTI_mean_fa_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
rostral anterior cingulate
dti.fa.right.rostral.ant.cingulate
DTI_mean_fa_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
rostral middle frontal
dti.fa.right.rostral.middle.frontal
DTI_mean_fa_right_superior_frontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
superior frontal
dti.fa.right.sup.frontal
DTI_mean_fa_right_superior_parietal
DTI
right
desikan-killiany-tourville
fractional anisotropy
superior parietal
dti.fa.right.sup.parietal
DTI_mean_fa_right_superior_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
superior temporal
dti.fa.right.sup.temporal
DTI_mean_fa_right_supramarginal
DTI
right
desikan-killiany-tourville
fractional anisotropy
supramarginal
dti.fa.right.supramarginal
DTI_mean_fa_right_transverse_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
transverse temporal
dti.fa.right.transverse.temporal
DTI_volume_fa_background
DTI
​
ANTs
geometry/volume
background
dti.volume.fa.background
DTI_volume_fa_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
dti.volume.fa.left.caudal.ant.cingulate
DTI_volume_fa_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
dti.volume.fa.left.caudal.middle.frontal
DTI_volume_fa_left_cuneus
DTI
left
desikan-killiany-tourville
geometry/volume
cuneus
dti.volume.fa.left.cuneus
DTI_volume_fa_left_entorhinal
DTI
left
desikan-killiany-tourville
geometry/volume
entorhinal
dti.volume.fa.left.entorhinal
DTI_volume_fa_left_fusiform
DTI
left
desikan-killiany-tourville
geometry/volume
fusiform
dti.volume.fa.left.fusiform
DTI_volume_fa_left_inferior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior parietal
dti.volume.fa.left.inf.parietal
DTI_volume_fa_left_inferior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior temporal
dti.volume.fa.left.inf.temporal
DTI_volume_fa_left_insula
DTI
left
desikan-killiany-tourville
geometry/volume
insula
dti.volume.fa.left.insula
DTI_volume_fa_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
dti.volume.fa.left.isthmus.cingulate
DTI_volume_fa_left_lateral_occipital
DTI
left
desikan-killiany-tourville
geometry/volume
lateral occipital
dti.volume.fa.left.lateral.occipital
DTI_volume_fa_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
dti.volume.fa.left.lateral.orbitofrontal
DTI_volume_fa_left_lingual
DTI
left
desikan-killiany-tourville
geometry/volume
lingual
dti.volume.fa.left.lingual
DTI_volume_fa_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
dti.volume.fa.left.medial.orbitofrontal
DTI_volume_fa_left_middle_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
middle temporal
dti.volume.fa.left.middle.temporal
DTI_volume_fa_left_paracentral
DTI
left
desikan-killiany-tourville
geometry/volume
paracentral
dti.volume.fa.left.paracent
DTI_volume_fa_left_parahippocampal
DTI
left
desikan-killiany-tourville
geometry/volume
parahippocampal
dti.volume.fa.left.parahippocampal
DTI_volume_fa_left_pars_opercularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars opercularis
dti.volume.fa.left.pars.opercularis
DTI_volume_fa_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
dti.volume.fa.left.pars.orbitalis
DTI_volume_fa_left_pars_triangularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars triangularis
dti.volume.fa.left.pars.triangularis
DTI_volume_fa_left_pericalcarine
DTI
left
desikan-killiany-tourville
geometry/volume
pericalcarine
dti.volume.fa.left.pericalcarine
DTI_volume_fa_left_postcentral
DTI
left
desikan-killiany-tourville
geometry/volume
postcentral
dti.volume.fa.left.postcent
DTI_volume_fa_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
dti.volume.fa.left.post.cingulate
DTI_volume_fa_left_precentral
DTI
left
desikan-killiany-tourville
geometry/volume
precentral
dti.volume.fa.left.precent
DTI_volume_fa_left_precuneus
DTI
left
desikan-killiany-tourville
geometry/volume
precuneus
dti.volume.fa.left.precuneus
DTI_volume_fa_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
dti.volume.fa.left.rostral.ant.cingulate
DTI_volume_fa_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
dti.volume.fa.left.rostral.middle.frontal
DTI_volume_fa_left_superior_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
superior frontal
dti.volume.fa.left.sup.frontal
DTI_volume_fa_left_superior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
superior parietal
dti.volume.fa.left.sup.parietal
DTI_volume_fa_left_superior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
superior temporal
dti.volume.fa.left.sup.temporal
DTI_volume_fa_left_supramarginal
DTI
left
desikan-killiany-tourville
geometry/volume
supramarginal
dti.volume.fa.left.supramarginal
DTI_volume_fa_left_transverse_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
transverse temporal
dti.volume.fa.left.transverse.temporal
DTI_volume_fa_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
dti.volume.fa.right.caudal.ant.cingulate
DTI_volume_fa_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
dti.volume.fa.right.caudal.middle.frontal
DTI_volume_fa_right_cuneus
DTI
right
desikan-killiany-tourville
geometry/volume
cuneus
dti.volume.fa.right.cuneus
DTI_volume_fa_right_entorhinal
DTI
right
desikan-killiany-tourville
geometry/volume
entorhinal
dti.volume.fa.right.entorhinal
DTI_volume_fa_right_fusiform
DTI
right
desikan-killiany-tourville
geometry/volume
fusiform
dti.volume.fa.right.fusiform
DTI_volume_fa_right_inferior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior parietal
dti.volume.fa.right.inf.parietal
DTI_volume_fa_right_inferior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior temporal
dti.volume.fa.right.inf.temporal
DTI_volume_fa_right_insula
DTI
right
desikan-killiany-tourville
geometry/volume
insula
dti.volume.fa.right.insula
DTI_volume_fa_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
dti.volume.fa.right.isthmus.cingulate
DTI_volume_fa_right_lateral_occipital
DTI
right
desikan-killiany-tourville
geometry/volume
lateral occipital
dti.volume.fa.right.lateral.occipital
DTI_volume_fa_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
dti.volume.fa.right.lateral.orbitofrontal
DTI_volume_fa_right_lingual
DTI
right
desikan-killiany-tourville
geometry/volume
lingual
dti.volume.fa.right.lingual
DTI_volume_fa_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
dti.volume.fa.right.medial.orbitofrontal
DTI_volume_fa_right_middle_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
middle temporal
dti.volume.fa.right.middle.temporal
DTI_volume_fa_right_paracentral
DTI
right
desikan-killiany-tourville
geometry/volume
paracentral
dti.volume.fa.right.paracent
DTI_volume_fa_right_parahippocampal
DTI
right
desikan-killiany-tourville
geometry/volume
parahippocampal
dti.volume.fa.right.parahippocampal
DTI_volume_fa_right_pars_opercularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars opercularis
dti.volume.fa.right.pars.opercularis
DTI_volume_fa_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
dti.volume.fa.right.pars.orbitalis
DTI_volume_fa_right_pars_triangularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars triangularis
dti.volume.fa.right.pars.triangularis
DTI_volume_fa_right_pericalcarine
DTI
right
desikan-killiany-tourville
geometry/volume
pericalcarine
dti.volume.fa.right.pericalcarine
DTI_volume_fa_right_postcentral
DTI
right
desikan-killiany-tourville
geometry/volume
postcentral
dti.volume.fa.right.postcent
DTI_volume_fa_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
dti.volume.fa.right.post.cingulate
DTI_volume_fa_right_precentral
DTI
right
desikan-killiany-tourville
geometry/volume
precentral
dti.volume.fa.right.precent
DTI_volume_fa_right_precuneus
DTI
right
desikan-killiany-tourville
geometry/volume
precuneus
dti.volume.fa.right.precuneus
DTI_volume_fa_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
dti.volume.fa.right.rostral.ant.cingulate
DTI_volume_fa_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
dti.volume.fa.right.rostral.middle.frontal
DTI_volume_fa_right_superior_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
superior frontal
dti.volume.fa.right.sup.frontal
DTI_volume_fa_right_superior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
superior parietal
dti.volume.fa.right.sup.parietal
DTI_volume_fa_right_superior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
superior temporal
dti.volume.fa.right.sup.temporal
DTI_volume_fa_right_supramarginal
DTI
right
desikan-killiany-tourville
geometry/volume
supramarginal
dti.volume.fa.right.supramarginal
DTI_volume_fa_right_transverse_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
transverse temporal
dti.volume.fa.right.transverse.temporal
DTI_mean_fa_deep_bn_gp_gpe_left
DTI
left
CIT168
fractional anisotropy
globus pallidus externa
dti.fa.deep.bn.gp.gpe.left
DTI_mean_fa_deep_bn_gp_gpe_right
DTI
right
CIT168
fractional anisotropy
globus pallidus externa
dti.fa.deep.bn.gp.gpe.right
DTI_mean_fa_deep_bn_gp_gpi_left
DTI
left
CIT168
fractional anisotropy
globus pallidus interna
dti.fa.deep.bn.gp.gpi.left
DTI_mean_fa_deep_bn_gp_gpi_right
DTI
right
CIT168
fractional anisotropy
globus pallidus interna
dti.fa.deep.bn.gp.gpi.right
DTI_mean_fa_deep_bn_str_ca_left
DTI
left
CIT168
fractional anisotropy
caudate
dti.fa.deep.bn.str.ca.left
DTI_mean_fa_deep_bn_str_ca_right
DTI
right
CIT168
fractional anisotropy
caudate
dti.fa.deep.bn.str.ca.right
DTI_mean_fa_deep_bn_str_pu_left
DTI
left
CIT168
fractional anisotropy
putamen
dti.fa.deep.bn.str.pu.left
DTI_mean_fa_deep_bn_str_pu_right
DTI
right
CIT168
fractional anisotropy
putamen
dti.fa.deep.bn.str.pu.right
DTI_mean_fa_deep_mtg_rn_left
DTI
left
CIT168
fractional anisotropy
red nucleus
dti.fa.deep.mtg.rn.left
DTI_mean_fa_deep_mtg_rn_right
DTI
right
CIT168
fractional anisotropy
red nucleus
dti.fa.deep.mtg.rn.right
DTI_mean_fa_deep_mtg_sn_snc_left
DTI
left
CIT168
fractional anisotropy
Substantia Nigra pars compacta
dti.fa.deep.snc.left
DTI_mean_fa_deep_mtg_sn_snc_right
DTI
right
CIT168
fractional anisotropy
Substantia Nigra pars compacta
dti.fa.deep.snc.right
DTI_mean_fa_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.fa.deep.snr.left
DTI_mean_fa_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.fa.deep.snr.right
DTI_mean_fa_deep_referenceregion_left
DTI
left
CIT168
fractional anisotropy
​
dti.fa.deep.referenceregion.left
DTI_mean_fa_deep_referenceregion_right
DTI
right
CIT168
fractional anisotropy
​
dti.fa.deep.referenceregion.right
DTI_volume_fa_deep_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
dti.volume.fa.deep.bn.gp.gpe.left
DTI_volume_fa_deep_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
dti.volume.fa.deep.bn.gp.gpe.right
DTI_volume_fa_deep_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
dti.volume.fa.deep.bn.gp.gpi.left
DTI_volume_fa_deep_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
dti.volume.fa.deep.bn.gp.gpi.right
DTI_volume_fa_deep_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
dti.volume.fa.deep.bn.str.ca.left
DTI_volume_fa_deep_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
dti.volume.fa.deep.bn.str.ca.right
DTI_volume_fa_deep_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
dti.volume.fa.deep.bn.str.pu.left
DTI_volume_fa_deep_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
dti.volume.fa.deep.bn.str.pu.right
DTI_volume_fa_deep_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
dti.volume.fa.deep.mtg.rn.left
DTI_volume_fa_deep_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
dti.volume.fa.deep.mtg.rn.right
DTI_volume_fa_deep_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.fa.deep.snc.left
DTI_volume_fa_deep_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.fa.deep.snc.right
DTI_volume_fa_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.fa.deep.snr.left
DTI_volume_fa_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.fa.deep.snr.right
DTI_volume_fa_deep_referenceregion_left
DTI
left
CIT168
geometry/volume
​
dti.volume.fa.deep.referenceregion.left
DTI_volume_fa_deep_referenceregion_right
DTI
right
CIT168
geometry/volume
​
dti.volume.fa.deep.referenceregion.right
DTI_mean_fa_bn_gp_gpe_left
DTI
left
CIT168
fractional anisotropy
globus pallidus externa
dti.fa.bn.gp.gpe.left
DTI_mean_fa_bn_gp_gpe_right
DTI
right
CIT168
fractional anisotropy
globus pallidus externa
dti.fa.bn.gp.gpe.right
DTI_mean_fa_bn_gp_gpi_left
DTI
left
CIT168
fractional anisotropy
globus pallidus interna
dti.fa.bn.gp.gpi.left
DTI_mean_fa_bn_gp_gpi_right
DTI
right
CIT168
fractional anisotropy
globus pallidus interna
dti.fa.bn.gp.gpi.right
DTI_mean_fa_bn_gp_vep_left
DTI
left
CIT168
fractional anisotropy
ventral pallidum
dti.fa.bn.gp.vep.left
DTI_mean_fa_bn_gp_vep_right
DTI
right
CIT168
fractional anisotropy
ventral pallidum
dti.fa.bn.gp.vep.right
DTI_mean_fa_bn_str_ca_left
DTI
left
CIT168
fractional anisotropy
caudate
dti.fa.bn.str.ca.left
DTI_mean_fa_bn_str_ca_right
DTI
right
CIT168
fractional anisotropy
caudate
dti.fa.bn.str.ca.right
DTI_mean_fa_bn_str_nac_left
DTI
left
CIT168
fractional anisotropy
Nucleus Accumbens
dti.fa.bn.str.nac.left
DTI_mean_fa_bn_str_nac_right
DTI
right
CIT168
fractional anisotropy
Nucleus Accumbens
dti.fa.bn.str.nac.right
DTI_mean_fa_bn_str_pu_left
DTI
left
CIT168
fractional anisotropy
putamen
dti.fa.bn.str.pu.left
DTI_mean_fa_bn_str_pu_right
DTI
right
CIT168
fractional anisotropy
putamen
dti.fa.bn.str.pu.right
DTI_mean_fa_die_hth_left
DTI
left
CIT168
fractional anisotropy
Hypothalamus
dti.fa.die.hth.left
DTI_mean_fa_die_hth_mn_left
DTI
left
CIT168
fractional anisotropy
mammillary nucleus
dti.fa.die.hth.mn.left
DTI_mean_fa_die_hth_mn_right
DTI
right
CIT168
fractional anisotropy
mammillary nucleus
dti.fa.die.hth.mn.right
DTI_mean_fa_die_hth_right
DTI
right
CIT168
fractional anisotropy
Hypothalamus
dti.fa.die.hth.right
DTI_mean_fa_die_sth_left
DTI
left
CIT168
fractional anisotropy
Subthalamic Nucleus
dti.fa.die.sth.left
DTI_mean_fa_die_sth_right
DTI
right
CIT168
fractional anisotropy
Subthalamic Nucleus
dti.fa.die.sth.right
DTI_mean_fa_exa_left
DTI
left
CIT168
fractional anisotropy
extended amygdala
dti.fa.exa.left
DTI_mean_fa_exa_right
DTI
right
CIT168
fractional anisotropy
extended amygdala
dti.fa.exa.right
DTI_mean_fa_mtg_rn_left
DTI
left
CIT168
fractional anisotropy
red nucleus
dti.fa.mtg.rn.left
DTI_mean_fa_mtg_rn_right
DTI
right
CIT168
fractional anisotropy
red nucleus
dti.fa.mtg.rn.right
DTI_mean_fa_mtg_sn_snc_left
DTI
left
CIT168
fractional anisotropy
Substantia Nigra pars compacta
dti.fa.snc.left
DTI_mean_fa_mtg_sn_snc_right
DTI
right
CIT168
fractional anisotropy
Substantia Nigra pars compacta
dti.fa.snc.right
DTI_mean_fa_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.fa.snr.left
DTI_mean_fa_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.fa.snr.right
DTI_mean_fa_mtg_vtr_pbp_left
DTI
left
CIT168
fractional anisotropy
Parabrachial Pigmented Nucleus
dti.fa.mtg.vtr.pbp.left
DTI_mean_fa_mtg_vtr_pbp_right
DTI
right
CIT168
fractional anisotropy
Parabrachial Pigmented Nucleus
dti.fa.mtg.vtr.pbp.right
DTI_mean_fa_mtg_vtr_vta_left
DTI
left
CIT168
fractional anisotropy
Ventral Tegmental Area
dti.fa.mtg.vtr.vta.left
DTI_mean_fa_mtg_vtr_vta_right
DTI
right
CIT168
fractional anisotropy
Ventral Tegmental Area
dti.fa.mtg.vtr.vta.right
DTI_mean_fa_referenceregion_left
DTI
left
CIT168
fractional anisotropy
​
dti.fa.referenceregion.left
DTI_mean_fa_referenceregion_right
DTI
right
CIT168
fractional anisotropy
​
dti.fa.referenceregion.right
DTI_mean_fa_thm_eth_hn_left
DTI
left
CIT168
fractional anisotropy
Habenular Nuclei
dti.fa.thm.eth.hn.left
DTI_mean_fa_thm_eth_hn_right
DTI
right
CIT168
fractional anisotropy
Habenular Nuclei
dti.fa.thm.eth.hn.right
DTI_volume_fa_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
dti.volume.fa.bn.gp.gpe.left
DTI_volume_fa_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
dti.volume.fa.bn.gp.gpe.right
DTI_volume_fa_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
dti.volume.fa.bn.gp.gpi.left
DTI_volume_fa_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
dti.volume.fa.bn.gp.gpi.right
DTI_volume_fa_bn_gp_vep_left
DTI
left
CIT168
geometry/volume
ventral pallidum
dti.volume.fa.bn.gp.vep.left
DTI_volume_fa_bn_gp_vep_right
DTI
right
CIT168
geometry/volume
ventral pallidum
dti.volume.fa.bn.gp.vep.right
DTI_volume_fa_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
dti.volume.fa.bn.str.ca.left
DTI_volume_fa_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
dti.volume.fa.bn.str.ca.right
DTI_volume_fa_bn_str_nac_left
DTI
left
CIT168
geometry/volume
Nucleus Accumbens
dti.volume.fa.bn.str.nac.left
DTI_volume_fa_bn_str_nac_right
DTI
right
CIT168
geometry/volume
Nucleus Accumbens
dti.volume.fa.bn.str.nac.right
DTI_volume_fa_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
dti.volume.fa.bn.str.pu.left
DTI_volume_fa_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
dti.volume.fa.bn.str.pu.right
DTI_volume_fa_die_hth_left
DTI
left
CIT168
geometry/volume
Hypothalamus
dti.volume.fa.die.hth.left
DTI_volume_fa_die_hth_mn_left
DTI
left
CIT168
geometry/volume
mammillary nucleus
dti.volume.fa.die.hth.mn.left
DTI_volume_fa_die_hth_mn_right
DTI
right
CIT168
geometry/volume
mammillary nucleus
dti.volume.fa.die.hth.mn.right
DTI_volume_fa_die_hth_right
DTI
right
CIT168
geometry/volume
Hypothalamus
dti.volume.fa.die.hth.right
DTI_volume_fa_die_sth_left
DTI
left
CIT168
geometry/volume
Subthalamic Nucleus
dti.volume.fa.die.sth.left
DTI_volume_fa_die_sth_right
DTI
right
CIT168
geometry/volume
Subthalamic Nucleus
dti.volume.fa.die.sth.right
DTI_volume_fa_exa_left
DTI
left
CIT168
geometry/volume
extended amygdala
dti.volume.fa.exa.left
DTI_volume_fa_exa_right
DTI
right
CIT168
geometry/volume
extended amygdala
dti.volume.fa.exa.right
DTI_volume_fa_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
dti.volume.fa.mtg.rn.left
DTI_volume_fa_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
dti.volume.fa.mtg.rn.right
DTI_volume_fa_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.fa.snc.left
DTI_volume_fa_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.fa.snc.right
DTI_volume_fa_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.fa.snr.left
DTI_volume_fa_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.fa.snr.right
DTI_volume_fa_mtg_vtr_pbp_left
DTI
left
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
dti.volume.fa.mtg.vtr.pbp.left
DTI_volume_fa_mtg_vtr_pbp_right
DTI
right
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
dti.volume.fa.mtg.vtr.pbp.right
DTI_volume_fa_mtg_vtr_vta_left
DTI
left
CIT168
geometry/volume
Ventral Tegmental Area
dti.volume.fa.mtg.vtr.vta.left
DTI_volume_fa_mtg_vtr_vta_right
DTI
right
CIT168
geometry/volume
Ventral Tegmental Area
dti.volume.fa.mtg.vtr.vta.right
DTI_volume_fa_referenceregion_left
DTI
left
CIT168
geometry/volume
​
dti.volume.fa.referenceregion.left
DTI_volume_fa_referenceregion_right
DTI
right
CIT168
geometry/volume
​
dti.volume.fa.referenceregion.right
DTI_volume_fa_thm_eth_hn_left
DTI
left
CIT168
geometry/volume
Habenular Nuclei
dti.volume.fa.thm.eth.hn.left
DTI_volume_fa_thm_eth_hn_right
DTI
right
CIT168
geometry/volume
Habenular Nuclei
dti.volume.fa.thm.eth.hn.right
DTI_mean_fa_ch13_left
DTI
left
BF
fractional anisotropy
basal nucleus ch1 to ch3
dti.fa.ch13.left
DTI_mean_fa_ch13_right
DTI
right
BF
fractional anisotropy
basal nucleus ch1 to ch3
dti.fa.ch13.right
DTI_mean_fa_nbm_left_ant
DTI
left
BF
fractional anisotropy
basal nucleus anterior ch4
dti.fa.nbm.left.ant
DTI_mean_fa_nbm_left_mid
DTI
left
BF
fractional anisotropy
basal nucleus middle ch4
dti.fa.nbm.left.mid
DTI_mean_fa_nbm_left_pos
DTI
left
BF
fractional anisotropy
basal nucleus posterior ch4
dti.fa.nbm.left.pos
DTI_mean_fa_nbm_right_ant
DTI
right
BF
fractional anisotropy
basal nucleus anterior ch4
dti.fa.nbm.right.ant
DTI_mean_fa_nbm_right_mid
DTI
right
BF
fractional anisotropy
basal nucleus middle ch4
dti.fa.nbm.right.mid
DTI_mean_fa_nbm_right_pos
DTI
right
BF
fractional anisotropy
basal nucleus posterior ch4
dti.fa.nbm.right.pos
DTI_volume_fa_ch13_left
DTI
left
BF
geometry/volume
basal nucleus ch1 to ch3
dti.volume.fa.ch13.left
DTI_volume_fa_ch13_right
DTI
right
BF
geometry/volume
basal nucleus ch1 to ch3
dti.volume.fa.ch13.right
DTI_volume_fa_nbm_left_ant
DTI
left
BF
geometry/volume
basal nucleus anterior ch4
dti.volume.fa.nbm.left.ant
DTI_volume_fa_nbm_left_mid
DTI
left
BF
geometry/volume
basal nucleus middle ch4
dti.volume.fa.nbm.left.mid
DTI_volume_fa_nbm_left_pos
DTI
left
BF
geometry/volume
basal nucleus posterior ch4
dti.volume.fa.nbm.left.pos
DTI_volume_fa_nbm_right_ant
DTI
right
BF
geometry/volume
basal nucleus anterior ch4
dti.volume.fa.nbm.right.ant
DTI_volume_fa_nbm_right_mid
DTI
right
BF
geometry/volume
basal nucleus middle ch4
dti.volume.fa.nbm.right.mid
DTI_volume_fa_nbm_right_pos
DTI
right
BF
geometry/volume
basal nucleus posterior ch4
dti.volume.fa.nbm.right.pos
DTI_mean_md_background
DTI
​
ANTs
mean diffusion
background
dti.mean.md.background
DTI_mean_md_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
caudal anterior cingulate
dti.mean.md.left.caudal.ant.cingulate
DTI_mean_md_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
mean diffusion
caudal middle frontal
dti.mean.md.left.caudal.middle.frontal
DTI_mean_md_left_cuneus
DTI
left
desikan-killiany-tourville
mean diffusion
cuneus
dti.mean.md.left.cuneus
DTI_mean_md_left_entorhinal
DTI
left
desikan-killiany-tourville
mean diffusion
entorhinal
dti.mean.md.left.entorhinal
DTI_mean_md_left_fusiform
DTI
left
desikan-killiany-tourville
mean diffusion
fusiform
dti.mean.md.left.fusiform
DTI_mean_md_left_inferior_parietal
DTI
left
desikan-killiany-tourville
mean diffusion
inferior parietal
dti.mean.md.left.inf.parietal
DTI_mean_md_left_inferior_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
inferior temporal
dti.mean.md.left.inf.temporal
DTI_mean_md_left_insula
DTI
left
desikan-killiany-tourville
mean diffusion
insula
dti.mean.md.left.insula
DTI_mean_md_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
isthmus cingulate
dti.mean.md.left.isthmus.cingulate
DTI_mean_md_left_lateral_occipital
DTI
left
desikan-killiany-tourville
mean diffusion
lateral occipital
dti.mean.md.left.lateral.occipital
DTI_mean_md_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
mean diffusion
lateral orbitofrontal
dti.mean.md.left.lateral.orbitofrontal
DTI_mean_md_left_lingual
DTI
left
desikan-killiany-tourville
mean diffusion
lingual
dti.mean.md.left.lingual
DTI_mean_md_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
mean diffusion
medial orbitofrontal
dti.mean.md.left.medial.orbitofrontal
DTI_mean_md_left_middle_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
middle temporal
dti.mean.md.left.middle.temporal
DTI_mean_md_left_paracentral
DTI
left
desikan-killiany-tourville
mean diffusion
paracentral
dti.mean.md.left.paracent
DTI_mean_md_left_parahippocampal
DTI
left
desikan-killiany-tourville
mean diffusion
parahippocampal
dti.mean.md.left.parahippocampal
DTI_mean_md_left_pars_opercularis
DTI
left
desikan-killiany-tourville
mean diffusion
pars opercularis
dti.mean.md.left.pars.opercularis
DTI_mean_md_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
mean diffusion
pars orbitalis
dti.mean.md.left.pars.orbitalis
DTI_mean_md_left_pars_triangularis
DTI
left
desikan-killiany-tourville
mean diffusion
pars triangularis
dti.mean.md.left.pars.triangularis
DTI_mean_md_left_pericalcarine
DTI
left
desikan-killiany-tourville
mean diffusion
pericalcarine
dti.mean.md.left.pericalcarine
DTI_mean_md_left_postcentral
DTI
left
desikan-killiany-tourville
mean diffusion
postcentral
dti.mean.md.left.postcent
DTI_mean_md_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
posterior cingulate
dti.mean.md.left.post.cingulate
DTI_mean_md_left_precentral
DTI
left
desikan-killiany-tourville
mean diffusion
precentral
dti.mean.md.left.precent
DTI_mean_md_left_precuneus
DTI
left
desikan-killiany-tourville
mean diffusion
precuneus
dti.mean.md.left.precuneus
DTI_mean_md_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
rostral anterior cingulate
dti.mean.md.left.rostral.ant.cingulate
DTI_mean_md_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
mean diffusion
rostral middle frontal
dti.mean.md.left.rostral.middle.frontal
DTI_mean_md_left_superior_frontal
DTI
left
desikan-killiany-tourville
mean diffusion
superior frontal
dti.mean.md.left.sup.frontal
DTI_mean_md_left_superior_parietal
DTI
left
desikan-killiany-tourville
mean diffusion
superior parietal
dti.mean.md.left.sup.parietal
DTI_mean_md_left_superior_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
superior temporal
dti.mean.md.left.sup.temporal
DTI_mean_md_left_supramarginal
DTI
left
desikan-killiany-tourville
mean diffusion
supramarginal
dti.mean.md.left.supramarginal
DTI_mean_md_left_transverse_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
transverse temporal
dti.mean.md.left.transverse.temporal
DTI_mean_md_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
caudal anterior cingulate
dti.mean.md.right.caudal.ant.cingulate
DTI_mean_md_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
mean diffusion
caudal middle frontal
dti.mean.md.right.caudal.middle.frontal
DTI_mean_md_right_cuneus
DTI
right
desikan-killiany-tourville
mean diffusion
cuneus
dti.mean.md.right.cuneus
DTI_mean_md_right_entorhinal
DTI
right
desikan-killiany-tourville
mean diffusion
entorhinal
dti.mean.md.right.entorhinal
DTI_mean_md_right_fusiform
DTI
right
desikan-killiany-tourville
mean diffusion
fusiform
dti.mean.md.right.fusiform
DTI_mean_md_right_inferior_parietal
DTI
right
desikan-killiany-tourville
mean diffusion
inferior parietal
dti.mean.md.right.inf.parietal
DTI_mean_md_right_inferior_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
inferior temporal
dti.mean.md.right.inf.temporal
DTI_mean_md_right_insula
DTI
right
desikan-killiany-tourville
mean diffusion
insula
dti.mean.md.right.insula
DTI_mean_md_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
isthmus cingulate
dti.mean.md.right.isthmus.cingulate
DTI_mean_md_right_lateral_occipital
DTI
right
desikan-killiany-tourville
mean diffusion
lateral occipital
dti.mean.md.right.lateral.occipital
DTI_mean_md_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
mean diffusion
lateral orbitofrontal
dti.mean.md.right.lateral.orbitofrontal
DTI_mean_md_right_lingual
DTI
right
desikan-killiany-tourville
mean diffusion
lingual
dti.mean.md.right.lingual
DTI_mean_md_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
mean diffusion
medial orbitofrontal
dti.mean.md.right.medial.orbitofrontal
DTI_mean_md_right_middle_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
middle temporal
dti.mean.md.right.middle.temporal
DTI_mean_md_right_paracentral
DTI
right
desikan-killiany-tourville
mean diffusion
paracentral
dti.mean.md.right.paracent
DTI_mean_md_right_parahippocampal
DTI
right
desikan-killiany-tourville
mean diffusion
parahippocampal
dti.mean.md.right.parahippocampal
DTI_mean_md_right_pars_opercularis
DTI
right
desikan-killiany-tourville
mean diffusion
pars opercularis
dti.mean.md.right.pars.opercularis
DTI_mean_md_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
mean diffusion
pars orbitalis
dti.mean.md.right.pars.orbitalis
DTI_mean_md_right_pars_triangularis
DTI
right
desikan-killiany-tourville
mean diffusion
pars triangularis
dti.mean.md.right.pars.triangularis
DTI_mean_md_right_pericalcarine
DTI
right
desikan-killiany-tourville
mean diffusion
pericalcarine
dti.mean.md.right.pericalcarine
DTI_mean_md_right_postcentral
DTI
right
desikan-killiany-tourville
mean diffusion
postcentral
dti.mean.md.right.postcent
DTI_mean_md_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
posterior cingulate
dti.mean.md.right.post.cingulate
DTI_mean_md_right_precentral
DTI
right
desikan-killiany-tourville
mean diffusion
precentral
dti.mean.md.right.precent
DTI_mean_md_right_precuneus
DTI
right
desikan-killiany-tourville
mean diffusion
precuneus
dti.mean.md.right.precuneus
DTI_mean_md_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
rostral anterior cingulate
dti.mean.md.right.rostral.ant.cingulate
DTI_mean_md_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
mean diffusion
rostral middle frontal
dti.mean.md.right.rostral.middle.frontal
DTI_mean_md_right_superior_frontal
DTI
right
desikan-killiany-tourville
mean diffusion
superior frontal
dti.mean.md.right.sup.frontal
DTI_mean_md_right_superior_parietal
DTI
right
desikan-killiany-tourville
mean diffusion
superior parietal
dti.mean.md.right.sup.parietal
DTI_mean_md_right_superior_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
superior temporal
dti.mean.md.right.sup.temporal
DTI_mean_md_right_supramarginal
DTI
right
desikan-killiany-tourville
mean diffusion
supramarginal
dti.mean.md.right.supramarginal
DTI_mean_md_right_transverse_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
transverse temporal
dti.mean.md.right.transverse.temporal
DTI_volume_md_background
DTI
​
ANTs
geometry/volume
background
dti.volume.md.background
DTI_volume_md_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
dti.volume.md.left.caudal.ant.cingulate
DTI_volume_md_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
dti.volume.md.left.caudal.middle.frontal
DTI_volume_md_left_cuneus
DTI
left
desikan-killiany-tourville
geometry/volume
cuneus
dti.volume.md.left.cuneus
DTI_volume_md_left_entorhinal
DTI
left
desikan-killiany-tourville
geometry/volume
entorhinal
dti.volume.md.left.entorhinal
DTI_volume_md_left_fusiform
DTI
left
desikan-killiany-tourville
geometry/volume
fusiform
dti.volume.md.left.fusiform
DTI_volume_md_left_inferior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior parietal
dti.volume.md.left.inf.parietal
DTI_volume_md_left_inferior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior temporal
dti.volume.md.left.inf.temporal
DTI_volume_md_left_insula
DTI
left
desikan-killiany-tourville
geometry/volume
insula
dti.volume.md.left.insula
DTI_volume_md_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
dti.volume.md.left.isthmus.cingulate
DTI_volume_md_left_lateral_occipital
DTI
left
desikan-killiany-tourville
geometry/volume
lateral occipital
dti.volume.md.left.lateral.occipital
DTI_volume_md_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
dti.volume.md.left.lateral.orbitofrontal
DTI_volume_md_left_lingual
DTI
left
desikan-killiany-tourville
geometry/volume
lingual
dti.volume.md.left.lingual
DTI_volume_md_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
dti.volume.md.left.medial.orbitofrontal
DTI_volume_md_left_middle_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
middle temporal
dti.volume.md.left.middle.temporal
DTI_volume_md_left_paracentral
DTI
left
desikan-killiany-tourville
geometry/volume
paracentral
dti.volume.md.left.paracent
DTI_volume_md_left_parahippocampal
DTI
left
desikan-killiany-tourville
geometry/volume
parahippocampal
dti.volume.md.left.parahippocampal
DTI_volume_md_left_pars_opercularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars opercularis
dti.volume.md.left.pars.opercularis
DTI_volume_md_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
dti.volume.md.left.pars.orbitalis
DTI_volume_md_left_pars_triangularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars triangularis
dti.volume.md.left.pars.triangularis
DTI_volume_md_left_pericalcarine
DTI
left
desikan-killiany-tourville
geometry/volume
pericalcarine
dti.volume.md.left.pericalcarine
DTI_volume_md_left_postcentral
DTI
left
desikan-killiany-tourville
geometry/volume
postcentral
dti.volume.md.left.postcent
DTI_volume_md_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
dti.volume.md.left.post.cingulate
DTI_volume_md_left_precentral
DTI
left
desikan-killiany-tourville
geometry/volume
precentral
dti.volume.md.left.precent
DTI_volume_md_left_precuneus
DTI
left
desikan-killiany-tourville
geometry/volume
precuneus
dti.volume.md.left.precuneus
DTI_volume_md_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
dti.volume.md.left.rostral.ant.cingulate
DTI_volume_md_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
dti.volume.md.left.rostral.middle.frontal
DTI_volume_md_left_superior_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
superior frontal
dti.volume.md.left.sup.frontal
DTI_volume_md_left_superior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
superior parietal
dti.volume.md.left.sup.parietal
DTI_volume_md_left_superior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
superior temporal
dti.volume.md.left.sup.temporal
DTI_volume_md_left_supramarginal
DTI
left
desikan-killiany-tourville
geometry/volume
supramarginal
dti.volume.md.left.supramarginal
DTI_volume_md_left_transverse_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
transverse temporal
dti.volume.md.left.transverse.temporal
DTI_volume_md_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
dti.volume.md.right.caudal.ant.cingulate
DTI_volume_md_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
dti.volume.md.right.caudal.middle.frontal
DTI_volume_md_right_cuneus
DTI
right
desikan-killiany-tourville
geometry/volume
cuneus
dti.volume.md.right.cuneus
DTI_volume_md_right_entorhinal
DTI
right
desikan-killiany-tourville
geometry/volume
entorhinal
dti.volume.md.right.entorhinal
DTI_volume_md_right_fusiform
DTI
right
desikan-killiany-tourville
geometry/volume
fusiform
dti.volume.md.right.fusiform
DTI_volume_md_right_inferior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior parietal
dti.volume.md.right.inf.parietal
DTI_volume_md_right_inferior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior temporal
dti.volume.md.right.inf.temporal
DTI_volume_md_right_insula
DTI
right
desikan-killiany-tourville
geometry/volume
insula
dti.volume.md.right.insula
DTI_volume_md_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
dti.volume.md.right.isthmus.cingulate
DTI_volume_md_right_lateral_occipital
DTI
right
desikan-killiany-tourville
geometry/volume
lateral occipital
dti.volume.md.right.lateral.occipital
DTI_volume_md_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
dti.volume.md.right.lateral.orbitofrontal
DTI_volume_md_right_lingual
DTI
right
desikan-killiany-tourville
geometry/volume
lingual
dti.volume.md.right.lingual
DTI_volume_md_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
dti.volume.md.right.medial.orbitofrontal
DTI_volume_md_right_middle_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
middle temporal
dti.volume.md.right.middle.temporal
DTI_volume_md_right_paracentral
DTI
right
desikan-killiany-tourville
geometry/volume
paracentral
dti.volume.md.right.paracent
DTI_volume_md_right_parahippocampal
DTI
right
desikan-killiany-tourville
geometry/volume
parahippocampal
dti.volume.md.right.parahippocampal
DTI_volume_md_right_pars_opercularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars opercularis
dti.volume.md.right.pars.opercularis
DTI_volume_md_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
dti.volume.md.right.pars.orbitalis
DTI_volume_md_right_pars_triangularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars triangularis
dti.volume.md.right.pars.triangularis
DTI_volume_md_right_pericalcarine
DTI
right
desikan-killiany-tourville
geometry/volume
pericalcarine
dti.volume.md.right.pericalcarine
DTI_volume_md_right_postcentral
DTI
right
desikan-killiany-tourville
geometry/volume
postcentral
dti.volume.md.right.postcent
DTI_volume_md_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
dti.volume.md.right.post.cingulate
DTI_volume_md_right_precentral
DTI
right
desikan-killiany-tourville
geometry/volume
precentral
dti.volume.md.right.precent
DTI_volume_md_right_precuneus
DTI
right
desikan-killiany-tourville
geometry/volume
precuneus
dti.volume.md.right.precuneus
DTI_volume_md_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
dti.volume.md.right.rostral.ant.cingulate
DTI_volume_md_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
dti.volume.md.right.rostral.middle.frontal
DTI_volume_md_right_superior_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
superior frontal
dti.volume.md.right.sup.frontal
DTI_volume_md_right_superior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
superior parietal
dti.volume.md.right.sup.parietal
DTI_volume_md_right_superior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
superior temporal
dti.volume.md.right.sup.temporal
DTI_volume_md_right_supramarginal
DTI
right
desikan-killiany-tourville
geometry/volume
supramarginal
dti.volume.md.right.supramarginal
DTI_volume_md_right_transverse_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
transverse temporal
dti.volume.md.right.transverse.temporal
DTI_mean_md_deep_bn_gp_gpe_left
DTI
left
CIT168
mean diffusion
globus pallidus externa
dti.mean.md.deep.bn.gp.gpe.left
DTI_mean_md_deep_bn_gp_gpe_right
DTI
right
CIT168
mean diffusion
globus pallidus externa
dti.mean.md.deep.bn.gp.gpe.right
DTI_mean_md_deep_bn_gp_gpi_left
DTI
left
CIT168
mean diffusion
globus pallidus interna
dti.mean.md.deep.bn.gp.gpi.left
DTI_mean_md_deep_bn_gp_gpi_right
DTI
right
CIT168
mean diffusion
globus pallidus interna
dti.mean.md.deep.bn.gp.gpi.right
DTI_mean_md_deep_bn_str_ca_left
DTI
left
CIT168
mean diffusion
caudate
dti.mean.md.deep.bn.str.ca.left
DTI_mean_md_deep_bn_str_ca_right
DTI
right
CIT168
mean diffusion
caudate
dti.mean.md.deep.bn.str.ca.right
DTI_mean_md_deep_bn_str_pu_left
DTI
left
CIT168
mean diffusion
putamen
dti.mean.md.deep.bn.str.pu.left
DTI_mean_md_deep_bn_str_pu_right
DTI
right
CIT168
mean diffusion
putamen
dti.mean.md.deep.bn.str.pu.right
DTI_mean_md_deep_mtg_rn_left
DTI
left
CIT168
mean diffusion
red nucleus
dti.mean.md.deep.mtg.rn.left
DTI_mean_md_deep_mtg_rn_right
DTI
right
CIT168
mean diffusion
red nucleus
dti.mean.md.deep.mtg.rn.right
DTI_mean_md_deep_mtg_sn_snc_left
DTI
left
CIT168
mean diffusion
Substantia Nigra pars compacta
dti.mean.md.deep.snc.left
DTI_mean_md_deep_mtg_sn_snc_right
DTI
right
CIT168
mean diffusion
Substantia Nigra pars compacta
dti.mean.md.deep.snc.right
DTI_mean_md_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.mean.md.deep.snr.left
DTI_mean_md_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.mean.md.deep.snr.right
DTI_mean_md_deep_referenceregion_left
DTI
left
CIT168
mean diffusion
​
dti.mean.md.deep.referenceregion.left
DTI_mean_md_deep_referenceregion_right
DTI
right
CIT168
mean diffusion
​
dti.mean.md.deep.referenceregion.right
DTI_volume_md_deep_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
dti.volume.md.deep.bn.gp.gpe.left
DTI_volume_md_deep_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
dti.volume.md.deep.bn.gp.gpe.right
DTI_volume_md_deep_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
dti.volume.md.deep.bn.gp.gpi.left
DTI_volume_md_deep_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
dti.volume.md.deep.bn.gp.gpi.right
DTI_volume_md_deep_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
dti.volume.md.deep.bn.str.ca.left
DTI_volume_md_deep_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
dti.volume.md.deep.bn.str.ca.right
DTI_volume_md_deep_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
dti.volume.md.deep.bn.str.pu.left
DTI_volume_md_deep_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
dti.volume.md.deep.bn.str.pu.right
DTI_volume_md_deep_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
dti.volume.md.deep.mtg.rn.left
DTI_volume_md_deep_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
dti.volume.md.deep.mtg.rn.right
DTI_volume_md_deep_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.md.deep.snc.left
DTI_volume_md_deep_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.md.deep.snc.right
DTI_volume_md_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.md.deep.snr.left
DTI_volume_md_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.md.deep.snr.right
DTI_volume_md_deep_referenceregion_left
DTI
left
CIT168
geometry/volume
​
dti.volume.md.deep.referenceregion.left
DTI_volume_md_deep_referenceregion_right
DTI
right
CIT168
geometry/volume
​
dti.volume.md.deep.referenceregion.right
DTI_mean_md_bn_gp_gpe_left
DTI
left
CIT168
mean diffusion
globus pallidus externa
dti.mean.md.bn.gp.gpe.left
DTI_mean_md_bn_gp_gpe_right
DTI
right
CIT168
mean diffusion
globus pallidus externa
dti.mean.md.bn.gp.gpe.right
DTI_mean_md_bn_gp_gpi_left
DTI
left
CIT168
mean diffusion
globus pallidus interna
dti.mean.md.bn.gp.gpi.left
DTI_mean_md_bn_gp_gpi_right
DTI
right
CIT168
mean diffusion
globus pallidus interna
dti.mean.md.bn.gp.gpi.right
DTI_mean_md_bn_gp_vep_left
DTI
left
CIT168
mean diffusion
ventral pallidum
dti.mean.md.bn.gp.vep.left
DTI_mean_md_bn_gp_vep_right
DTI
right
CIT168
mean diffusion
ventral pallidum
dti.mean.md.bn.gp.vep.right
DTI_mean_md_bn_str_ca_left
DTI
left
CIT168
mean diffusion
caudate
dti.mean.md.bn.str.ca.left
DTI_mean_md_bn_str_ca_right
DTI
right
CIT168
mean diffusion
caudate
dti.mean.md.bn.str.ca.right
DTI_mean_md_bn_str_nac_left
DTI
left
CIT168
mean diffusion
Nucleus Accumbens
dti.mean.md.bn.str.nac.left
DTI_mean_md_bn_str_nac_right
DTI
right
CIT168
mean diffusion
Nucleus Accumbens
dti.mean.md.bn.str.nac.right
DTI_mean_md_bn_str_pu_left
DTI
left
CIT168
mean diffusion
putamen
dti.mean.md.bn.str.pu.left
DTI_mean_md_bn_str_pu_right
DTI
right
CIT168
mean diffusion
putamen
dti.mean.md.bn.str.pu.right
DTI_mean_md_die_hth_left
DTI
left
CIT168
mean diffusion
Hypothalamus
dti.mean.md.die.hth.left
DTI_mean_md_die_hth_mn_left
DTI
left
CIT168
mean diffusion
mammillary nucleus
dti.mean.md.die.hth.mn.left
DTI_mean_md_die_hth_mn_right
DTI
right
CIT168
mean diffusion
mammillary nucleus
dti.mean.md.die.hth.mn.right
DTI_mean_md_die_hth_right
DTI
right
CIT168
mean diffusion
Hypothalamus
dti.mean.md.die.hth.right
DTI_mean_md_die_sth_left
DTI
left
CIT168
mean diffusion
Subthalamic Nucleus
dti.mean.md.die.sth.left
DTI_mean_md_die_sth_right
DTI
right
CIT168
mean diffusion
Subthalamic Nucleus
dti.mean.md.die.sth.right
DTI_mean_md_exa_left
DTI
left
CIT168
mean diffusion
extended amygdala
dti.mean.md.exa.left
DTI_mean_md_exa_right
DTI
right
CIT168
mean diffusion
extended amygdala
dti.mean.md.exa.right
DTI_mean_md_mtg_rn_left
DTI
left
CIT168
mean diffusion
red nucleus
dti.mean.md.mtg.rn.left
DTI_mean_md_mtg_rn_right
DTI
right
CIT168
mean diffusion
red nucleus
dti.mean.md.mtg.rn.right
DTI_mean_md_mtg_sn_snc_left
DTI
left
CIT168
mean diffusion
Substantia Nigra pars compacta
dti.mean.md.snc.left
DTI_mean_md_mtg_sn_snc_right
DTI
right
CIT168
mean diffusion
Substantia Nigra pars compacta
dti.mean.md.snc.right
DTI_mean_md_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.mean.md.snr.left
DTI_mean_md_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.mean.md.snr.right
DTI_mean_md_mtg_vtr_pbp_left
DTI
left
CIT168
mean diffusion
Parabrachial Pigmented Nucleus
dti.mean.md.mtg.vtr.pbp.left
DTI_mean_md_mtg_vtr_pbp_right
DTI
right
CIT168
mean diffusion
Parabrachial Pigmented Nucleus
dti.mean.md.mtg.vtr.pbp.right
DTI_mean_md_mtg_vtr_vta_left
DTI
left
CIT168
mean diffusion
Ventral Tegmental Area
dti.mean.md.mtg.vtr.vta.left
DTI_mean_md_mtg_vtr_vta_right
DTI
right
CIT168
mean diffusion
Ventral Tegmental Area
dti.mean.md.mtg.vtr.vta.right
DTI_mean_md_referenceregion_left
DTI
left
CIT168
mean diffusion
​
dti.mean.md.referenceregion.left
DTI_mean_md_referenceregion_right
DTI
right
CIT168
mean diffusion
​
dti.mean.md.referenceregion.right
DTI_mean_md_thm_eth_hn_left
DTI
left
CIT168
mean diffusion
Habenular Nuclei
dti.mean.md.thm.eth.hn.left
DTI_mean_md_thm_eth_hn_right
DTI
right
CIT168
mean diffusion
Habenular Nuclei
dti.mean.md.thm.eth.hn.right
DTI_volume_md_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
dti.volume.md.bn.gp.gpe.left
DTI_volume_md_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
dti.volume.md.bn.gp.gpe.right
DTI_volume_md_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
dti.volume.md.bn.gp.gpi.left
DTI_volume_md_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
dti.volume.md.bn.gp.gpi.right
DTI_volume_md_bn_gp_vep_left
DTI
left
CIT168
geometry/volume
ventral pallidum
dti.volume.md.bn.gp.vep.left
DTI_volume_md_bn_gp_vep_right
DTI
right
CIT168
geometry/volume
ventral pallidum
dti.volume.md.bn.gp.vep.right
DTI_volume_md_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
dti.volume.md.bn.str.ca.left
DTI_volume_md_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
dti.volume.md.bn.str.ca.right
DTI_volume_md_bn_str_nac_left
DTI
left
CIT168
geometry/volume
Nucleus Accumbens
dti.volume.md.bn.str.nac.left
DTI_volume_md_bn_str_nac_right
DTI
right
CIT168
geometry/volume
Nucleus Accumbens
dti.volume.md.bn.str.nac.right
DTI_volume_md_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
dti.volume.md.bn.str.pu.left
DTI_volume_md_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
dti.volume.md.bn.str.pu.right
DTI_volume_md_die_hth_left
DTI
left
CIT168
geometry/volume
Hypothalamus
dti.volume.md.die.hth.left
DTI_volume_md_die_hth_mn_left
DTI
left
CIT168
geometry/volume
mammillary nucleus
dti.volume.md.die.hth.mn.left
DTI_volume_md_die_hth_mn_right
DTI
right
CIT168
geometry/volume
mammillary nucleus
dti.volume.md.die.hth.mn.right
DTI_volume_md_die_hth_right
DTI
right
CIT168
geometry/volume
Hypothalamus
dti.volume.md.die.hth.right
DTI_volume_md_die_sth_left
DTI
left
CIT168
geometry/volume
Subthalamic Nucleus
dti.volume.md.die.sth.left
DTI_volume_md_die_sth_right
DTI
right
CIT168
geometry/volume
Subthalamic Nucleus
dti.volume.md.die.sth.right
DTI_volume_md_exa_left
DTI
left
CIT168
geometry/volume
extended amygdala
dti.volume.md.exa.left
DTI_volume_md_exa_right
DTI
right
CIT168
geometry/volume
extended amygdala
dti.volume.md.exa.right
DTI_volume_md_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
dti.volume.md.mtg.rn.left
DTI_volume_md_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
dti.volume.md.mtg.rn.right
DTI_volume_md_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.md.snc.left
DTI_volume_md_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
dti.volume.md.snc.right
DTI_volume_md_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.md.snr.left
DTI_volume_md_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
dti.volume.md.snr.right
DTI_volume_md_mtg_vtr_pbp_left
DTI
left
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
dti.volume.md.mtg.vtr.pbp.left
DTI_volume_md_mtg_vtr_pbp_right
DTI
right
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
dti.volume.md.mtg.vtr.pbp.right
DTI_volume_md_mtg_vtr_vta_left
DTI
left
CIT168
geometry/volume
Ventral Tegmental Area
dti.volume.md.mtg.vtr.vta.left
DTI_volume_md_mtg_vtr_vta_right
DTI
right
CIT168
geometry/volume
Ventral Tegmental Area
dti.volume.md.mtg.vtr.vta.right
DTI_volume_md_referenceregion_left
DTI
left
CIT168
geometry/volume
​
dti.volume.md.referenceregion.left
DTI_volume_md_referenceregion_right
DTI
right
CIT168
geometry/volume
​
dti.volume.md.referenceregion.right
DTI_volume_md_thm_eth_hn_left
DTI
left
CIT168
geometry/volume
Habenular Nuclei
dti.volume.md.thm.eth.hn.left
DTI_volume_md_thm_eth_hn_right
DTI
right
CIT168
geometry/volume
Habenular Nuclei
dti.volume.md.thm.eth.hn.right
DTI_mean_md_ch13_left
DTI
left
BF
mean diffusion
basal nucleus ch1 to ch3
dti.mean.md.ch13.left
DTI_mean_md_ch13_right
DTI
right
BF
mean diffusion
basal nucleus ch1 to ch3
dti.mean.md.ch13.right

## Joining with clinical data: PPMI

We provide an example of how to join derived `ANTsPyMM` summary data with clinical variables from PPMI.

    library( subtyper)
    ?merge_ppmi_imaging_clinical_demographic_data